@@ -6,8 +6,12 @@ import { GrafanaRootScope } from 'app/angular/GrafanaCtrl';
 import coreModule from 'app/angular/core_module';
 
 export class AngularLoader implements AngularLoaderInterface {
-  /** @ngInject */
-  constructor(private $compile: any, private $rootScope: GrafanaRootScope) {}
+  static $inject = ['$compile', '$rootScope'];
+
+  constructor(
+    private $compile: any,
+    private $rootScope: GrafanaRootScope
+  ) {}
 
   load(elem: any, scopeProps: any, template: string): AngularComponent {
     const scope = this.$rootScope.$new();
