@@ -1,8 +1,8 @@
 import { useObservable } from 'react-use';
 import { BehaviorSubject } from 'rxjs';
 
-import { AppEvents, NavModelItem, UrlQueryValue } from '@grafana/data';
-import { locationService } from '@grafana/runtime';
+import { AppEvents, NavModel, NavModelItem, PageLayoutType, UrlQueryValue } from '@grafana/data';
+import { locationService, reportInteraction } from '@grafana/runtime';
 import appEvents from 'app/core/app_events';
 import { t } from 'app/core/internationalization';
 import store from 'app/core/store';
@@ -13,26 +13,26 @@ import { RouteDescriptor } from '../../navigation/types';
 
 export interface AppChromeState {
   chromeless?: boolean;
-  sectionNav: NavModelItem;
+  sectionNav: NavModel;
   pageNav?: NavModelItem;
   actions?: React.ReactNode;
   searchBarHidden?: boolean;
   megaMenuOpen?: boolean;
   kioskMode: KioskMode | null;
+  layout: PageLayoutType;
 }
 
-const defaultSection: NavModelItem = { text: 'Grafana' };
-
 export class AppChromeService {
   searchBarStorageKey = 'SearchBar_Hidden';
   private currentRoute?: RouteDescriptor;
-  private routeChangeHandled?: boolean;
+  private routeChangeHandled = true;
 
   readonly state = new BehaviorSubject<AppChromeState>({
     chromeless: true, // start out hidden to not flash it on pages without chrome
-    sectionNav: defaultSection,
+    sectionNav: { node: { text: t('nav.home.title', 'Home') }, main: { text: '' } },
     searchBarHidden: store.getBool(this.searchBarStorageKey, false),
     kioskMode: null,
+    layout: PageLayoutType.Canvas,
   });
 
   setMatchedRoute(route: RouteDescriptor) {
@@ -52,8 +52,9 @@ export class AppChromeService {
     if (!this.routeChangeHandled) {
       newState.actions = undefined;
       newState.pageNav = undefined;
-      newState.sectionNav = defaultSection;
+      newState.sectionNav = { node: { text: t('nav.home.title', 'Home') }, main: { text: '' } };
       newState.chromeless = this.currentRoute?.chromeless;
+      newState.layout = PageLayoutType.Standard;
       this.routeChangeHandled = true;
     }
 
@@ -62,18 +63,40 @@ export class AppChromeService {
     // KioskMode overrides chromeless state
     newState.chromeless = newState.kioskMode === KioskMode.Full || this.currentRoute?.chromeless;
 
-    if (!isShallowEqual(current, newState)) {
+    if (!this.ignoreStateUpdate(newState, current)) {
       this.state.next(newState);
     }
   }
 
+  ignoreStateUpdate(newState: AppChromeState, current: AppChromeState) {
+    if (isShallowEqual(newState, current)) {
+      return true;
+    }
+
+    // Some updates can have new instance of sectionNav or pageNav but with same values
+    if (newState.sectionNav !== current.sectionNav || newState.pageNav !== current.pageNav) {
+      if (
+        newState.actions === current.actions &&
+        newState.layout === current.layout &&
+        navItemsAreTheSame(newState.sectionNav.node, current.sectionNav.node) &&
+        navItemsAreTheSame(newState.pageNav, current.pageNav)
+      ) {
+        return true;
+      }
+    }
+
+    return false;
+  }
+
   useState() {
     // eslint-disable-next-line react-hooks/rules-of-hooks
     return useObservable(this.state, this.state.getValue());
   }
 
   onToggleMegaMenu = () => {
-    this.update({ megaMenuOpen: !this.state.getValue().megaMenuOpen });
+    const isOpen = !this.state.getValue().megaMenuOpen;
+    reportInteraction('grafana_toggle_menu_clicked', { action: isOpen ? 'open' : 'close' });
+    this.update({ megaMenuOpen: isOpen });
   };
 
   setMegaMenu = (megaMenuOpen: boolean) => {
@@ -81,9 +104,15 @@ export class AppChromeService {
   };
 
   onToggleSearchBar = () => {
-    const searchBarHidden = !this.state.getValue().searchBarHidden;
-    store.set(this.searchBarStorageKey, searchBarHidden);
-    this.update({ searchBarHidden });
+    const { searchBarHidden, kioskMode } = this.state.getValue();
+    const newSearchBarHidden = !searchBarHidden;
+    store.set(this.searchBarStorageKey, newSearchBarHidden);
+
+    if (kioskMode) {
+      locationService.partial({ kiosk: null });
+    }
+
+    this.update({ searchBarHidden: newSearchBarHidden, kioskMode: null });
   };
 
   onToggleKioskMode = () => {
@@ -134,3 +163,22 @@ export class AppChromeService {
     return null;
   }
 }
+
+/**
+ * Checks if text, url, active child url and parent are the same
+ **/
+function navItemsAreTheSame(a: NavModelItem | undefined, b: NavModelItem | undefined): boolean {
+  if (a === b) {
+    return true;
+  }
+
+  const aActiveChild = a?.children?.find((child) => child.active);
+  const bActiveChild = b?.children?.find((child) => child.active);
+
+  return (
+    a?.text === b?.text &&
+    a?.url === b?.url &&
+    aActiveChild?.url === bActiveChild?.url &&
+    navItemsAreTheSame(a?.parentItem, b?.parentItem)
+  );
+}
