@@ -3,7 +3,6 @@ import React from 'react';
 import { useEffectOnce } from 'react-use';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { config } from '@grafana/runtime';
 import { Alert, useStyles2 } from '@grafana/ui';
 import { AppNotification, timeoutMap } from 'app/types';
 
@@ -21,7 +20,7 @@ export default function AppNotificationItem({ appNotification, onClearNotificati
     }, timeoutMap[appNotification.severity]);
   });
 
-  const showTraceId = config.featureToggles.tracing && appNotification.traceId;
+  const hasBody = appNotification.component || appNotification.text || appNotification.traceId;
 
   return (
     <Alert
@@ -30,10 +29,12 @@ export default function AppNotificationItem({ appNotification, onClearNotificati
       onRemove={() => onClearNotification(appNotification.id)}
       elevated
     >
-      <div className={styles.wrapper}>
-        <span>{appNotification.component || appNotification.text}</span>
-        {showTraceId && <span className={styles.trace}>Trace ID: {appNotification.traceId}</span>}
-      </div>
+      {hasBody && (
+        <div className={styles.wrapper}>
+          <span>{appNotification.component || appNotification.text}</span>
+          {appNotification.traceId && <span className={styles.trace}>Trace ID: {appNotification.traceId}</span>}
+        </div>
+      )}
     </Alert>
   );
 }
