@@ -2,7 +2,6 @@ import React, { FC, HTMLAttributes, RefCallback } from 'react';
 
 import { NavModel, NavModelItem, PageLayoutType } from '@grafana/data';
 
-import { OldNavOnly } from './OldNavOnly';
 import { PageContents } from './PageContents';
 
 export interface PageProps extends HTMLAttributes<HTMLDivElement> {
@@ -14,14 +13,13 @@ export interface PageProps extends HTMLAttributes<HTMLDivElement> {
   info?: PageInfoItem[];
   /** Can be used to place actions inline with the heading */
   actions?: React.ReactNode;
+  onEditTitle?: (newValue: string) => Promise<void>;
   /** Can be used to customize rendering of title */
   renderTitle?: (title: string) => React.ReactNode;
   /** Can be used to customize or customize and set a page sub title */
   subTitle?: React.ReactNode;
   /** Control the page layout. */
   layout?: PageLayoutType;
-  /** Something we can remove when we remove the old nav. */
-  toolbar?: React.ReactNode;
   /** Can be used to get the scroll container element to access scroll position */
   scrollRef?: RefCallback<HTMLDivElement>;
   /** Can be used to update the current scroll position */
@@ -34,6 +32,5 @@ export interface PageInfoItem {
 }
 
 export interface PageType extends FC<PageProps> {
-  OldNavOnly: typeof OldNavOnly;
   Contents: typeof PageContents;
 }
