@@ -1,33 +1,35 @@
 import { css, cx } from '@emotion/css';
 import React, { MouseEventHandler } from 'react';
-import { DraggableProvidedDragHandleProps } from 'react-beautiful-dnd';
+import { DraggableProvided } from 'react-beautiful-dnd';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { Icon, IconButton, useStyles2 } from '@grafana/ui';
 
-interface QueryOperationRowHeaderProps {
+export interface QueryOperationRowHeaderProps {
   actionsElement?: React.ReactNode;
   disabled?: boolean;
   draggable: boolean;
-  dragHandleProps?: DraggableProvidedDragHandleProps;
+  collapsable?: boolean;
+  dragHandleProps?: DraggableProvided['dragHandleProps'];
   headerElement?: React.ReactNode;
   isContentVisible: boolean;
   onRowToggle: () => void;
   reportDragMousePosition: MouseEventHandler<HTMLDivElement>;
-  titleElement?: React.ReactNode;
+  title?: string;
   id: string;
 }
 
-export const QueryOperationRowHeader: React.FC<QueryOperationRowHeaderProps> = ({
+export const QueryOperationRowHeader = ({
   actionsElement,
   disabled,
   draggable,
+  collapsable = true,
   dragHandleProps,
   headerElement,
   isContentVisible,
   onRowToggle,
   reportDragMousePosition,
-  titleElement,
+  title,
   id,
 }: QueryOperationRowHeaderProps) => {
   const styles = useStyles2(getStyles);
@@ -35,19 +37,22 @@ export const QueryOperationRowHeader: React.FC<QueryOperationRowHeaderProps> = (
   return (
     <div className={styles.header}>
       <div className={styles.column}>
-        <IconButton
-          name={isContentVisible ? 'angle-down' : 'angle-right'}
-          title="toggle collapse and expand"
-          aria-label="toggle collapse and expand query row"
-          className={styles.collapseIcon}
-          onClick={onRowToggle}
-          type="button"
-          aria-expanded={isContentVisible}
-          aria-controls={id}
-        />
-        {titleElement && (
+        {collapsable && (
+          <IconButton
+            name={isContentVisible ? 'angle-down' : 'angle-right'}
+            tooltip={isContentVisible ? 'Collapse query row' : 'Expand query row'}
+            className={styles.collapseIcon}
+            onClick={onRowToggle}
+            aria-expanded={isContentVisible}
+            aria-controls={id}
+          />
+        )}
+        {title && (
+          // disabling the a11y rules here as the IconButton above handles keyboard interactions
+          // this is just to provide a better experience for mouse users
+          // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
           <div className={styles.titleWrapper} onClick={onRowToggle} aria-label="Query operation row title">
-            <div className={cx(styles.title, disabled && styles.disabled)}>{titleElement}</div>
+            <div className={cx(styles.title, disabled && styles.disabled)}>{title}</div>
           </div>
         )}
         {headerElement}
