@@ -1,7 +1,8 @@
-import * as DOMPurify from 'dompurify';
 import React from 'react';
 import SVG, { Props } from 'react-inlinesvg';
 
+import { textUtil } from '@grafana/data';
+
 export const SanitizedSVG = (props: Props) => {
   return <SVG {...props} cacheRequests={true} preProcessor={getCleanSVG} />;
 };
@@ -11,7 +12,7 @@ let cache = new Map<string, string>();
 function getCleanSVG(code: string): string {
   let clean = cache.get(code);
   if (!clean) {
-    clean = DOMPurify.sanitize(code, { USE_PROFILES: { svg: true, svgFilters: true } });
+    clean = textUtil.sanitizeSVGContent(code);
     cache.set(code, clean);
   }
   return clean;
