@@ -1,9 +1,10 @@
 import { css } from '@emotion/css';
-import React, { FC, useCallback, useEffect, useMemo, useState } from 'react';
+import React, { useCallback, useEffect, useMemo, useState } from 'react';
 import { components } from 'react-select';
 
 import { escapeStringForRegex, GrafanaTheme2 } from '@grafana/data';
 import { Icon, MultiSelect, useStyles2 } from '@grafana/ui';
+import { t } from 'app/core/internationalization';
 
 import { TagBadge } from './TagBadge';
 import { TagOption } from './TagOption';
@@ -38,18 +39,18 @@ const filterOption = (option: any, searchQuery: string) => {
   return regex.test(option.value);
 };
 
-export const TagFilter: FC<Props> = ({
+export const TagFilter = ({
   allowCustomValue = false,
   formatCreateLabel,
   hideValues,
   inputId,
   isClearable,
   onChange,
-  placeholder = 'Filter by tag',
+  placeholder,
   tagOptions,
   tags,
   width,
-}) => {
+}: Props) => {
   const styles = useStyles2(getStyles);
 
   const currentlySelectedTags = tags.map((tag) => ({ value: tag, label: tag, count: 0 }));
@@ -134,10 +135,10 @@ export const TagFilter: FC<Props> = ({
     getOptionValue: (i: any) => i.value,
     inputId,
     isMulti: true,
-    loadingMessage: 'Loading...',
-    noOptionsMessage: 'No tags found',
     onChange: onTagChange,
-    placeholder,
+    loadingMessage: t('tag-filter.loading', 'Loading...'),
+    noOptionsMessage: t('tag-filter.no-tags', 'No tags found'),
+    placeholder: placeholder || t('tag-filter.placeholder', 'Filter by tag'),
     value: currentlySelectedTags,
     width,
     components: {
