@@ -1,54 +1,59 @@
 import { css } from '@emotion/css';
-import React from 'react';
+import React, { useMemo } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { Modal, useStyles2 } from '@grafana/ui';
+import { getModKey } from 'app/core/utils/browser';
 
-const shortcuts = {
-  Global: [
-    { keys: ['g', 'h'], description: 'Go to Home Dashboard' },
-    { keys: ['g', 'p'], description: 'Go to Profile' },
-    { keys: ['s', 'o'], description: 'Open search' },
-    { keys: ['esc'], description: 'Exit edit/setting views' },
-    { keys: ['h'], description: 'Show all keyboard shortcuts' },
-    { keys: ['mod+k'], description: 'Open command palette' },
-    { keys: ['c', 't'], description: 'Change theme' },
-  ],
-  Dashboard: [
-    { keys: ['mod+s'], description: 'Save dashboard' },
-    { keys: ['d', 'r'], description: 'Refresh all panels' },
-    { keys: ['d', 's'], description: 'Dashboard settings' },
-    { keys: ['d', 'v'], description: 'Toggle in-active / view mode' },
-    { keys: ['d', 'k'], description: 'Toggle kiosk mode (hides top nav)' },
-    { keys: ['d', 'E'], description: 'Expand all rows' },
-    { keys: ['d', 'C'], description: 'Collapse all rows' },
-    { keys: ['d', 'a'], description: 'Toggle auto fit panels (experimental feature)' },
-    { keys: ['mod+o'], description: 'Toggle shared graph crosshair' },
-    { keys: ['d', 'l'], description: 'Toggle all panel legends' },
-  ],
-  'Focused Panel': [
-    { keys: ['e'], description: 'Toggle panel edit view' },
-    { keys: ['v'], description: 'Toggle panel fullscreen view' },
-    { keys: ['p', 's'], description: 'Open Panel Share Modal' },
-    { keys: ['p', 'd'], description: 'Duplicate Panel' },
-    { keys: ['p', 'r'], description: 'Remove Panel' },
-    { keys: ['p', 'l'], description: 'Toggle panel legend' },
-  ],
-  'Time Range': [
-    { keys: ['t', 'z'], description: 'Zoom out time range' },
-    {
-      keys: ['t', '←'],
-      description: 'Move time range back',
-    },
-    {
-      keys: ['t', '→'],
-      description: 'Move time range forward',
-    },
-    {
-      keys: ['t', 'a'],
-      description: 'Make time range absolute/permanent',
-    },
-  ],
+const getShortcuts = (modKey: string) => {
+  return {
+    Global: [
+      { keys: ['g', 'h'], description: 'Go to Home Dashboard' },
+      { keys: ['g', 'd'], description: 'Go to Dashboards' },
+      { keys: ['g', 'e'], description: 'Go to Explore' },
+      { keys: ['g', 'p'], description: 'Go to Profile' },
+      { keys: [`${modKey} + k`], description: 'Open search' },
+      { keys: ['esc'], description: 'Exit edit/setting views' },
+      { keys: ['h'], description: 'Show all keyboard shortcuts' },
+      { keys: ['c', 't'], description: 'Change theme' },
+    ],
+    Dashboard: [
+      { keys: [`${modKey}+s`], description: 'Save dashboard' },
+      { keys: ['d', 'r'], description: 'Refresh all panels' },
+      { keys: ['d', 's'], description: 'Dashboard settings' },
+      { keys: ['d', 'v'], description: 'Toggle in-active / view mode' },
+      { keys: ['d', 'k'], description: 'Toggle kiosk mode (hides top nav)' },
+      { keys: ['d', 'E'], description: 'Expand all rows' },
+      { keys: ['d', 'C'], description: 'Collapse all rows' },
+      { keys: ['d', 'a'], description: 'Toggle auto fit panels (experimental feature)' },
+      { keys: [`${modKey} + o`], description: 'Toggle shared graph crosshair' },
+      { keys: ['d', 'l'], description: 'Toggle all panel legends' },
+      { keys: ['d', 'x'], description: 'Toggle exemplars in all panel' },
+    ],
+    'Focused Panel': [
+      { keys: ['e'], description: 'Toggle panel edit view' },
+      { keys: ['v'], description: 'Toggle panel fullscreen view' },
+      { keys: ['p', 's'], description: 'Open Panel Share Modal' },
+      { keys: ['p', 'd'], description: 'Duplicate Panel' },
+      { keys: ['p', 'r'], description: 'Remove Panel' },
+      { keys: ['p', 'l'], description: 'Toggle panel legend' },
+    ],
+    'Time Range': [
+      { keys: ['t', 'z'], description: 'Zoom out time range' },
+      {
+        keys: ['t', '←'],
+        description: 'Move time range back',
+      },
+      {
+        keys: ['t', '→'],
+        description: 'Move time range forward',
+      },
+      {
+        keys: ['t', 'a'],
+        description: 'Make time range absolute/permanent',
+      },
+    ],
+  };
 };
 
 export interface HelpModalProps {
@@ -57,11 +62,10 @@ export interface HelpModalProps {
 
 export const HelpModal = ({ onDismiss }: HelpModalProps): JSX.Element => {
   const styles = useStyles2(getStyles);
+  const modKey = useMemo(() => getModKey(), []);
+  const shortcuts = useMemo(() => getShortcuts(modKey), [modKey]);
   return (
     <Modal title="Shortcuts" isOpen onDismiss={onDismiss} onClickBackdrop={onDismiss}>
-      <div className={styles.titleDescription}>
-        <span className={styles.shortcutTableKey}>mod</span> =<span> CTRL on windows or linux and CMD key on Mac</span>
-      </div>
       <div className={styles.categories}>
         {Object.entries(shortcuts).map(([category, shortcuts], i) => (
           <div className={styles.shortcutCategory} key={i}>
@@ -137,7 +141,12 @@ function getStyles(theme: GrafanaTheme2) {
       text-align: center;
       margin-right: ${theme.spacing(0.5)};
       padding: 3px 5px;
-      font: 11px Consolas, 'Liberation Mono', Menlo, Courier, monospace;
+      font:
+        11px Consolas,
+        'Liberation Mono',
+        Menlo,
+        Courier,
+        monospace;
       line-height: 10px;
       vertical-align: middle;
       border: solid 1px ${theme.colors.border.medium};
