@@ -7,7 +7,7 @@ import { connectWithProvider } from '../../utils/connectWithReduxStore';
 /**
  * Component that enables rendering React modals from Angular
  */
-export const AngularModalProxy = connectWithProvider((props: any) => {
+export const AngularModalProxy = connectWithProvider((props: Record<string, unknown>) => {
   return (
     <>
       <ModalsProvider {...props}>
