@@ -4,6 +4,8 @@ import { cloneDeep } from 'lodash';
 import { NavIndex, NavModel, NavModelItem } from '@grafana/data';
 import config from 'app/core/config';
 
+import { getNavSubTitle, getNavTitle } from '../components/AppChrome/MegaMenu/navBarItem-translations';
+
 export const HOME_NAV_ID = 'home';
 
 export function buildInitialState(): NavIndex {
@@ -16,22 +18,37 @@ export function buildInitialState(): NavIndex {
     buildNavIndex(navIndex, [homeNav]);
   }
   // set home as parent for the other rootNodes
-  buildNavIndex(navIndex, otherRootNodes, homeNav);
+  // need to use the translated home node from the navIndex
+  buildNavIndex(navIndex, otherRootNodes, navIndex[HOME_NAV_ID]);
 
   return navIndex;
 }
 
 function buildNavIndex(navIndex: NavIndex, children: NavModelItem[], parentItem?: NavModelItem) {
+  const translatedChildren: NavModelItem[] = [];
+
   for (const node of children) {
-    node.parentItem = parentItem;
+    const translatedNode: NavModelItem = {
+      ...node,
+      text: getNavTitle(node.id) ?? node.text,
+      subTitle: getNavSubTitle(node.id) ?? node.subTitle,
+      emptyMessage: getNavTitle(node.emptyMessageId),
+      parentItem: parentItem,
+    };
 
-    if (node.id) {
-      navIndex[node.id] = node;
+    if (translatedNode.id) {
+      navIndex[translatedNode.id] = translatedNode;
     }
 
-    if (node.children) {
-      buildNavIndex(navIndex, node.children, node);
+    if (translatedNode.children) {
+      buildNavIndex(navIndex, translatedNode.children, translatedNode);
     }
+    translatedChildren.push(translatedNode);
+  }
+
+  // need to update the parentItem children with the new translated children
+  if (parentItem) {
+    parentItem.children = translatedChildren;
   }
 
   navIndex['not-found'] = { ...buildWarningNav('Page not found', '404 Error').node };
@@ -75,12 +92,20 @@ export const navIndexReducer = (state: NavIndex = initialState, action: AnyActio
     const newPages: NavIndex = {};
     const payload = action.payload;
 
-    for (const node of payload.children!) {
-      newPages[node.id!] = {
-        ...node,
-        parentItem: payload,
-      };
+    function addNewPages(node: NavModelItem) {
+      if (node.children) {
+        for (const child of node.children) {
+          newPages[child.id!] = {
+            ...child,
+            parentItem: node,
+          };
+        }
+      }
+      if (node.parentItem) {
+        addNewPages(node.parentItem);
+      }
     }
+    addNewPages(payload);
 
     return { ...state, ...newPages };
   } else if (updateConfigurationSubtitle.match(action)) {
