@@ -1,6 +1,7 @@
-import { BackendSrvRequest } from '@grafana/runtime';
-import omitBy from 'lodash/omitBy';
+import { omitBy } from 'lodash';
+
 import { deprecationWarning } from '@grafana/data';
+import { BackendSrvRequest } from '@grafana/runtime';
 
 export const parseInitFromOptions = (options: BackendSrvRequest): RequestInit => {
   const method = options.method;
@@ -88,6 +89,9 @@ export const parseBody = (options: BackendSrvRequest, isAppJson: boolean) => {
   if (!options.data || typeof options.data === 'string') {
     return options.data;
   }
+  if (options.data instanceof Blob) {
+    return options.data;
+  }
 
   return isAppJson ? JSON.stringify(options.data) : new URLSearchParams(options.data);
 };
@@ -105,7 +109,14 @@ export async function parseResponseBody<T>(
         return response.blob() as any;
 
       case 'json':
-        return response.json();
+        // An empty string is not a valid JSON.
+        // Sometimes (unfortunately) our APIs declare their Content-Type as JSON, however they return an empty body.
+        if (response.headers.get('Content-Length') === '0') {
+          console.warn(`${response.url} returned an invalid JSON`);
+          return {} as unknown as T;
+        }
+
+        return await response.json();
 
       case 'text':
         return response.text() as any;
