@@ -1,7 +1,10 @@
 import memoizeOne from 'memoize-one';
+
 import { getBackendSrv, config } from '@grafana/runtime';
-import { AppEvents } from '@grafana/data';
-import appEvents from 'app/core/app_events';
+import { notifyApp } from 'app/core/actions';
+import { createErrorNotification, createSuccessNotification } from 'app/core/copy/appNotification';
+import { dispatch } from 'app/store/store';
+
 import { copyStringToClipboard } from './explore';
 
 function buildHostUrl() {
@@ -21,7 +24,7 @@ export const createShortLink = memoizeOne(async function (path: string) {
     return shortLink.url;
   } catch (err) {
     console.error('Error when creating shortened link: ', err);
-    appEvents.emit(AppEvents.alertError, ['Error generating shortened link']);
+    dispatch(notifyApp(createErrorNotification('Error generating shortened link')));
   }
 });
 
@@ -29,8 +32,8 @@ export const createAndCopyShortLink = async (path: string) => {
   const shortLink = await createShortLink(path);
   if (shortLink) {
     copyStringToClipboard(shortLink);
-    appEvents.emit(AppEvents.alertSuccess, ['Shortened link copied to clipboard']);
+    dispatch(notifyApp(createSuccessNotification('Shortened link copied to clipboard')));
   } else {
-    appEvents.emit(AppEvents.alertError, ['Error generating shortened link']);
+    dispatch(notifyApp(createErrorNotification('Error generating shortened link')));
   }
 };
