@@ -1,5 +1,5 @@
 import { css, cx } from '@emotion/css';
-import React, { FC, HTMLAttributes } from 'react';
+import React, { HTMLAttributes } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { IconSize, useStyles2, Button } from '@grafana/ui';
@@ -14,7 +14,7 @@ interface Props extends HTMLAttributes<HTMLButtonElement> {
   text?: string;
 }
 
-export const CollapseToggle: FC<Props> = ({
+export const CollapseToggle = ({
   isCollapsed,
   onToggle,
   idControlled,
@@ -22,7 +22,7 @@ export const CollapseToggle: FC<Props> = ({
   text,
   size = 'xl',
   ...restOfProps
-}) => {
+}: Props) => {
   const styles = useStyles2(getStyles);
 
   return (
