@@ -1,8 +1,9 @@
 import { css } from '@emotion/css';
 import pluralize from 'pluralize';
-import React, { FC, useEffect, useState } from 'react';
+import React, { useEffect, useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Stack } from '@grafana/experimental';
 import { logInfo } from '@grafana/runtime';
 import { Badge, ConfirmModal, HorizontalGroup, Icon, Spinner, Tooltip, useStyles2 } from '@grafana/ui';
 import { useDispatch } from 'app/types';
@@ -14,7 +15,7 @@ import { useHasRuler } from '../../hooks/useHasRuler';
 import { deleteRulesGroupAction } from '../../state/actions';
 import { useRulesAccess } from '../../utils/accessControlHooks';
 import { GRAFANA_RULES_SOURCE_NAME, isCloudRulesSource } from '../../utils/datasource';
-import { makeFolderLink } from '../../utils/misc';
+import { makeFolderLink, makeFolderSettingsLink } from '../../utils/misc';
 import { isFederatedRuleGroup, isGrafanaRulerRule } from '../../utils/rules';
 import { CollapseToggle } from '../CollapseToggle';
 import { RuleLocation } from '../RuleLocation';
@@ -22,7 +23,7 @@ import { RuleLocation } from '../RuleLocation';
 import { ActionIcon } from './ActionIcon';
 import { EditCloudGroupModal } from './EditRuleGroupModal';
 import { ReorderCloudGroupModal } from './ReorderRuleGroupModal';
-import { RuleStats } from './RuleStats';
+import { RuleGroupStats } from './RuleStats';
 import { RulesTable } from './RulesTable';
 
 type ViewMode = 'grouped' | 'list';
@@ -34,7 +35,7 @@ interface Props {
   viewMode: ViewMode;
 }
 
-export const RulesGroup: FC<Props> = React.memo(({ group, namespace, expandAll, viewMode }) => {
+export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }: Props) => {
   const { rulesSource } = namespace;
   const dispatch = useDispatch();
   const styles = useStyles2(getStyles);
@@ -208,24 +209,50 @@ export const RulesGroup: FC<Props> = React.memo(({ group, namespace, expandAll,
             />
           </Tooltip>
         )}
-        <h6 className={styles.heading}>
-          {isFederated && <Badge color="purple" text="Federated" />} {groupName}
-        </h6>
+        {
+          // eslint-disable-next-line
+          <div className={styles.groupName} onClick={() => setIsCollapsed(!isCollapsed)}>
+            {isFederated && <Badge color="purple" text="Federated" />} {groupName}
+          </div>
+        }
         <div className={styles.spacer} />
         <div className={styles.headerStats}>
-          <RuleStats showInactive={false} group={group} />
+          <RuleGroupStats group={group} />
         </div>
+        {isProvisioned && (
+          <>
+            <div className={styles.actionsSeparator}>|</div>
+            <div className={styles.actionIcons}>
+              <Badge color="purple" text="Provisioned" />
+            </div>
+          </>
+        )}
         {!!actionIcons.length && (
           <>
             <div className={styles.actionsSeparator}>|</div>
-            <div className={styles.actionIcons}>{actionIcons}</div>
+            <div className={styles.actionIcons}>
+              <Stack gap={0.5}>{actionIcons}</Stack>
+            </div>
           </>
         )}
       </div>
       {!isCollapsed && (
-        <RulesTable showSummaryColumn={true} className={styles.rulesTable} showGuidelines={true} rules={group.rules} />
+        <RulesTable
+          showSummaryColumn={true}
+          className={styles.rulesTable}
+          showGuidelines={true}
+          showNextEvaluationColumn={Boolean(group.interval)}
+          rules={group.rules}
+        />
+      )}
+      {isEditingGroup && (
+        <EditCloudGroupModal
+          namespace={namespace}
+          group={group}
+          onClose={() => closeEditModal()}
+          folderUrl={folder?.canEdit ? makeFolderSettingsLink(folder) : undefined}
+        />
       )}
-      {isEditingGroup && <EditCloudGroupModal group={group} namespace={namespace} onClose={() => closeEditModal()} />}
       {isReorderingGroup && (
         <ReorderCloudGroupModal group={group} namespace={namespace} onClose={() => setIsReorderingGroup(false)} />
       )}
@@ -234,11 +261,11 @@ export const RulesGroup: FC<Props> = React.memo(({ group, namespace, expandAll,
         title="Delete group"
         body={
           <div>
-            Deleting this group will permanently remove the group
-            <br />
-            and {group.rules.length} alert {pluralize('rule', group.rules.length)} belonging to it.
-            <br />
-            Are you sure you want to delete this group?
+            <p>
+              Deleting &quot;<strong>{group.name}</strong>&quot; will permanently remove the group and{' '}
+              {group.rules.length} alert {pluralize('rule', group.rules.length)} belonging to it.
+            </p>
+            <p>Are you sure you want to delete this group?</p>
           </div>
         }
         onConfirm={deleteGroup}
@@ -251,69 +278,78 @@ export const RulesGroup: FC<Props> = React.memo(({ group, namespace, expandAll,
 
 RulesGroup.displayName = 'RulesGroup';
 
-export const getStyles = (theme: GrafanaTheme2) => ({
-  wrapper: css`
-    & + & {
-      margin-top: ${theme.spacing(2)};
-    }
-  `,
-  header: css`
-    display: flex;
-    flex-direction: row;
-    align-items: center;
-    padding: ${theme.spacing(1)} ${theme.spacing(1)} ${theme.spacing(1)} 0;
-    background-color: ${theme.colors.background.secondary};
-    flex-wrap: wrap;
-  `,
-  headerStats: css`
-    span {
-      vertical-align: middle;
-    }
+export const getStyles = (theme: GrafanaTheme2) => {
+  return {
+    wrapper: css``,
+    header: css`
+      display: flex;
+      flex-direction: row;
+      align-items: center;
+      padding: ${theme.spacing(1)} ${theme.spacing(1)} ${theme.spacing(1)} 0;
+      flex-wrap: nowrap;
+      border-bottom: 1px solid ${theme.colors.border.weak};
+      &:hover {
+        background-color: ${theme.components.table.rowHoverBackground};
+      }
+    `,
+    headerStats: css`
+      flex-shrink: 0;
 
-    ${theme.breakpoints.down('sm')} {
-      order: 2;
-      width: 100%;
-      padding-left: ${theme.spacing(1)};
-    }
-  `,
-  heading: css`
-    margin-left: ${theme.spacing(1)};
-    margin-bottom: 0;
-  `,
-  spacer: css`
-    flex: 1;
-  `,
-  collapseToggle: css`
-    background: none;
-    border: none;
-    margin-top: -${theme.spacing(1)};
-    margin-bottom: -${theme.spacing(1)};
+      span {
+        vertical-align: middle;
+      }
 
-    svg {
+      ${theme.breakpoints.down('sm')} {
+        order: 2;
+        width: 100%;
+        padding-left: ${theme.spacing(1)};
+      }
+    `,
+    groupName: css`
+      margin-left: ${theme.spacing(1)};
       margin-bottom: 0;
-    }
-  `,
-  dataSourceIcon: css`
-    width: ${theme.spacing(2)};
-    height: ${theme.spacing(2)};
-    margin-left: ${theme.spacing(2)};
-  `,
-  dataSourceOrigin: css`
-    margin-right: 1em;
-    color: ${theme.colors.text.disabled};
-  `,
-  actionsSeparator: css`
-    margin: 0 ${theme.spacing(2)};
-  `,
-  actionIcons: css`
-    & > * + * {
-      margin-left: ${theme.spacing(0.5)};
-    }
-  `,
-  rulesTable: css`
-    margin-top: ${theme.spacing(3)};
-  `,
-  rotate90: css`
-    transform: rotate(90deg);
-  `,
-});
+      cursor: pointer;
+
+      white-space: nowrap;
+      overflow: hidden;
+      text-overflow: ellipsis;
+    `,
+    spacer: css`
+      flex: 1;
+    `,
+    collapseToggle: css`
+      background: none;
+      border: none;
+      margin-top: -${theme.spacing(1)};
+      margin-bottom: -${theme.spacing(1)};
+
+      svg {
+        margin-bottom: 0;
+      }
+    `,
+    dataSourceIcon: css`
+      width: ${theme.spacing(2)};
+      height: ${theme.spacing(2)};
+      margin-left: ${theme.spacing(2)};
+    `,
+    dataSourceOrigin: css`
+      margin-right: 1em;
+      color: ${theme.colors.text.disabled};
+    `,
+    actionsSeparator: css`
+      margin: 0 ${theme.spacing(2)};
+    `,
+    actionIcons: css`
+      width: 80px;
+      align-items: center;
+
+      flex-shrink: 0;
+    `,
+    rulesTable: css`
+      margin: ${theme.spacing(2, 0)};
+    `,
+    rotate90: css`
+      transform: rotate(90deg);
+    `,
+  };
+};
