@@ -1,4 +1,4 @@
-import React, { FC } from 'react';
+import React from 'react';
 
 import { SilenceState } from 'app/plugins/datasource/alertmanager/types';
 
@@ -14,6 +14,4 @@ interface Props {
   state: SilenceState;
 }
 
-export const SilenceStateTag: FC<Props> = ({ state }) => (
-  <StateTag state={silenceStateToState[state]}>{state}</StateTag>
-);
+export const SilenceStateTag = ({ state }: Props) => <StateTag state={silenceStateToState[state]}>{state}</StateTag>;
