@@ -1,36 +1,36 @@
 import { css, cx } from '@emotion/css';
-import { pickBy } from 'lodash';
-import React, { FC, useMemo, useState } from 'react';
-import { useForm, FormProvider } from 'react-hook-form';
+import { isEqual, pickBy } from 'lodash';
+import React, { useMemo, useState } from 'react';
+import { FormProvider, useForm } from 'react-hook-form';
 import { useDebounce } from 'react-use';
 
 import {
-  DefaultTimeZone,
-  parseDuration,
-  intervalToAbbreviatedDurationString,
   addDurationToDate,
   dateTime,
-  isValidDate,
+  DefaultTimeZone,
   GrafanaTheme2,
+  intervalToAbbreviatedDurationString,
+  isValidDate,
+  parseDuration,
 } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import { Button, Field, FieldSet, Input, LinkButton, TextArea, useStyles2 } from '@grafana/ui';
 import { useCleanup } from 'app/core/hooks/useCleanup';
-import { MatcherOperator, Silence, SilenceCreatePayload } from 'app/plugins/datasource/alertmanager/types';
+import { Matcher, MatcherOperator, Silence, SilenceCreatePayload } from 'app/plugins/datasource/alertmanager/types';
 import { useDispatch } from 'app/types';
 
 import { useURLSearchParams } from '../../hooks/useURLSearchParams';
 import { useUnifiedAlertingSelector } from '../../hooks/useUnifiedAlertingSelector';
 import { createOrUpdateSilenceAction } from '../../state/actions';
 import { SilenceFormFields } from '../../types/silence-form';
-import { matcherToMatcherField, matcherFieldToMatcher } from '../../utils/alertmanager';
+import { matcherFieldToMatcher, matcherToMatcherField } from '../../utils/alertmanager';
 import { parseQueryParamMatchers } from '../../utils/matchers';
 import { makeAMLink } from '../../utils/misc';
 import { initialAsyncRequestState } from '../../utils/redux';
 
-import { MatchedSilencedRules } from './MatchedSilencedRules';
 import MatchersField from './MatchersField';
 import { SilencePeriod } from './SilencePeriod';
+import { SilencedInstancesPreview } from './SilencedInstancesPreview';
 
 interface Props {
   silence?: Silence;
@@ -97,13 +97,16 @@ const getDefaultFormValues = (searchParams: URLSearchParams, silence?: Silence):
   }
 };
 
-export const SilencesEditor: FC<Props> = ({ silence, alertManagerSourceName }) => {
+export const SilencesEditor = ({ silence, alertManagerSourceName }: Props) => {
   const [urlSearchParams] = useURLSearchParams();
 
   const defaultValues = useMemo(() => getDefaultFormValues(urlSearchParams, silence), [silence, urlSearchParams]);
   const formAPI = useForm({ defaultValues });
   const dispatch = useDispatch();
   const styles = useStyles2(getStyles);
+  const [matchersForPreview, setMatchersForPreview] = useState<Matcher[]>(
+    defaultValues.matchers.map(matcherFieldToMatcher)
+  );
 
   const { loading } = useUnifiedAlertingSelector((state) => state.updateSilence);
 
@@ -138,6 +141,7 @@ export const SilencesEditor: FC<Props> = ({ silence, alertManagerSourceName }) =
   const duration = watch('duration');
   const startsAt = watch('startsAt');
   const endsAt = watch('endsAt');
+  const matcherFields = watch('matchers');
 
   // Keep duration and endsAt in sync
   const [prevDuration, setPrevDuration] = useState(duration);
@@ -164,6 +168,19 @@ export const SilencesEditor: FC<Props> = ({ silence, alertManagerSourceName }) =
     700,
     [clearErrors, duration, endsAt, prevDuration, setValue, startsAt]
   );
+
+  useDebounce(
+    () => {
+      // React-hook-form watch does not return referentialy equal values so this trick is needed
+      const newMatchers = matcherFields.filter((m) => m.name && m.value).map(matcherFieldToMatcher);
+      if (!isEqual(matchersForPreview, newMatchers)) {
+        setMatchersForPreview(newMatchers);
+      }
+    },
+    700,
+    [matcherFields]
+  );
+
   const userLogged = Boolean(config.bootData.user.isSignedIn && config.bootData.user.name);
 
   return (
@@ -221,7 +238,7 @@ export const SilencesEditor: FC<Props> = ({ silence, alertManagerSourceName }) =
               />
             </Field>
           )}
-          <MatchedSilencedRules />
+          <SilencedInstancesPreview amSourceName={alertManagerSourceName} matchers={matchersForPreview} />
         </FieldSet>
         <div className={styles.flexRow}>
           {loading && (
@@ -229,12 +246,8 @@ export const SilencesEditor: FC<Props> = ({ silence, alertManagerSourceName }) =
               Saving...
             </Button>
           )}
-          {!loading && <Button type="submit">Submit</Button>}
-          <LinkButton
-            href={makeAMLink('alerting/silences', alertManagerSourceName)}
-            variant={'secondary'}
-            fill="outline"
-          >
+          {!loading && <Button type="submit">Save silence</Button>}
+          <LinkButton href={makeAMLink('alerting/silences', alertManagerSourceName)} variant={'secondary'}>
             Cancel
           </LinkButton>
         </div>
