@@ -1,54 +1,14 @@
-import { ColorDimensionConfig, ResourceDimensionConfig, TextDimensionConfig } from 'app/features/dimensions/types';
-
-export interface Placement {
-  top?: number;
-  left?: number;
-  right?: number;
-  bottom?: number;
-
-  width?: number;
-  height?: number;
-}
-
-export interface Constraint {
-  horizontal?: HorizontalConstraint;
-  vertical?: VerticalConstraint;
-}
-
-export enum HorizontalConstraint {
-  Left = 'left',
-  Right = 'right',
-  LeftRight = 'leftright',
-  Center = 'center',
-  Scale = 'scale',
-}
-
-export enum VerticalConstraint {
-  Top = 'top',
-  Bottom = 'bottom',
-  TopBottom = 'topbottom',
-  Center = 'center',
-  Scale = 'scale',
-}
-
-export enum BackgroundImageSize {
-  Original = 'original',
-  Contain = 'contain',
-  Cover = 'cover',
-  Fill = 'fill',
-  Tile = 'tile',
-}
-
-export interface BackgroundConfig {
-  color?: ColorDimensionConfig;
-  image?: ResourceDimensionConfig;
-  size?: BackgroundImageSize;
-}
-
-export interface LineConfig {
-  color?: ColorDimensionConfig;
-  width?: number;
-}
+import { LinkModel } from '@grafana/data/src';
+import { ColorDimensionConfig, TextDimensionConfig } from '@grafana/schema';
+import {
+  BackgroundImageSize,
+  Constraint,
+  HorizontalConstraint,
+  Placement,
+  VerticalConstraint,
+  LineConfig,
+  BackgroundConfig,
+} from 'app/plugins/panel/canvas/panelcfg.gen';
 
 export enum QuickPlacement {
   Top = 'top',
@@ -77,6 +37,7 @@ export interface TextData {
   size?: number; // 0 or missing will "auto size"
   align: Align;
   valign: VAlign;
+  links?: LinkModel[];
 }
 
 export interface TextConfig {
@@ -86,3 +47,13 @@ export interface TextConfig {
   align: Align;
   valign: VAlign;
 }
+
+export {
+  Placement,
+  Constraint,
+  HorizontalConstraint,
+  VerticalConstraint,
+  BackgroundImageSize,
+  LineConfig,
+  BackgroundConfig,
+};
