@@ -1,10 +1,9 @@
-import { NavIndex, NavSection } from '@grafana/data';
+import { NavIndex } from '@grafana/data';
 
 export const navIndex: NavIndex = {
   home: {
     id: 'home',
     text: 'Home',
-    section: NavSection.Core,
     icon: 'home-alt',
     url: '/',
     sortWeight: -2000,
@@ -12,14 +11,12 @@ export const navIndex: NavIndex = {
   starred: {
     id: 'starred',
     text: 'Starred',
-    section: NavSection.Core,
     icon: 'star',
     sortWeight: -1900,
     emptyMessageId: 'starred-empty',
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -28,7 +25,6 @@ export const navIndex: NavIndex = {
   'dashboards/browse': {
     id: 'dashboards/browse',
     text: 'Dashboards',
-    section: NavSection.Core,
     subTitle: 'Create and manage dashboards to visualize your data',
     icon: 'apps',
     url: '/dashboards',
@@ -59,7 +55,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -99,7 +94,6 @@ export const navIndex: NavIndex = {
   explore: {
     id: 'explore',
     text: 'Explore',
-    section: NavSection.Core,
     subTitle: 'Explore your data',
     icon: 'compass',
     url: '/explore',
@@ -107,7 +101,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -116,7 +109,6 @@ export const navIndex: NavIndex = {
   alerting: {
     id: 'alerting',
     text: 'Alerting',
-    section: NavSection.Core,
     subTitle: 'Learn about problems in your systems moments after they occur',
     icon: 'bell',
     url: '/alerting',
@@ -132,7 +124,7 @@ export const navIndex: NavIndex = {
       {
         id: 'receivers',
         text: 'Contact points',
-        subTitle: 'Decide how your contacts are notified when an alert fires',
+        subTitle: 'Choose how to notify your  contact points when an alert instance fires',
         icon: 'comment-alt-share',
         url: '/alerting/notifications',
       },
@@ -163,26 +155,18 @@ export const navIndex: NavIndex = {
         icon: 'cog',
         url: '/alerting/admin',
       },
-      {
-        id: 'divider',
-        text: 'Divider',
-        divider: true,
-        hideFromTabs: true,
-      },
       {
         id: 'alert',
-        text: 'New alert rule',
+        text: 'Create alert rule',
         subTitle: 'Create an alert rule',
         icon: 'plus',
         url: '/alerting/new',
         hideFromTabs: true,
-        showIconInNavbar: true,
       },
     ],
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -198,7 +182,7 @@ export const navIndex: NavIndex = {
   receivers: {
     id: 'receivers',
     text: 'Contact points',
-    subTitle: 'Decide how your contacts are notified when an alert fires',
+    subTitle: 'Choose how to notify your  contact points when an alert instance fires',
     icon: 'comment-alt-share',
     url: '/alerting/notifications',
   },
@@ -231,99 +215,67 @@ export const navIndex: NavIndex = {
   },
   alert: {
     id: 'alert',
-    text: 'New alert rule',
+    text: 'Create alert rule',
     subTitle: 'Create an alert rule',
     icon: 'plus',
     url: '/alerting/new',
     hideFromTabs: true,
-    showIconInNavbar: true,
   },
   connections: {
     id: 'connections',
     text: 'Connections',
-    section: NavSection.Core,
     icon: 'link',
     url: '/connections',
     sortWeight: -1300,
     children: [
       {
-        id: 'connections-your-connections',
-        text: 'Your connections',
-        subTitle: 'Manage your existing connections',
-        url: '/connections/your-connections',
-        children: [
-          {
-            id: 'connections-your-connections-datasources',
-            text: 'Datasources',
-            subTitle: 'Manage your existing datasource connections',
-            url: '/connections/your-connections/datasources',
-          },
-          {
-            id: 'standalone-plugin-page-/connections/your-connections/infrastructure',
-            text: 'Infrastructure',
-            url: '/connections/your-connections/infrastructure',
-            pluginId: 'grafana-easystart-app',
-          },
-        ],
+        id: 'connections-add-new-connection',
+        text: 'Add new connection',
+        subTitle: 'Browse and create new connections',
+        url: '/connections/add-new-connection',
       },
       {
-        id: 'connections-connect-data',
-        text: 'Connect data',
-        subTitle: 'Browse and create new connections',
-        url: '/connections/connect-data',
+        id: 'connections-datasources',
+        text: 'Data sources',
+        subTitle: 'Manage your existing datasource connections',
+        url: '/connections/datasources',
+      },
+      {
+        id: 'standalone-plugin-page-/connections/infrastructure',
+        text: 'Infrastructure',
+        url: '/connections/infrastructure',
+        pluginId: 'grafana-easystart-app',
       },
     ],
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
     },
   },
-  'connections-your-connections': {
-    id: 'connections-your-connections',
-    text: 'Your connections',
-    subTitle: 'Manage your existing connections',
-    url: '/connections/your-connections',
-    children: [
-      {
-        id: 'connections-your-connections-datasources',
-        text: 'Datasources',
-        subTitle: 'Manage your existing datasource connections',
-        url: '/connections/your-connections/datasources',
-      },
-      {
-        id: 'standalone-plugin-page-/connections/your-connections/infrastructure',
-        text: 'Infrastructure',
-        url: '/connections/your-connections/infrastructure',
-        pluginId: 'grafana-easystart-app',
-      },
-    ],
-  },
-  'connections-your-connections-datasources': {
-    id: 'connections-your-connections-datasources',
-    text: 'Datasources',
+  'connections-datasources': {
+    id: 'connections-datasources',
+    text: 'Data sources',
     subTitle: 'Manage your existing datasource connections',
-    url: '/connections/your-connections/datasources',
+    url: '/connections/datasources',
   },
-  'standalone-plugin-page-/connections/your-connections/infrastructure': {
-    id: 'standalone-plugin-page-/connections/your-connections/infrastructure',
+  'standalone-plugin-page-/connections/infrastructure': {
+    id: 'standalone-plugin-page-/connections/infrastructure',
     text: 'Infrastructure',
-    url: '/connections/your-connections/infrastructure',
+    url: '/connections/infrastructure',
     pluginId: 'grafana-easystart-app',
   },
-  'connections-connect-data': {
-    id: 'connections-connect-data',
-    text: 'Connect data',
+  'connections-add-new-connection': {
+    id: 'connections-add-new-connection',
+    text: 'Add new connection',
     subTitle: 'Browse and create new connections',
-    url: '/connections/connect-data',
+    url: '/connections/add-new-connection',
   },
   cfg: {
     id: 'cfg',
     text: 'Administration',
-    section: NavSection.Config,
     subTitle: 'Organization: Main Org. 123',
     icon: 'cog',
     url: '/admin',
@@ -381,7 +333,6 @@ export const navIndex: NavIndex = {
       {
         id: 'admin',
         text: 'Server admin',
-        section: NavSection.Config,
         subTitle: 'Manage server-wide settings and access to resources such as organizations, users, and licenses',
         icon: 'shield',
         url: '/admin/server',
@@ -419,7 +370,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -477,7 +427,6 @@ export const navIndex: NavIndex = {
   admin: {
     id: 'admin',
     text: 'Server admin',
-    section: NavSection.Config,
     subTitle: 'Manage server-wide settings and access to resources such as organizations, users, and licenses',
     icon: 'shield',
     url: '/admin/server',
@@ -540,8 +489,7 @@ export const navIndex: NavIndex = {
   },
   monitoring: {
     id: 'monitoring',
-    text: 'Monitoring',
-    section: NavSection.Core,
+    text: 'Observability',
     subTitle: 'Monitoring and infrastructure apps',
     icon: 'heart-rate',
     url: '/monitoring',
@@ -550,7 +498,6 @@ export const navIndex: NavIndex = {
       {
         id: 'plugin-page-grafana-synthetic-monitoring-app',
         text: 'Synthetic Monitoring',
-        section: NavSection.Plugin,
         img: 'public/plugins/grafana-synthetic-monitoring-app/img/logo.svg',
         url: '/a/grafana-synthetic-monitoring-app/home',
         sortWeight: 2,
@@ -588,7 +535,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -597,7 +543,6 @@ export const navIndex: NavIndex = {
   'plugin-page-grafana-synthetic-monitoring-app': {
     id: 'plugin-page-grafana-synthetic-monitoring-app',
     text: 'Synthetic Monitoring',
-    section: NavSection.Plugin,
     img: 'public/plugins/grafana-synthetic-monitoring-app/img/logo.svg',
     url: '/a/grafana-synthetic-monitoring-app/home',
     sortWeight: 2,
@@ -639,7 +584,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'plugin-page-redis-explorer-app',
       text: 'Redis Explorer',
-      section: NavSection.Plugin,
       img: 'public/plugins/redis-explorer-app/img/logo.svg',
       url: '/a/redis-explorer-app/',
       sortWeight: -1200,
@@ -674,7 +618,6 @@ export const navIndex: NavIndex = {
       parentItem: {
         id: 'apps',
         text: 'Apps',
-        section: NavSection.Core,
         subTitle: 'App plugins that extend the Grafana experience',
         icon: 'apps',
         url: '/apps',
@@ -683,7 +626,6 @@ export const navIndex: NavIndex = {
           {
             id: 'plugin-page-cloudflare-app',
             text: 'Cloudflare Grafana App',
-            section: NavSection.Plugin,
             img: 'public/plugins/cloudflare-app/img/cf_icon.png',
             url: '/a/cloudflare-app',
             sortWeight: -1200,
@@ -705,7 +647,6 @@ export const navIndex: NavIndex = {
           {
             id: 'plugin-page-grafana-easystart-app',
             text: 'Integrations and Connections',
-            section: NavSection.Plugin,
             img: 'public/plugins/grafana-easystart-app/img/logo.svg',
             url: '/a/grafana-easystart-app',
             sortWeight: -1200,
@@ -722,7 +663,6 @@ export const navIndex: NavIndex = {
           {
             id: 'plugin-page-grafana-k6-app',
             text: 'k6 Cloud App',
-            section: NavSection.Plugin,
             img: 'public/plugins/grafana-k6-app/img/logo.svg',
             url: '/a/grafana-k6-app',
             sortWeight: -1200,
@@ -732,7 +672,6 @@ export const navIndex: NavIndex = {
           {
             id: 'plugin-page-myorg-app-basic',
             text: 'Basic App',
-            section: NavSection.Plugin,
             img: 'public/plugins/myorg-app-basic/img/logo.svg',
             url: '/a/myorg-app-basic/one',
             sortWeight: -1200,
@@ -766,7 +705,6 @@ export const navIndex: NavIndex = {
         parentItem: {
           id: 'home',
           text: 'Home',
-          section: NavSection.Core,
           icon: 'home-alt',
           url: '/',
           sortWeight: -2000,
@@ -777,7 +715,6 @@ export const navIndex: NavIndex = {
   apps: {
     id: 'apps',
     text: 'Apps',
-    section: NavSection.Core,
     subTitle: 'App plugins that extend the Grafana experience',
     icon: 'apps',
     url: '/apps',
@@ -786,7 +723,6 @@ export const navIndex: NavIndex = {
       {
         id: 'plugin-page-cloudflare-app',
         text: 'Cloudflare Grafana App',
-        section: NavSection.Plugin,
         img: 'public/plugins/cloudflare-app/img/cf_icon.png',
         url: '/a/cloudflare-app',
         sortWeight: -1200,
@@ -808,7 +744,6 @@ export const navIndex: NavIndex = {
       {
         id: 'plugin-page-grafana-easystart-app',
         text: 'Integrations and Connections',
-        section: NavSection.Plugin,
         img: 'public/plugins/grafana-easystart-app/img/logo.svg',
         url: '/a/grafana-easystart-app',
         sortWeight: -1200,
@@ -825,7 +760,6 @@ export const navIndex: NavIndex = {
       {
         id: 'plugin-page-grafana-k6-app',
         text: 'k6 Cloud App',
-        section: NavSection.Plugin,
         img: 'public/plugins/grafana-k6-app/img/logo.svg',
         url: '/a/grafana-k6-app',
         sortWeight: -1200,
@@ -835,7 +769,6 @@ export const navIndex: NavIndex = {
       {
         id: 'plugin-page-myorg-app-basic',
         text: 'Basic App',
-        section: NavSection.Plugin,
         img: 'public/plugins/myorg-app-basic/img/logo.svg',
         url: '/a/myorg-app-basic/one',
         sortWeight: -1200,
@@ -869,7 +802,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -878,7 +810,6 @@ export const navIndex: NavIndex = {
   'plugin-page-cloudflare-app': {
     id: 'plugin-page-cloudflare-app',
     text: 'Cloudflare Grafana App',
-    section: NavSection.Plugin,
     img: 'public/plugins/cloudflare-app/img/cf_icon.png',
     url: '/a/cloudflare-app',
     sortWeight: -1200,
@@ -900,7 +831,6 @@ export const navIndex: NavIndex = {
   'plugin-page-grafana-easystart-app': {
     id: 'plugin-page-grafana-easystart-app',
     text: 'Integrations and Connections',
-    section: NavSection.Plugin,
     img: 'public/plugins/grafana-easystart-app/img/logo.svg',
     url: '/a/grafana-easystart-app',
     sortWeight: -1200,
@@ -917,7 +847,6 @@ export const navIndex: NavIndex = {
   'plugin-page-grafana-k6-app': {
     id: 'plugin-page-grafana-k6-app',
     text: 'k6 Cloud App',
-    section: NavSection.Plugin,
     img: 'public/plugins/grafana-k6-app/img/logo.svg',
     url: '/a/grafana-k6-app',
     sortWeight: -1200,
@@ -927,7 +856,6 @@ export const navIndex: NavIndex = {
   'plugin-page-myorg-app-basic': {
     id: 'plugin-page-myorg-app-basic',
     text: 'Basic App',
-    section: NavSection.Plugin,
     img: 'public/plugins/myorg-app-basic/img/logo.svg',
     url: '/a/myorg-app-basic/one',
     sortWeight: -1200,
@@ -960,7 +888,6 @@ export const navIndex: NavIndex = {
   'plugin-page-redis-explorer-app': {
     id: 'plugin-page-redis-explorer-app',
     text: 'Redis Explorer',
-    section: NavSection.Plugin,
     img: 'public/plugins/redis-explorer-app/img/logo.svg',
     url: '/a/redis-explorer-app/',
     sortWeight: -1200,
@@ -995,7 +922,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'apps',
       text: 'Apps',
-      section: NavSection.Core,
       subTitle: 'App plugins that extend the Grafana experience',
       icon: 'apps',
       url: '/apps',
@@ -1004,7 +930,6 @@ export const navIndex: NavIndex = {
         {
           id: 'plugin-page-cloudflare-app',
           text: 'Cloudflare Grafana App',
-          section: NavSection.Plugin,
           img: 'public/plugins/cloudflare-app/img/cf_icon.png',
           url: '/a/cloudflare-app',
           sortWeight: -1200,
@@ -1026,7 +951,6 @@ export const navIndex: NavIndex = {
         {
           id: 'plugin-page-grafana-easystart-app',
           text: 'Integrations and Connections',
-          section: NavSection.Plugin,
           img: 'public/plugins/grafana-easystart-app/img/logo.svg',
           url: '/a/grafana-easystart-app',
           sortWeight: -1200,
@@ -1043,7 +967,6 @@ export const navIndex: NavIndex = {
         {
           id: 'plugin-page-grafana-k6-app',
           text: 'k6 Cloud App',
-          section: NavSection.Plugin,
           img: 'public/plugins/grafana-k6-app/img/logo.svg',
           url: '/a/grafana-k6-app',
           sortWeight: -1200,
@@ -1053,7 +976,6 @@ export const navIndex: NavIndex = {
         {
           id: 'plugin-page-myorg-app-basic',
           text: 'Basic App',
-          section: NavSection.Plugin,
           img: 'public/plugins/myorg-app-basic/img/logo.svg',
           url: '/a/myorg-app-basic/one',
           sortWeight: -1200,
@@ -1087,7 +1009,6 @@ export const navIndex: NavIndex = {
       parentItem: {
         id: 'home',
         text: 'Home',
-        section: NavSection.Core,
         icon: 'home-alt',
         url: '/',
         sortWeight: -2000,
@@ -1097,7 +1018,6 @@ export const navIndex: NavIndex = {
   profile: {
     id: 'profile',
     text: 'admin',
-    section: NavSection.Config,
     img: '/avatar/46d229b033af06a191ff2267bca9ae56',
     url: '/profile',
     sortWeight: -600,
@@ -1133,7 +1053,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
@@ -1168,7 +1087,6 @@ export const navIndex: NavIndex = {
   help: {
     id: 'help',
     text: 'Help',
-    section: NavSection.Config,
     subTitle: 'Grafana v9.4.0-pre (8f5dc47e87)',
     icon: 'question-circle',
     url: '#',
@@ -1176,7 +1094,6 @@ export const navIndex: NavIndex = {
     parentItem: {
       id: 'home',
       text: 'Home',
-      section: NavSection.Core,
       icon: 'home-alt',
       url: '/',
       sortWeight: -2000,
