@@ -1,59 +1,30 @@
-import { render, waitFor, screen, fireEvent, waitForElementToBeRemoved, within, Matcher } from '@testing-library/react';
+import { render, waitFor, screen, fireEvent, within, Matcher, getByRole } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
 import { merge, uniqueId } from 'lodash';
 import React from 'react';
-import { DeepPartial } from 'react-hook-form';
-import { Provider } from 'react-redux';
+import { openMenu } from 'react-select-event';
 import { Observable } from 'rxjs';
+import { TestProvider } from 'test/helpers/TestProvider';
 import { MockDataSourceApi } from 'test/mocks/datasource_srv';
 import { getGrafanaContextMock } from 'test/mocks/getGrafanaContextMock';
 
-import { DataSourcePluginMeta } from '@grafana/data';
-import {
-  BackendSrv,
-  FetchError,
-  FetchResponse,
-  setDataSourceSrv,
-  BackendSrvRequest,
-  reportInteraction,
-} from '@grafana/runtime';
-import { GrafanaContext } from 'app/core/context/GrafanaContext';
+import { DataSourcePluginMeta, SupportedTransformationType } from '@grafana/data';
+import { BackendSrv, setDataSourceSrv, BackendSrvRequest, reportInteraction } from '@grafana/runtime';
 import { contextSrv } from 'app/core/services/context_srv';
 import { configureStore } from 'app/store/configureStore';
 
 import { mockDataSource, MockDataSourceSrv } from '../alerting/unified/mocks';
 
 import CorrelationsPage from './CorrelationsPage';
+import {
+  createCreateCorrelationResponse,
+  createFetchCorrelationsError,
+  createFetchCorrelationsResponse,
+  createRemoveCorrelationResponse,
+  createUpdateCorrelationResponse,
+} from './__mocks__/useCorrelations.mocks';
 import { Correlation, CreateCorrelationParams } from './types';
 
-function createFetchResponse<T>(overrides?: DeepPartial<FetchResponse>): FetchResponse<T> {
-  return merge(
-    {
-      data: undefined,
-      status: 200,
-      url: '',
-      config: { url: '' },
-      type: 'basic',
-      statusText: 'Ok',
-      redirected: false,
-      headers: {} as unknown as Headers,
-      ok: true,
-    },
-    overrides
-  );
-}
-
-function createFetchError(overrides?: DeepPartial<FetchError>): FetchError {
-  return merge(
-    createFetchResponse(),
-    {
-      status: 500,
-      statusText: 'Internal Server Error',
-      ok: false,
-    },
-    overrides
-  );
-}
-
 const renderWithContext = async (
   datasources: ConstructorParameters<typeof MockDataSourceSrv>[0] = {},
   correlations: Correlation[] = []
@@ -67,19 +38,10 @@ const renderWithContext = async (
       if (matches?.groups) {
         const { dsUid, correlationUid } = matches.groups;
         correlations = correlations.filter((c) => c.uid !== correlationUid || c.sourceUID !== dsUid);
-        return createFetchResponse({
-          data: {
-            message: 'Correlation deleted',
-          },
-        });
+        return createRemoveCorrelationResponse();
       }
 
-      throw createFetchError({
-        data: {
-          message: 'Correlation not found',
-        },
-        status: 404,
-      });
+      throw createFetchCorrelationsError();
     },
     post: async (url: string, data: Omit<CreateCorrelationParams, 'sourceUID'>) => {
       const matches = url.match(/^\/api\/datasources\/uid\/(?<sourceUID>[a-zA-Z0-9]+)\/correlations$/);
@@ -87,15 +49,10 @@ const renderWithContext = async (
         const { sourceUID } = matches.groups;
         const correlation = { sourceUID, ...data, uid: uniqueId() };
         correlations.push(correlation);
-        return correlation;
+        return createCreateCorrelationResponse(correlation);
       }
 
-      throw createFetchError({
-        status: 404,
-        data: {
-          message: 'Source datasource not found',
-        },
-      });
+      throw createFetchCorrelationsError();
     },
     patch: async (url: string, data: Omit<CreateCorrelationParams, 'sourceUID'>) => {
       const matches = url.match(
@@ -109,20 +66,21 @@ const renderWithContext = async (
           }
           return c;
         });
-        return createFetchResponse({
-          data: { sourceUID, ...data },
-        });
+        return createUpdateCorrelationResponse({ sourceUID, ...data, uid: uniqueId() });
       }
 
-      throw createFetchError({
-        data: { message: 'either correlation uid or source id not found' },
-        status: 404,
-      });
+      throw createFetchCorrelationsError();
     },
     fetch: (options: BackendSrvRequest) => {
       return new Observable((s) => {
-        s.next(merge(createFetchResponse({ url: options.url, data: correlations })));
-
+        s.next(
+          merge(
+            createFetchCorrelationsResponse({
+              url: options.url,
+              data: { correlations, page: 1, limit: 5, totalCount: 0 },
+            })
+          )
+        );
         s.complete();
       });
     },
@@ -141,11 +99,9 @@ const renderWithContext = async (
   setDataSourceSrv(dsServer);
 
   const renderResult = render(
-    <Provider store={configureStore({})}>
-      <GrafanaContext.Provider value={grafanaContext}>
-        <CorrelationsPage />
-      </GrafanaContext.Provider>
-    </Provider>,
+    <TestProvider store={configureStore({})} grafanaContext={grafanaContext}>
+      <CorrelationsPage />
+    </TestProvider>,
     {
       queries: {
         /**
@@ -225,12 +181,16 @@ const mocks = {
   reportInteraction: jest.fn(),
 };
 
-jest.mock('@grafana/runtime', () => ({
-  ...jest.requireActual('@grafana/runtime'),
-  reportInteraction: (...args: Parameters<typeof reportInteraction>) => {
-    mocks.reportInteraction(...args);
-  },
-}));
+jest.mock('@grafana/runtime', () => {
+  const runtime = jest.requireActual('@grafana/runtime');
+
+  return {
+    ...runtime,
+    reportInteraction: (...args: Parameters<typeof reportInteraction>) => {
+      mocks.reportInteraction(...args);
+    },
+  };
+});
 
 beforeAll(() => {
   mocks.contextSrv.hasPermission.mockImplementation(() => true);
@@ -273,9 +233,12 @@ describe('CorrelationsPage', () => {
       mocks.reportInteraction.mockClear();
     });
 
-    it('shows CTA', async () => {
+    it('shows the first page of the wizard', async () => {
+      const CTAButton = await screen.findByRole('button', { name: /add correlation/i });
+      expect(CTAButton).toBeInTheDocument();
+
       // insert form should not be present
-      expect(screen.queryByRole('button', { name: /add$/i })).not.toBeInTheDocument();
+      expect(screen.queryByRole('button', { name: /next$/i })).not.toBeInTheDocument();
 
       // "add new" button is the button on the top of the page, not visible when the CTA is rendered
       expect(screen.queryByRole('button', { name: /add new$/i })).not.toBeInTheDocument();
@@ -283,51 +246,56 @@ describe('CorrelationsPage', () => {
       // there's no table in the page
       expect(screen.queryByRole('table')).not.toBeInTheDocument();
 
-      const CTAButton = screen.getByRole('button', { name: /add correlation/i });
-      expect(CTAButton).toBeInTheDocument();
+      await userEvent.click(CTAButton);
 
-      fireEvent.click(CTAButton);
-
-      // wait for the form to be rendered and query editor to be mounted
-      await waitForElementToBeRemoved(() => screen.queryByText(/loading query editor/i));
-
-      // form's submit button
-      expect(screen.getByRole('button', { name: /add$/i })).toBeInTheDocument();
+      // form's next button
+      expect(await screen.findByRole('button', { name: /next$/i })).toBeInTheDocument();
     });
 
-    it('correctly adds correlations', async () => {
-      const CTAButton = screen.getByRole('button', { name: /add correlation/i });
+    it('correctly adds first correlation', async () => {
+      const CTAButton = await screen.findByRole('button', { name: /add correlation/i });
       expect(CTAButton).toBeInTheDocument();
 
       // there's no table in the page, as we are adding the first correlation
       expect(screen.queryByRole('table')).not.toBeInTheDocument();
 
-      fireEvent.click(CTAButton);
+      await userEvent.click(CTAButton);
 
-      fireEvent.change(screen.getByRole('textbox', { name: /label/i }), { target: { value: 'A Label' } });
-      fireEvent.change(screen.getByRole('textbox', { name: /description/i }), { target: { value: 'A Description' } });
-
-      // set source datasource picker value
-      fireEvent.keyDown(screen.getByLabelText(/^source$/i), { keyCode: 40 });
-      fireEvent.click(screen.getByText('loki'));
+      // step 1: label and description
+      await userEvent.clear(screen.getByRole('textbox', { name: /label/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /label/i }), 'A Label');
+      await userEvent.clear(screen.getByRole('textbox', { name: /description/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /description/i }), 'A Description');
+      await userEvent.click(await screen.findByRole('button', { name: /next$/i }));
 
+      // step 2:
       // set target datasource picker value
-      fireEvent.keyDown(screen.getByLabelText(/^target$/i), { keyCode: 40 });
-      fireEvent.click(screen.getByText('prometheus'));
+      fireEvent.keyDown(screen.getByLabelText(/^target/i), { keyCode: 40 });
+      await userEvent.click(screen.getByText('prometheus'));
+      await userEvent.click(await screen.findByRole('button', { name: /next$/i }));
 
-      fireEvent.change(screen.getByRole('textbox', { name: /target field/i }), { target: { value: 'Line' } });
+      // step 3:
+      // set source datasource picker value
+      fireEvent.keyDown(screen.getByLabelText(/^source/i), { keyCode: 40 });
+      await userEvent.click(screen.getByText('loki'));
+      await userEvent.click(await screen.findByRole('button', { name: /add$/i }));
 
-      await waitForElementToBeRemoved(() => screen.queryByText(/loading query editor/i));
+      await userEvent.clear(screen.getByRole('textbox', { name: /results field/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /results field/i }), 'Line');
 
-      fireEvent.click(screen.getByRole('button', { name: /add$/i }));
+      // add transformation
+      await userEvent.click(screen.getByRole('button', { name: /add transformation/i }));
+      const typeFilterSelect = screen.getAllByLabelText('Type');
+      openMenu(typeFilterSelect[0]);
+      await userEvent.click(screen.getByText('Regular expression'));
+      await userEvent.type(screen.getByLabelText(/expression/i), 'test expression');
 
-      // Waits for the form to be removed, meaning the correlation got successfully saved
-      await waitForElementToBeRemoved(() => screen.queryByRole('button', { name: /add$/i }));
+      await userEvent.click(await screen.findByRole('button', { name: /add$/i }));
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_added');
 
       // the table showing correlations should have appeared
-      expect(screen.getByRole('table')).toBeInTheDocument();
+      expect(await screen.findByRole('table')).toBeInTheDocument();
     });
   });
 
@@ -390,7 +358,14 @@ describe('CorrelationsPage', () => {
             targetUID: 'loki',
             uid: '1',
             label: 'Some label',
-            config: { field: 'line', target: {}, type: 'query' },
+            config: {
+              field: 'line',
+              target: {},
+              type: 'query',
+              transformations: [
+                { type: SupportedTransformationType.Regex, expression: 'url=http[s]?://(S*)', mapValue: 'path' },
+              ],
+            },
           },
           {
             sourceUID: 'prometheus',
@@ -407,12 +382,15 @@ describe('CorrelationsPage', () => {
     });
 
     it('shows a table with correlations', async () => {
-      expect(screen.getByRole('table')).toBeInTheDocument();
+      expect(await screen.findByRole('table')).toBeInTheDocument();
     });
 
     it('correctly sorts by source', async () => {
-      const sourceHeader = getHeaderByName('Source');
-      fireEvent.click(sourceHeader);
+      // wait for table to appear
+      await screen.findByRole('table');
+
+      const sourceHeader = getByRole(getHeaderByName('Source'), 'button');
+      await userEvent.click(sourceHeader);
       let cells = queryCellsByColumnName('Source');
       cells.forEach((cell, i, allCells) => {
         const prevCell = allCells[i - 1];
@@ -421,7 +399,7 @@ describe('CorrelationsPage', () => {
         }
       });
 
-      fireEvent.click(sourceHeader);
+      await userEvent.click(sourceHeader);
       cells = queryCellsByColumnName('Source');
       cells.forEach((cell, i, allCells) => {
         const prevCell = allCells[i - 1];
@@ -431,47 +409,53 @@ describe('CorrelationsPage', () => {
       });
     });
 
-    it('correctly adds correlations', async () => {
-      const addNewButton = screen.getByRole('button', { name: /add new/i });
+    it('correctly adds new correlation', async () => {
+      const addNewButton = await screen.findByRole('button', { name: /add new/i });
       expect(addNewButton).toBeInTheDocument();
-      fireEvent.click(addNewButton);
+      await userEvent.click(addNewButton);
 
-      fireEvent.change(screen.getByRole('textbox', { name: /label/i }), { target: { value: 'A Label' } });
-      fireEvent.change(screen.getByRole('textbox', { name: /description/i }), { target: { value: 'A Description' } });
-
-      // set source datasource picker value
-      fireEvent.keyDown(screen.getByLabelText(/^source$/i), { keyCode: 40 });
-      fireEvent.click(within(screen.getByLabelText('Select options menu')).getByText('prometheus'));
+      // step 1:
+      await userEvent.clear(screen.getByRole('textbox', { name: /label/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /label/i }), 'A Label');
+      await userEvent.clear(screen.getByRole('textbox', { name: /description/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /description/i }), 'A Description');
+      await userEvent.click(await screen.findByRole('button', { name: /next$/i }));
 
+      // step 2:
       // set target datasource picker value
-      fireEvent.keyDown(screen.getByLabelText(/^target$/i), { keyCode: 40 });
-      fireEvent.click(screen.getByText('elastic'));
+      fireEvent.keyDown(screen.getByLabelText(/^target/i), { keyCode: 40 });
+      await userEvent.click(screen.getByText('elastic'));
+      await userEvent.click(await screen.findByRole('button', { name: /next$/i }));
 
-      fireEvent.change(screen.getByRole('textbox', { name: /target field/i }), { target: { value: 'Line' } });
+      // step 3:
+      // set source datasource picker value
+      fireEvent.keyDown(screen.getByLabelText(/^source/i), { keyCode: 40 });
+      await userEvent.click(within(screen.getByLabelText('Select options menu')).getByText('prometheus'));
 
-      await waitForElementToBeRemoved(() => screen.queryByText(/loading query editor/i));
+      await userEvent.clear(screen.getByRole('textbox', { name: /results field/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /results field/i }), 'Line');
 
-      fireEvent.click(screen.getByRole('button', { name: /add$/i }));
-
-      // the form should get removed after successful submissions
-      await waitForElementToBeRemoved(() => screen.queryByRole('button', { name: /add$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /add$/i }));
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_added');
+
+      // the table showing correlations should have appeared
+      expect(await screen.findByRole('table')).toBeInTheDocument();
     });
 
     it('correctly closes the form when clicking on the close icon', async () => {
-      const addNewButton = screen.getByRole('button', { name: /add new/i });
+      const addNewButton = await screen.findByRole('button', { name: /add new/i });
       expect(addNewButton).toBeInTheDocument();
-      fireEvent.click(addNewButton);
+      await userEvent.click(addNewButton);
 
-      fireEvent.click(screen.getByRole('button', { name: /close$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /close$/i }));
 
       expect(screen.queryByRole('button', { name: /add$/i })).not.toBeInTheDocument();
     });
 
     it('correctly deletes correlations', async () => {
       // A row with the correlation should exist
-      expect(screen.getByRole('cell', { name: /some label/i })).toBeInTheDocument();
+      expect(await screen.findByRole('cell', { name: /some label/i })).toBeInTheDocument();
 
       const tableRows = queryRowsByCellValue('Source', 'loki');
 
@@ -479,43 +463,172 @@ describe('CorrelationsPage', () => {
 
       expect(deleteButton).toBeInTheDocument();
 
-      fireEvent.click(deleteButton);
+      await userEvent.click(deleteButton);
 
       const confirmButton = within(tableRows[0]).getByRole('button', { name: /delete$/i });
       expect(confirmButton).toBeInTheDocument();
 
-      fireEvent.click(confirmButton);
+      await userEvent.click(confirmButton);
 
-      await waitForElementToBeRemoved(() => screen.queryByRole('cell', { name: /some label$/i }));
+      expect(screen.queryByRole('cell', { name: /some label$/i })).not.toBeInTheDocument();
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_deleted');
     });
 
     it('correctly edits correlations', async () => {
+      // wait for table to appear
+      await screen.findByRole('table');
+
       const tableRows = queryRowsByCellValue('Source', 'loki');
 
       const rowExpanderButton = within(tableRows[0]).getByRole('button', { name: /toggle row expanded/i });
-      fireEvent.click(rowExpanderButton);
+      await userEvent.click(rowExpanderButton);
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_details_expanded');
 
-      await waitForElementToBeRemoved(() => screen.queryByText(/loading query editor/i));
-
-      fireEvent.change(screen.getByRole('textbox', { name: /label/i }), { target: { value: 'edited label' } });
-      fireEvent.change(screen.getByRole('textbox', { name: /description/i }), {
-        target: { value: 'edited description' },
-      });
+      await userEvent.clear(screen.getByRole('textbox', { name: /label/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /label/i }), 'edited label');
+      await userEvent.clear(screen.getByRole('textbox', { name: /description/i }));
+      await userEvent.type(screen.getByRole('textbox', { name: /description/i }), 'edited description');
 
       expect(screen.queryByRole('cell', { name: /edited label$/i })).not.toBeInTheDocument();
 
-      fireEvent.click(screen.getByRole('button', { name: /save$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
 
-      await waitFor(() => {
-        expect(screen.queryByRole('cell', { name: /edited label$/i })).toBeInTheDocument();
-      });
+      await userEvent.click(screen.getByRole('button', { name: /save$/i }));
+
+      expect(await screen.findByRole('cell', { name: /edited label$/i })).toBeInTheDocument();
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_edited');
     });
+
+    it('correctly edits transformations', async () => {
+      // wait for table to appear
+      await screen.findByRole('table');
+
+      const tableRows = queryRowsByCellValue('Source', 'loki');
+
+      const rowExpanderButton = within(tableRows[0]).getByRole('button', { name: /toggle row expanded/i });
+      await userEvent.click(rowExpanderButton);
+
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
+
+      // select Logfmt, be sure expression field is disabled
+      let typeFilterSelect = screen.getAllByLabelText('Type');
+      openMenu(typeFilterSelect[0]);
+      await userEvent.click(screen.getByText('Logfmt'));
+
+      let expressionInput = screen.queryByLabelText(/expression/i);
+      expect(expressionInput).toBeInTheDocument();
+      expect(expressionInput).toBeDisabled();
+
+      // select Regex, be sure expression field is not disabled and contains the former expression
+      openMenu(typeFilterSelect[0]);
+      await userEvent.click(screen.getByText('Regular expression', { selector: 'span' }));
+      expressionInput = screen.queryByLabelText(/expression/i);
+      expect(expressionInput).toBeInTheDocument();
+      expect(expressionInput).toBeEnabled();
+      expect(expressionInput).toHaveAttribute('value', 'url=http[s]?://(S*)');
+
+      // select Logfmt, delete, then add a new one to be sure the value is blank
+      openMenu(typeFilterSelect[0]);
+      await userEvent.click(screen.getByText('Logfmt'));
+      await userEvent.click(screen.getByRole('button', { name: /remove transformation/i }));
+      expressionInput = screen.queryByLabelText(/expression/i);
+      expect(expressionInput).not.toBeInTheDocument();
+
+      await userEvent.click(screen.getByRole('button', { name: /add transformation/i }));
+      typeFilterSelect = screen.getAllByLabelText('Type');
+      openMenu(typeFilterSelect[0]);
+      await userEvent.click(screen.getByText('Regular expression'));
+      expressionInput = screen.queryByLabelText(/expression/i);
+      expect(expressionInput).toBeInTheDocument();
+      expect(expressionInput).toBeEnabled();
+      expect(expressionInput).not.toHaveValue('url=http[s]?://(S*)');
+      await userEvent.click(screen.getByRole('button', { name: /save$/i }));
+      expect(screen.getByText('Please define an expression')).toBeInTheDocument();
+      await userEvent.type(screen.getByLabelText(/expression/i), 'test expression');
+      await userEvent.click(screen.getByRole('button', { name: /save$/i }));
+      expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_edited');
+    });
+  });
+
+  describe('With correlations with datasources the user cannot access', () => {
+    let queryCellsByColumnName: (columnName: Matcher) => HTMLTableCellElement[];
+    beforeEach(async () => {
+      const renderResult = await renderWithContext(
+        {
+          loki: mockDataSource(
+            {
+              uid: 'loki',
+              name: 'loki',
+              readOnly: false,
+              jsonData: {},
+              access: 'direct',
+              type: 'datasource',
+            },
+            {
+              logs: true,
+            }
+          ),
+        },
+        [
+          {
+            sourceUID: 'loki',
+            targetUID: 'loki',
+            uid: '1',
+            label: 'Loki to Loki',
+            config: {
+              field: 'line',
+              target: {},
+              type: 'query',
+              transformations: [
+                { type: SupportedTransformationType.Regex, expression: 'url=http[s]?://(S*)', mapValue: 'path' },
+              ],
+            },
+          },
+          {
+            sourceUID: 'loki',
+            targetUID: 'prometheus',
+            uid: '2',
+            label: 'Loki to Prometheus',
+            config: {
+              field: 'line',
+              target: {},
+              type: 'query',
+              transformations: [
+                { type: SupportedTransformationType.Regex, expression: 'url=http[s]?://(S*)', mapValue: 'path' },
+              ],
+            },
+          },
+          {
+            sourceUID: 'prometheus',
+            targetUID: 'loki',
+            uid: '3',
+            label: 'Prometheus to Loki',
+            config: { field: 'label', target: {}, type: 'query' },
+          },
+          {
+            sourceUID: 'prometheus',
+            targetUID: 'prometheus',
+            uid: '4',
+            label: 'Prometheus to Prometheus',
+            config: { field: 'label', target: {}, type: 'query' },
+          },
+        ]
+      );
+      queryCellsByColumnName = renderResult.queryCellsByColumnName;
+    });
+
+    it("doesn't show correlations from source or target datasources the user doesn't have access to", async () => {
+      await screen.findByRole('table');
+
+      const labels = queryCellsByColumnName('Label');
+      expect(labels.length).toBe(1);
+      expect(labels[0].textContent).toBe('Loki to Loki');
+    });
   });
 
   describe('Read only correlations', () => {
@@ -525,7 +638,12 @@ describe('CorrelationsPage', () => {
         targetUID: 'loki',
         uid: '1',
         label: 'Some label',
-        config: { field: 'line', target: {}, type: 'query' },
+        config: {
+          field: 'line',
+          target: {},
+          type: 'query',
+          transformations: [{ type: SupportedTransformationType.Regex, expression: '(?:msg)=' }],
+        },
       },
     ];
 
@@ -548,24 +666,21 @@ describe('CorrelationsPage', () => {
 
     it("doesn't render delete button", async () => {
       // A row with the correlation should exist
-      expect(screen.getByRole('cell', { name: /some label/i })).toBeInTheDocument();
+      expect(await screen.findByRole('cell', { name: /some label/i })).toBeInTheDocument();
 
       expect(screen.queryByRole('button', { name: /delete correlation/i })).not.toBeInTheDocument();
     });
 
     it('edit form is read only', async () => {
       // A row with the correlation should exist
-      const rowExpanderButton = screen.getByRole('button', { name: /toggle row expanded/i });
+      const rowExpanderButton = await screen.findByRole('button', { name: /toggle row expanded/i });
 
-      fireEvent.click(rowExpanderButton);
+      await userEvent.click(rowExpanderButton);
 
       expect(mocks.reportInteraction).toHaveBeenLastCalledWith('grafana_correlations_details_expanded');
 
-      // wait for the form to be rendered and query editor to be mounted
-      await waitForElementToBeRemoved(() => screen.queryByText(/loading query editor/i));
-
       // form elements should be readonly
-      const labelInput = screen.getByRole('textbox', { name: /label/i });
+      const labelInput = await screen.findByRole('textbox', { name: /label/i });
       expect(labelInput).toBeInTheDocument();
       expect(labelInput).toHaveAttribute('readonly');
 
@@ -573,6 +688,16 @@ describe('CorrelationsPage', () => {
       expect(descriptionInput).toBeInTheDocument();
       expect(descriptionInput).toHaveAttribute('readonly');
 
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
+      await userEvent.click(screen.getByRole('button', { name: /next$/i }));
+
+      // expect the transformation to exist but be read only
+      const expressionInput = screen.queryByLabelText(/expression/i);
+      expect(expressionInput).toBeInTheDocument();
+      expect(expressionInput).toHaveAttribute('readonly');
+      expect(screen.queryByRole('button', { name: 'add transformation' })).not.toBeInTheDocument();
+      expect(screen.queryByRole('button', { name: 'remove transformation' })).not.toBeInTheDocument();
+
       // we don't expect the save button to be rendered
       expect(screen.queryByRole('button', { name: 'save' })).not.toBeInTheDocument();
     });
