@@ -1,53 +1,33 @@
-// Libraries
 import React, { Component } from 'react';
-import { dateMath, GrafanaTheme, TimeZone } from '@grafana/data';
-import { css } from 'emotion';
+import { Unsubscribable } from 'rxjs';
 
-// Types
-import { DashboardModel } from '../../state';
-import { LocationState, CoreEvents } from 'app/types';
-import { TimeRange } from '@grafana/data';
-
-// Components
-import { RefreshPicker, withTheme, stylesFactory, Themeable, defaultIntervals } from '@grafana/ui';
+import { dateMath, TimeRange, TimeZone } from '@grafana/data';
+import { TimeRangeUpdatedEvent } from '@grafana/runtime';
+import { defaultIntervals, RefreshPicker } from '@grafana/ui';
 import { TimePickerWithHistory } from 'app/core/components/TimePicker/TimePickerWithHistory';
-
-// Utils & Services
-import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { appEvents } from 'app/core/core';
+import { t } from 'app/core/internationalization';
+import { AutoRefreshInterval } from 'app/core/services/context_srv';
+import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 
-const getStyles = stylesFactory((theme: GrafanaTheme) => {
-  return {
-    container: css`
-      position: relative;
-      display: flex;
-    `,
-  };
-});
+import { ShiftTimeEvent, ShiftTimeEventDirection, ZoomOutEvent } from '../../../../types/events';
+import { DashboardModel } from '../../state';
 
-export interface Props extends Themeable {
+export interface Props {
   dashboard: DashboardModel;
-  location: LocationState;
   onChangeTimeZone: (timeZone: TimeZone) => void;
+  isOnCanvas?: boolean;
 }
-class UnthemedDashNavTimeControls extends Component<Props> {
+
+export class DashNavTimeControls extends Component<Props> {
+  private sub?: Unsubscribable;
+
   componentDidMount() {
-    // Only reason for this is that sometimes time updates can happen via redux location changes
-    // and this happens before timeSrv has had chance to update state (as it listens to angular route-updated)
-    // This can be removed after timeSrv listens redux location
-    this.props.dashboard.on(CoreEvents.timeRangeUpdated, this.triggerForceUpdate);
+    this.sub = this.props.dashboard.events.subscribe(TimeRangeUpdatedEvent, () => this.forceUpdate());
   }
 
   componentWillUnmount() {
-    this.props.dashboard.off(CoreEvents.timeRangeUpdated, this.triggerForceUpdate);
-  }
-
-  triggerForceUpdate = () => {
-    this.forceUpdate();
-  };
-
-  get refreshParamInUrl(): string {
-    return this.props.location.query.refresh as string;
+    this.sub?.unsubscribe();
   }
 
   onChangeRefreshInterval = (interval: string) => {
@@ -56,16 +36,16 @@ class UnthemedDashNavTimeControls extends Component<Props> {
   };
 
   onRefresh = () => {
-    getTimeSrv().refreshDashboard();
+    getTimeSrv().refreshTimeModel();
     return Promise.resolve();
   };
 
   onMoveBack = () => {
-    appEvents.emit(CoreEvents.shiftTime, -1);
+    appEvents.publish(new ShiftTimeEvent({ direction: ShiftTimeEventDirection.Left }));
   };
 
   onMoveForward = () => {
-    appEvents.emit(CoreEvents.shiftTime, 1);
+    appEvents.publish(new ShiftTimeEvent({ direction: ShiftTimeEventDirection.Right }));
   };
 
   onChangeTimePicker = (timeRange: TimeRange) => {
@@ -89,40 +69,56 @@ class UnthemedDashNavTimeControls extends Component<Props> {
     this.onRefresh();
   };
 
+  onChangeFiscalYearStartMonth = (month: number) => {
+    this.props.dashboard.fiscalYearStartMonth = month;
+    this.onRefresh();
+  };
+
   onZoom = () => {
-    appEvents.emit(CoreEvents.zoomOut, 2);
+    appEvents.publish(new ZoomOutEvent({ scale: 2 }));
   };
 
   render() {
-    const { dashboard, theme } = this.props;
+    const { dashboard, isOnCanvas } = this.props;
     const { refresh_intervals } = dashboard.timepicker;
     const intervals = getTimeSrv().getValidIntervals(refresh_intervals || defaultIntervals);
 
     const timePickerValue = getTimeSrv().timeRange();
     const timeZone = dashboard.getTimezone();
-    const styles = getStyles(theme);
+    const fiscalYearStartMonth = dashboard.fiscalYearStartMonth;
+    const hideIntervalPicker = dashboard.panelInEdit?.isEditing;
+
+    let text: string | undefined = undefined;
+    if (dashboard.refresh === AutoRefreshInterval) {
+      text = getTimeSrv().getAutoRefreshInteval().interval;
+    }
 
     return (
-      <div className={styles.container}>
+      <>
         <TimePickerWithHistory
           value={timePickerValue}
           onChange={this.onChangeTimePicker}
           timeZone={timeZone}
+          fiscalYearStartMonth={fiscalYearStartMonth}
           onMoveBackward={this.onMoveBack}
           onMoveForward={this.onMoveForward}
           onZoom={this.onZoom}
           onChangeTimeZone={this.onChangeTimeZone}
+          onChangeFiscalYearStartMonth={this.onChangeFiscalYearStartMonth}
+          isOnCanvas={isOnCanvas}
         />
         <RefreshPicker
           onIntervalChanged={this.onChangeRefreshInterval}
           onRefresh={this.onRefresh}
           value={dashboard.refresh}
           intervals={intervals}
-          tooltip="Refresh dashboard"
+          isOnCanvas={isOnCanvas}
+          tooltip={t('dashboard.toolbar.refresh', 'Refresh dashboard')}
+          noIntervalPicker={hideIntervalPicker}
+          showAutoInterval={true}
+          text={text}
         />
-      </div>
+      </>
     );
   }
 }
-
-export const DashNavTimeControls = withTheme(UnthemedDashNavTimeControls);
