@@ -12,7 +12,7 @@ import { BackendSrv, setBackendSrv } from '@grafana/runtime';
 import { GrafanaContext } from 'app/core/context/GrafanaContext';
 
 import { configureStore } from '../../../../store/configureStore';
-import { DashboardModel } from '../../state';
+import { createDashboardModelFixture } from '../../state/__fixtures__/dashboardFixtures';
 
 import { GeneralSettingsUnconnected as GeneralSettings, Props } from './GeneralSettings';
 
@@ -23,13 +23,16 @@ setBackendSrv({
 const setupTestContext = (options: Partial<Props>) => {
   const store = configureStore();
   const defaults: Props = {
-    dashboard: new DashboardModel(
+    dashboard: createDashboardModelFixture(
       {
         title: 'test dashboard title',
         description: 'test dashboard description',
         timepicker: {
           refresh_intervals: ['5s', '10s', '30s', '1m', '5m', '15m', '30m', '1h', '2h', '1d', '2d'],
           time_options: ['5m', '15m', '1h', '6h', '12h', '24h', '2d', '7d', '30d'],
+          collapse: true,
+          enable: true,
+          hidden: false,
         },
         timezone: 'utc',
       },
