@@ -1,8 +1,11 @@
+import { PanelPlugin } from '@grafana/data';
+import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
+import { LibraryElementDTOMeta } from '@grafana/schema';
+import { createDashboardModelFixture } from 'app/features/dashboard/state/__fixtures__/dashboardFixtures';
 import { panelModelAndPluginReady, removePanel } from 'app/features/panel/state/reducers';
-import { getPanelPlugin } from 'app/features/plugins/__mocks__/pluginMocks';
 
 import { thunkTester } from '../../../../../../test/core/thunk/thunkTester';
-import { DashboardModel, PanelModel } from '../../../state';
+import { PanelModel } from '../../../state';
 
 import { exitPanelEditor, initPanelEditor, skipPanelUpdate } from './actions';
 import { closeEditor, initialState, PanelEditorState } from './reducers';
@@ -10,7 +13,7 @@ import { closeEditor, initialState, PanelEditorState } from './reducers';
 describe('panelEditor actions', () => {
   describe('initPanelEditor', () => {
     it('initPanelEditor should create edit panel model as clone', async () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
       const sourcePanel = new PanelModel({ id: 12, type: 'graph' });
@@ -24,19 +27,17 @@ describe('panelEditor actions', () => {
         .givenThunk(initPanelEditor)
         .whenThunkIsDispatched(sourcePanel, dashboard);
 
-      expect(dispatchedActions.length).toBe(2);
-      expect(dispatchedActions[0].type).toBe(panelModelAndPluginReady.type);
-
-      expect(dispatchedActions[1].payload.sourcePanel).toBe(sourcePanel);
-      expect(dispatchedActions[1].payload.panel).not.toBe(sourcePanel);
-      expect(dispatchedActions[1].payload.panel.id).toBe(sourcePanel.id);
+      expect(dispatchedActions.length).toBe(1);
+      expect(dispatchedActions[0].payload.sourcePanel).toBe(sourcePanel);
+      expect(dispatchedActions[0].payload.panel).not.toBe(sourcePanel);
+      expect(dispatchedActions[0].payload.panel.id).toBe(sourcePanel.id);
     });
   });
 
   describe('panelEditorCleanUp', () => {
     it('should update source panel', async () => {
       const sourcePanel = new PanelModel({ id: 12, type: 'graph' });
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -68,7 +69,7 @@ describe('panelEditor actions', () => {
 
     it('should dispatch panelModelAndPluginReady if type changed', async () => {
       const sourcePanel = new PanelModel({ id: 12, type: 'graph' });
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -105,9 +106,9 @@ describe('panelEditor actions', () => {
       const sourcePanel = new PanelModel({ id: 12, type: 'graph' });
       sourcePanel.plugin = {
         customFieldConfigs: {},
-      } as any;
+      } as unknown as PanelPlugin;
 
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -140,7 +141,7 @@ describe('panelEditor actions', () => {
       sourcePanel.plugin = getPanelPlugin({});
       sourcePanel.plugin.angularPanelCtrl = undefined;
 
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -170,7 +171,7 @@ describe('panelEditor actions', () => {
       sourcePanel.plugin = getPanelPlugin({});
       sourcePanel.plugin.angularPanelCtrl = undefined;
 
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -209,7 +210,7 @@ describe('panelEditor actions', () => {
       sourcePanel.plugin = getPanelPlugin({});
       sourcePanel.plugin.angularPanelCtrl = {};
 
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [{ id: 12, type: 'graph' }],
       });
 
@@ -243,9 +244,9 @@ describe('panelEditor actions', () => {
   describe('skipPanelUpdate', () => {
     describe('when called with panel with an library uid different from the modified panel', () => {
       it('then it should return true', () => {
-        const meta: any = {};
-        const modified: any = { libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
-        const panel: any = { libraryPanel: { uid: '456', name: 'Name', meta, version: 1 } };
+        const meta = {} as LibraryElementDTOMeta;
+        const modified = new PanelModel({ libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
+        const panel = new PanelModel({ libraryPanel: { uid: '456', name: 'Name', meta, version: 1 } });
 
         expect(skipPanelUpdate(modified, panel)).toEqual(true);
       });
@@ -253,9 +254,9 @@ describe('panelEditor actions', () => {
 
     describe('when called with a panel that is the same as the modified panel', () => {
       it('then it should return true', () => {
-        const meta: any = {};
-        const modified: any = { id: 14, libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
-        const panel: any = { id: 14, libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
+        const meta = {} as LibraryElementDTOMeta;
+        const modified = new PanelModel({ id: 14, libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
+        const panel = new PanelModel({ id: 14, libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
 
         expect(skipPanelUpdate(modified, panel)).toEqual(true);
       });
@@ -263,9 +264,12 @@ describe('panelEditor actions', () => {
 
     describe('when called with a panel that is repeated', () => {
       it('then it should return true', () => {
-        const meta: any = {};
-        const modified: any = { libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
-        const panel: any = { repeatPanelId: 14, libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
+        const meta = {} as LibraryElementDTOMeta;
+        const modified = new PanelModel({ libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
+        const panel = new PanelModel({
+          repeatPanelId: 14,
+          libraryPanel: { uid: '123', name: 'Name', meta, version: 1 },
+        });
 
         expect(skipPanelUpdate(modified, panel)).toEqual(true);
       });
@@ -273,9 +277,9 @@ describe('panelEditor actions', () => {
 
     describe('when called with a panel that is a duplicate of the modified panel', () => {
       it('then it should return false', () => {
-        const meta: any = {};
-        const modified: any = { libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
-        const panel: any = { libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } };
+        const meta = {} as LibraryElementDTOMeta;
+        const modified = new PanelModel({ libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
+        const panel = new PanelModel({ libraryPanel: { uid: '123', name: 'Name', meta, version: 1 } });
 
         expect(skipPanelUpdate(modified, panel)).toEqual(false);
       });
