@@ -1,7 +1,7 @@
 import { css } from '@emotion/css';
 import React from 'react';
 
-import { GrafanaTheme2, colorManipulator } from '@grafana/data';
+import { GrafanaTheme2 } from '@grafana/data';
 import { useStyles2 } from '@grafana/ui';
 
 export interface PublicDashboardFooterCfg {
@@ -17,11 +17,9 @@ export const PublicDashboardFooter = function () {
 
   return conf.hide ? null : (
     <div className={styles.footer}>
-      <span className={styles.logoText}>
-        <a href={conf.link} target="_blank" rel="noreferrer noopener">
-          {conf.text} <img className={styles.logoImg} alt="" src={conf.logo}></img>
-        </a>
-      </span>
+      <a className={styles.link} href={conf.link} target="_blank" rel="noreferrer noopener">
+        {conf.text} <img className={styles.logoImg} alt="" src={conf.logo}></img>
+      </a>
     </div>
   );
 };
@@ -38,17 +36,16 @@ export let getPublicDashboardFooterConfig = (): PublicDashboardFooterCfg => ({
 
 const getStyles = (theme: GrafanaTheme2) => ({
   footer: css`
-    position: absolute;
+    display: flex;
+    justify-content: end;
     height: 30px;
-    bottom: 0;
-    width: 100%;
-    background-color: ${colorManipulator.alpha(theme.colors.background.canvas, 0.7)};
-    text-align: right;
-    font-size: ${theme.typography.body.fontSize};
-    z-index: ${theme.zIndex.navbarFixed};
+    padding: ${theme.spacing(0, 2, 0, 1)};
   `,
-  logoText: css`
-    margin-right: ${theme.spacing(1)};
+  link: css`
+    display: flex;
+    gap: 4px;
+    justify-content: end;
+    align-items: center;
   `,
   logoImg: css`
     height: 100%;
