@@ -1,20 +1,21 @@
-import React, { FC } from 'react';
+import { css } from '@emotion/css';
+import React from 'react';
+
 import { Modal, stylesFactory } from '@grafana/ui';
-import { css } from 'emotion';
 
 import { OnRowOptionsUpdate, RowOptionsForm } from './RowOptionsForm';
 
 export interface RowOptionsModalProps {
-  title: string | null;
-  repeat: string | null;
+  title: string;
+  repeat?: string | null;
   onDismiss: () => void;
   onUpdate: OnRowOptionsUpdate;
 }
 
-export const RowOptionsModal: FC<RowOptionsModalProps> = ({ repeat, title, onDismiss, onUpdate }) => {
+export const RowOptionsModal = ({ repeat, title, onDismiss, onUpdate }: RowOptionsModalProps) => {
   const styles = getStyles();
   return (
-    <Modal isOpen={true} title="Row Options" icon="copy" onDismiss={onDismiss} className={styles.modal}>
+    <Modal isOpen={true} title="Row options" icon="copy" onDismiss={onDismiss} className={styles.modal}>
       <RowOptionsForm repeat={repeat} title={title} onCancel={onDismiss} onUpdate={onUpdate} />
     </Modal>
   );
