@@ -1,23 +1,24 @@
 import React from 'react';
-import { Button, HorizontalGroup, Input, Switch, Form, Field, InputControl } from '@grafana/ui';
-import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
+
+import { Button, Input, Switch, Form, Field, InputControl, HorizontalGroup } from '@grafana/ui';
 import { FolderPicker } from 'app/core/components/Select/FolderPicker';
+import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
+import { validationSrv } from 'app/features/manage-dashboards/services/ValidationSrv';
+
 import { SaveDashboardFormProps } from '../types';
-import validationSrv from 'app/features/manage-dashboards/services/ValidationSrv';
 
 interface SaveDashboardAsFormDTO {
   title: string;
-  $folder: { id?: number; title?: string };
+  $folder: { uid?: string; title?: string };
   copyTags: boolean;
 }
 
 const getSaveAsDashboardClone = (dashboard: DashboardModel) => {
-  const clone: any = dashboard.getSaveModelClone();
+  const clone = dashboard.getSaveModelClone();
   clone.id = null;
   clone.uid = '';
   clone.title += ' Copy';
   clone.editable = true;
-  clone.hideControls = false;
 
   // remove alerts if source dashboard is already persisted
   // do not want to create alert dupes
@@ -30,20 +31,25 @@ const getSaveAsDashboardClone = (dashboard: DashboardModel) => {
     });
   }
 
-  delete clone.autoUpdate;
   return clone;
 };
 
-export const SaveDashboardAsForm: React.FC<SaveDashboardFormProps & { isNew?: boolean }> = ({
+export interface SaveDashboardAsFormProps extends SaveDashboardFormProps {
+  isNew?: boolean;
+}
+
+export const SaveDashboardAsForm = ({
   dashboard,
+  isLoading,
+  isNew,
   onSubmit,
   onCancel,
   onSuccess,
-}) => {
+}: SaveDashboardAsFormProps) => {
   const defaultValues: SaveDashboardAsFormDTO = {
-    title: `${dashboard.title} Copy`,
+    title: isNew ? dashboard.title : `${dashboard.title} Copy`,
     $folder: {
-      id: dashboard.meta.folderId,
+      uid: dashboard.meta.folderUid,
       title: dashboard.meta.folderTitle,
     },
     copyTags: false,
@@ -51,13 +57,14 @@ export const SaveDashboardAsForm: React.FC<SaveDashboardFormProps & { isNew?: bo
 
   const validateDashboardName = (getFormValues: () => SaveDashboardAsFormDTO) => async (dashboardName: string) => {
     if (dashboardName && dashboardName === getFormValues().$folder.title?.trim()) {
-      return 'Dashboard name cannot be the same as folder';
+      return 'Dashboard name cannot be the same as folder name';
     }
+
     try {
-      await validationSrv.validateNewDashboardName(getFormValues().$folder.id, dashboardName);
+      await validationSrv.validateNewDashboardName(getFormValues().$folder.uid ?? 'general', dashboardName);
       return true;
     } catch (e) {
-      return e.message;
+      return e instanceof Error ? e.message : 'Dashboard name is invalid';
     }
   };
 
@@ -71,14 +78,14 @@ export const SaveDashboardAsForm: React.FC<SaveDashboardFormProps & { isNew?: bo
 
         const clone = getSaveAsDashboardClone(dashboard);
         clone.title = data.title;
-        if (!data.copyTags) {
+        if (!isNew && !data.copyTags) {
           clone.tags = [];
         }
 
         const result = await onSubmit(
           clone,
           {
-            folderId: data.$folder.id,
+            folderUid: data.$folder.uid,
           },
           dashboard
         );
@@ -92,8 +99,7 @@ export const SaveDashboardAsForm: React.FC<SaveDashboardFormProps & { isNew?: bo
         <>
           <Field label="Dashboard name" invalid={!!errors.title} error={errors.title?.message}>
             <Input
-              name="title"
-              ref={register({
+              {...register('title', {
                 validate: validateDashboardName(getValues),
               })}
               aria-label="Save dashboard title field"
@@ -102,25 +108,33 @@ export const SaveDashboardAsForm: React.FC<SaveDashboardFormProps & { isNew?: bo
           </Field>
           <Field label="Folder">
             <InputControl
-              as={FolderPicker}
+              render={({ field: { ref, ...field } }) => (
+                <FolderPicker
+                  {...field}
+                  onChange={(uid: string, title: string) => field.onChange({ uid, title })}
+                  value={field.value?.uid}
+                  // Old folder picker fields
+                  initialTitle={dashboard.meta.folderTitle}
+                  dashboardId={dashboard.id}
+                  enableCreateNew
+                />
+              )}
               control={control}
               name="$folder"
-              dashboardId={dashboard.id}
-              initialFolderId={dashboard.meta.folderId}
-              initialTitle={dashboard.meta.folderTitle}
-              enableCreateNew
             />
           </Field>
-          <Field label="Copy tags">
-            <Switch name="copyTags" ref={register} />
-          </Field>
+          {!isNew && (
+            <Field label="Copy tags">
+              <Switch {...register('copyTags')} />
+            </Field>
+          )}
           <HorizontalGroup>
-            <Button type="submit" aria-label="Save dashboard button">
-              Save
-            </Button>
-            <Button variant="secondary" onClick={onCancel}>
+            <Button type="button" variant="secondary" onClick={onCancel} fill="outline">
               Cancel
             </Button>
+            <Button disabled={isLoading} type="submit" aria-label="Save dashboard button">
+              {isLoading ? 'Saving...' : 'Save'}
+            </Button>
           </HorizontalGroup>
         </>
       )}
