@@ -11,7 +11,7 @@ export interface SaveDashboardData {
 }
 
 export interface SaveDashboardOptions extends CloneOptions {
-  folderId?: number;
+  folderUid?: string;
   overwrite?: boolean;
   message?: string;
   makeEditable?: boolean;
@@ -20,15 +20,16 @@ export interface SaveDashboardOptions extends CloneOptions {
 export interface SaveDashboardCommand {
   dashboard: DashboardDataDTO;
   message?: string;
-  folderId?: number;
+  folderUid?: string;
   overwrite?: boolean;
 }
 
 export interface SaveDashboardFormProps {
   dashboard: DashboardModel;
+  isLoading: boolean;
   onCancel: () => void;
   onSuccess: () => void;
-  onSubmit?: (clone: any, options: SaveDashboardOptions, dashboard: DashboardModel) => Promise<any>;
+  onSubmit?: (clone: DashboardModel, options: SaveDashboardOptions, dashboard: DashboardModel) => Promise<any>;
 }
 
 export interface SaveDashboardModalProps {
