@@ -1,45 +1,45 @@
+import { dateTime, locationUtil, PanelModel, TimeRange, urlUtil } from '@grafana/data';
 import { config } from '@grafana/runtime';
-import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { createShortLink } from 'app/core/utils/shortLinks';
-import { PanelModel, dateTime, urlUtil } from '@grafana/data';
-import { getAllVariableValuesForUrl } from 'app/features/variables/getAllVariableValuesForUrl';
+import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 
-export function buildParams(
-  useCurrentTimeRange: boolean,
-  includeTemplateVars: boolean,
-  selectedTheme?: string,
-  panel?: PanelModel
-) {
-  let params = urlUtil.getUrlSearchParams();
+export interface BuildParamsArgs {
+  useCurrentTimeRange: boolean;
+  selectedTheme?: string;
+  panel?: PanelModel;
+  search?: string;
+  range?: TimeRange;
+  orgId?: number;
+}
 
-  const range = getTimeSrv().timeRange();
-  params.from = range.from.valueOf();
-  params.to = range.to.valueOf();
-  params.orgId = config.bootData.user.orgId;
+export function buildParams({
+  useCurrentTimeRange,
+  selectedTheme,
+  panel,
+  search = window.location.search,
+  range = getTimeSrv().timeRange(),
+  orgId = config.bootData.user.orgId,
+}: BuildParamsArgs): URLSearchParams {
+  const searchParams = new URLSearchParams(search);
+
+  searchParams.set('from', String(range.from.valueOf()));
+  searchParams.set('to', String(range.to.valueOf()));
+  searchParams.set('orgId', String(orgId));
 
   if (!useCurrentTimeRange) {
-    delete params.from;
-    delete params.to;
-  }
-
-  if (includeTemplateVars) {
-    params = {
-      ...params,
-      ...getAllVariableValuesForUrl(),
-    };
+    searchParams.delete('from');
+    searchParams.delete('to');
   }
 
   if (selectedTheme !== 'current') {
-    params.theme = selectedTheme;
+    searchParams.set('theme', selectedTheme!);
   }
 
-  if (panel && !params.editPanel) {
-    params.viewPanel = panel.id;
-  } else {
-    delete params.viewPanel;
+  if (panel && !searchParams.has('editPanel')) {
+    searchParams.set('viewPanel', String(panel.id));
   }
 
-  return params;
+  return searchParams;
 }
 
 export function buildBaseUrl() {
@@ -55,14 +55,13 @@ export function buildBaseUrl() {
 
 export async function buildShareUrl(
   useCurrentTimeRange: boolean,
-  includeTemplateVars: boolean,
   selectedTheme?: string,
   panel?: PanelModel,
   shortenUrl?: boolean
 ) {
   const baseUrl = buildBaseUrl();
-  const params = buildParams(useCurrentTimeRange, includeTemplateVars, selectedTheme, panel);
-  const shareUrl = urlUtil.appendQueryToUrl(baseUrl, urlUtil.toUrlParams(params));
+  const params = buildParams({ useCurrentTimeRange, selectedTheme, panel });
+  const shareUrl = urlUtil.appendQueryToUrl(baseUrl, params.toString());
   if (shortenUrl) {
     return await createShortLink(shareUrl);
   }
@@ -71,31 +70,37 @@ export async function buildShareUrl(
 
 export function buildSoloUrl(
   useCurrentTimeRange: boolean,
-  includeTemplateVars: boolean,
+  dashboardUid: string,
   selectedTheme?: string,
   panel?: PanelModel
 ) {
   const baseUrl = buildBaseUrl();
-  const params = buildParams(useCurrentTimeRange, includeTemplateVars, selectedTheme, panel);
+  const params = buildParams({ useCurrentTimeRange, selectedTheme, panel });
 
   let soloUrl = baseUrl.replace(config.appSubUrl + '/dashboard/', config.appSubUrl + '/dashboard-solo/');
   soloUrl = soloUrl.replace(config.appSubUrl + '/d/', config.appSubUrl + '/d-solo/');
 
-  params.panelId = params.editPanel ?? params.viewPanel;
-  delete params.editPanel;
-  delete params.viewPanel;
+  // For handling the case when default_home_dashboard_path is set in the grafana config
+  const strippedUrl = locationUtil.stripBaseFromUrl(baseUrl);
+  if (strippedUrl === '/') {
+    soloUrl = `${config.appUrl}d-solo/${dashboardUid}`;
+  }
 
-  return urlUtil.appendQueryToUrl(soloUrl, urlUtil.toUrlParams(params));
+  const panelId = params.get('editPanel') ?? params.get('viewPanel') ?? '';
+  params.set('panelId', panelId);
+  params.delete('editPanel');
+  params.delete('viewPanel');
+
+  return urlUtil.appendQueryToUrl(soloUrl, params.toString());
 }
 
 export function buildImageUrl(
   useCurrentTimeRange: boolean,
-  includeTemplateVars: boolean,
+  dashboardUid: string,
   selectedTheme?: string,
   panel?: PanelModel
 ) {
-  let soloUrl = buildSoloUrl(useCurrentTimeRange, includeTemplateVars, selectedTheme, panel);
-
+  let soloUrl = buildSoloUrl(useCurrentTimeRange, dashboardUid, selectedTheme, panel);
   let imageUrl = soloUrl.replace(config.appSubUrl + '/dashboard-solo/', config.appSubUrl + '/render/dashboard-solo/');
   imageUrl = imageUrl.replace(config.appSubUrl + '/d-solo/', config.appSubUrl + '/render/d-solo/');
   imageUrl += '&width=1000&height=500' + getLocalTimeZone();
@@ -104,11 +109,11 @@ export function buildImageUrl(
 
 export function buildIframeHtml(
   useCurrentTimeRange: boolean,
-  includeTemplateVars: boolean,
+  dashboardUid: string,
   selectedTheme?: string,
   panel?: PanelModel
 ) {
-  let soloUrl = buildSoloUrl(useCurrentTimeRange, includeTemplateVars, selectedTheme, panel);
+  let soloUrl = buildSoloUrl(useCurrentTimeRange, dashboardUid, selectedTheme, panel);
   return '<iframe src="' + soloUrl + '" width="450" height="200" frameborder="0"></iframe>';
 }
 
@@ -116,11 +121,11 @@ export function getLocalTimeZone() {
   const utcOffset = '&tz=UTC' + encodeURIComponent(dateTime().format('Z'));
 
   // Older browser does not the internationalization API
-  if (!(window as any).Intl) {
+  if (!window.Intl) {
     return utcOffset;
   }
 
-  const dateFormat = (window as any).Intl.DateTimeFormat();
+  const dateFormat = window.Intl.DateTimeFormat();
   if (!dateFormat.resolvedOptions) {
     return utcOffset;
   }
