@@ -12,12 +12,12 @@ interface TransformationOperationRowsProps {
   onChange: (index: number, config: DataTransformerConfig) => void;
 }
 
-export const TransformationOperationRows: React.FC<TransformationOperationRowsProps> = ({
+export const TransformationOperationRows = ({
   data,
   onChange,
   onRemove,
   configs,
-}) => {
+}: TransformationOperationRowsProps) => {
   return (
     <>
       {configs.map((t, i) => {
