@@ -21,6 +21,7 @@ export const getPublicDashboardRoutes = (): RouteDescriptor[] => {
         path: '/public-dashboards/:accessToken',
         pageClass: 'page-dashboard',
         routeName: DashboardRoutes.Public,
+        chromeless: true,
         component: SafeDynamicImport(
           () =>
             import(
@@ -30,6 +31,25 @@ export const getPublicDashboardRoutes = (): RouteDescriptor[] => {
       },
     ];
   }
+  return [];
+};
+
+export const getEmbeddedDashboardRoutes = (): RouteDescriptor[] => {
+  if (config.featureToggles.dashboardEmbed) {
+    return [
+      {
+        path: '/d-embed',
+        pageClass: 'dashboard-embed',
+        routeName: DashboardRoutes.Embedded,
+        component: SafeDynamicImport(
+          () =>
+            import(
+              /* webpackChunkName: "EmbeddedDashboardPage" */ '../../features/dashboard/containers/EmbeddedDashboardPage'
+            )
+        ),
+      },
+    ];
+  }
 
   return [];
 };
