@@ -1,12 +1,12 @@
 import { each, map } from 'lodash';
-import { expect } from 'test/lib/common';
 
 import { DataLinkBuiltInVars, MappingType } from '@grafana/data';
+import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
 import { setDataSourceSrv } from '@grafana/runtime';
+import { FieldConfigSource } from '@grafana/schema';
 import { config } from 'app/core/config';
 import { GRID_CELL_HEIGHT, GRID_CELL_VMARGIN } from 'app/core/constants';
 import { mockDataSource, MockDataSourceSrv } from 'app/features/alerting/unified/mocks';
-import { getPanelPlugin } from 'app/features/plugins/__mocks__/pluginMocks';
 import { MIXED_DATASOURCE_NAME } from 'app/plugins/datasource/mixed/MixedDataSource';
 
 import { VariableHide } from '../../variables/types';
@@ -67,7 +67,8 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'graph',
-            legend: true,
+            legend: { show: true },
+            // @ts-expect-error
             aliasYAxis: { test: 2 },
             y_formats: ['kbyte', 'ms'],
             grid: {
@@ -87,6 +88,7 @@ describe('DashboardModel', () => {
           },
           {
             type: 'singlestat',
+            // @ts-expect-error
             legend: true,
             thresholds: '10,20,30',
             colors: ['#FF0000', 'green', 'orange'],
@@ -96,6 +98,7 @@ describe('DashboardModel', () => {
           },
           {
             type: 'singlestat',
+            // @ts-expect-error
             thresholds: '10,20,30',
             colors: ['#FF0000', 'green', 'orange'],
             gauge: {
@@ -107,6 +110,7 @@ describe('DashboardModel', () => {
           },
           {
             type: 'table',
+            // @ts-expect-error
             legend: true,
             styles: [{ thresholds: ['10', '20', '30'] }, { thresholds: ['100', '200', '300'] }],
             targets: [{ refId: 'A' }, {}],
@@ -194,7 +198,7 @@ describe('DashboardModel', () => {
     });
 
     it('dashboard schema version should be set to latest', () => {
-      expect(model.schemaVersion).toBe(36);
+      expect(model.schemaVersion).toBe(38);
     });
 
     it('graph thresholds should be migrated', () => {
@@ -211,6 +215,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'graph',
+            // @ts-expect-error
             y_formats: ['kbyte', 'ms'],
             grid: {
               threshold1: 200,
@@ -469,6 +474,7 @@ describe('DashboardModel', () => {
       const model = {
         panels: [{ minSpan: 8 }],
       };
+      // @ts-expect-error
       const dashboard = new DashboardModel(model);
       expect(dashboard.panels[0].maxPerRow).toBe(3);
     });
@@ -482,6 +488,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             links: [
+              // @ts-expect-error
               {
                 url: 'http://mylink.com',
                 keepTime: true,
@@ -489,23 +496,28 @@ describe('DashboardModel', () => {
               },
               {
                 url: 'http://mylink.com?existingParam',
+                // @ts-expect-error
                 params: 'customParam',
                 title: 'test',
               },
+              // @ts-expect-error
               {
                 url: 'http://mylink.com?existingParam',
                 includeVars: true,
                 title: 'test',
               },
               {
+                // @ts-expect-error
                 dashboard: 'my other dashboard',
                 title: 'test',
               },
               {
+                // @ts-expect-error
                 dashUri: '',
                 title: 'test',
               },
               {
+                // @ts-expect-error
                 type: 'dashboard',
                 keepTime: true,
               },
@@ -537,6 +549,7 @@ describe('DashboardModel', () => {
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
+          // @ts-expect-error
           {
             //graph panel
             options: {
@@ -550,6 +563,7 @@ describe('DashboardModel', () => {
               ],
             },
           },
+          // @ts-expect-error
           {
             //  panel with field options
             options: {
@@ -602,6 +616,7 @@ describe('DashboardModel', () => {
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
+          // @ts-expect-error
           {
             //graph panel
             options: {
@@ -612,6 +627,7 @@ describe('DashboardModel', () => {
               ],
             },
           },
+          // @ts-expect-error
           {
             //  panel with field options
             options: {
@@ -649,6 +665,7 @@ describe('DashboardModel', () => {
       model = new DashboardModel({
         templating: {
           list: [
+            // @ts-expect-error
             {
               multi: false,
               current: {
@@ -656,6 +673,7 @@ describe('DashboardModel', () => {
                 text: ['text'],
               },
             },
+            // @ts-expect-error
             {
               multi: true,
               current: {
@@ -698,6 +716,7 @@ describe('DashboardModel', () => {
           list: [
             {
               type: 'query',
+              // @ts-expect-error
               tags: ['Africa', 'America', 'Asia', 'Europe'],
               tagsQuery: 'select datacenter from x',
               tagValuesQuery: 'select value from x where datacenter = xyz',
@@ -706,6 +725,7 @@ describe('DashboardModel', () => {
             {
               type: 'query',
               current: {
+                // @ts-expect-error
                 tags: [
                   {
                     selected: true,
@@ -730,6 +750,7 @@ describe('DashboardModel', () => {
             },
             {
               type: 'query',
+              // @ts-expect-error
               tags: [
                 { text: 'Africa', selected: false },
                 { text: 'America', selected: true },
@@ -784,10 +805,12 @@ describe('DashboardModel', () => {
             id: 2,
             type: 'text',
             title: 'Angular Text Panel',
+            // @ts-expect-error
             content:
               '# Angular Text Panel\n# $constant\n\nFor markdown syntax help: [commonmark.org/help](https://commonmark.org/help/)\n\n## $text\n\n',
             mode: 'markdown',
           },
+          // @ts-expect-error
           {
             id: 3,
             type: 'text2',
@@ -798,6 +821,7 @@ describe('DashboardModel', () => {
                 '# React Text Panel from scratch\n# $constant\n\nFor markdown syntax help: [commonmark.org/help](https://commonmark.org/help/)\n\n## $text',
             },
           },
+          // @ts-expect-error
           {
             id: 4,
             type: 'text2',
@@ -864,24 +888,28 @@ describe('DashboardModel', () => {
       model = new DashboardModel({
         templating: {
           list: [
+            // @ts-expect-error
             {
               type: 'query',
               hide: VariableHide.dontHide,
               datasource: null,
               allFormat: '',
             },
+            // @ts-expect-error
             {
               type: 'query',
               hide: VariableHide.hideLabel,
               datasource: null,
               allFormat: '',
             },
+            // @ts-expect-error
             {
               type: 'query',
               hide: VariableHide.hideVariable,
               datasource: null,
               allFormat: '',
             },
+            // @ts-expect-error
             {
               type: 'constant',
               hide: VariableHide.dontHide,
@@ -891,6 +919,7 @@ describe('DashboardModel', () => {
               datasource: null,
               allFormat: '',
             },
+            // @ts-expect-error
             {
               type: 'constant',
               hide: VariableHide.hideLabel,
@@ -900,6 +929,7 @@ describe('DashboardModel', () => {
               datasource: null,
               allFormat: '',
             },
+            // @ts-expect-error
             {
               type: 'constant',
               hide: VariableHide.hideVariable,
@@ -965,79 +995,93 @@ describe('DashboardModel', () => {
       model = new DashboardModel({
         templating: {
           list: [
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_never_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 0,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_never_refresh_without_options',
               options: [],
               refresh: 0,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_dashboard_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 1,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_dashboard_refresh_without_options',
               options: [],
               refresh: 1,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_timerange_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 2,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_timerange_refresh_without_options',
               options: [],
               refresh: 2,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_no_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_no_refresh_without_options',
               options: [],
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_unknown_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 2001,
             },
+            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_unknown_refresh_without_options',
               options: [],
               refresh: 2001,
             },
+            // @ts-expect-error
             {
               type: 'custom',
               name: 'custom',
               options: [{ text: 'custom', value: 'custom' }],
             },
+            // @ts-expect-error
             {
               type: 'textbox',
               name: 'textbox',
               options: [{ text: 'Hello', value: 'World' }],
             },
+            // @ts-expect-error
             {
               type: 'datasource',
               name: 'datasource',
               options: [{ text: 'ds', value: 'ds' }], // fake example doesn't exist
             },
+            // @ts-expect-error
             {
               type: 'interval',
               name: 'interval',
@@ -1113,6 +1157,7 @@ describe('DashboardModel', () => {
             fieldConfig: {
               defaults: {
                 thresholds: {
+                  // @ts-expect-error
                   mode: 'absolute',
                   steps: [
                     {
@@ -1129,12 +1174,14 @@ describe('DashboardModel', () => {
                   {
                     id: 0,
                     text: '1',
+                    // @ts-expect-error
                     type: 1,
                     value: 'up',
                   },
                   {
                     id: 1,
                     text: 'BAD',
+                    // @ts-expect-error
                     type: 1,
                     value: 'down',
                   },
@@ -1143,6 +1190,7 @@ describe('DashboardModel', () => {
                     id: 2,
                     text: 'below 30',
                     to: '30',
+                    // @ts-expect-error
                     type: 2,
                   },
                   {
@@ -1150,9 +1198,11 @@ describe('DashboardModel', () => {
                     id: 3,
                     text: '100',
                     to: '100',
+                    // @ts-expect-error
                     type: 2,
                   },
                   {
+                    // @ts-expect-error
                     type: 1,
                     value: 'null',
                     text: 'it is null',
@@ -1244,6 +1294,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'timeseries',
+            // @ts-expect-error
             legend: true,
             options: {
               tooltipOptions: { mode: 'multi' },
@@ -1251,6 +1302,7 @@ describe('DashboardModel', () => {
           },
           {
             type: 'xychart',
+            // @ts-expect-error
             legend: true,
             options: {
               tooltipOptions: { mode: 'single' },
@@ -1259,15 +1311,15 @@ describe('DashboardModel', () => {
         ],
       });
       expect(model.panels[0].options).toMatchInlineSnapshot(`
-        Object {
-          "tooltip": Object {
+        {
+          "tooltip": {
             "mode": "multi",
           },
         }
       `);
       expect(model.panels[1].options).toMatchInlineSnapshot(`
-        Object {
-          "tooltip": Object {
+        {
+          "tooltip": {
             "mode": "single",
           },
         }
@@ -1281,6 +1333,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'singlestat',
+            // @ts-expect-error
             legend: true,
             thresholds: '10,20,30',
             colors: ['#FF0000', 'green', 'orange'],
@@ -1315,18 +1368,18 @@ describe('DashboardModel', () => {
         ],
       });
       expect(model.panels[0].fieldConfig.defaults.mappings).toMatchInlineSnapshot(`
-        Array [
-          Object {
-            "options": Object {
-              "20": Object {
+        [
+          {
+            "options": {
+              "20": {
                 "color": undefined,
                 "text": "test",
               },
-              "30": Object {
+              "30": {
                 "color": undefined,
                 "text": "test1",
               },
-              "40": Object {
+              "40": {
                 "color": "orange",
                 "text": "50",
               },
@@ -1342,6 +1395,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             type: 'singlestat',
+            // @ts-expect-error
             legend: true,
             thresholds: '10,20,30',
             colors: ['#FF0000', 'green', 'orange'],
@@ -1376,11 +1430,11 @@ describe('DashboardModel', () => {
         ],
       });
       expect(model.panels[0].fieldConfig.defaults.mappings).toMatchInlineSnapshot(`
-        Array [
-          Object {
-            "options": Object {
+        [
+          {
+            "options": {
               "from": 20,
-              "result": Object {
+              "result": {
                 "color": undefined,
                 "text": "text1",
               },
@@ -1388,10 +1442,10 @@ describe('DashboardModel', () => {
             },
             "type": "range",
           },
-          Object {
-            "options": Object {
+          {
+            "options": {
               "from": 1,
-              "result": Object {
+              "result": {
                 "color": undefined,
                 "text": "text2",
               },
@@ -1399,10 +1453,10 @@ describe('DashboardModel', () => {
             },
             "type": "range",
           },
-          Object {
-            "options": Object {
+          {
+            "options": {
               "from": 5,
-              "result": Object {
+              "result": {
                 "color": "orange",
                 "text": "50",
               },
@@ -1425,6 +1479,7 @@ describe('DashboardModel', () => {
           {
             id: 1,
             type: 'timeseries',
+            // @ts-expect-error
             panels: [
               {
                 id: 2,
@@ -1463,6 +1518,7 @@ describe('DashboardModel', () => {
           {
             id: 1,
             type: 'timeseries',
+            // @ts-expect-error
             transformations: [{ id: 'labelsToFields' }],
           },
         ],
@@ -1472,13 +1528,13 @@ describe('DashboardModel', () => {
     it('should create two transormatoins', () => {
       const xforms = model.panels[0].transformations;
       expect(xforms).toMatchInlineSnapshot(`
-        Array [
-          Object {
+        [
+          {
             "id": "labelsToFields",
           },
-          Object {
+          {
             "id": "merge",
-            "options": Object {},
+            "options": {},
           },
         ]
       `);
@@ -1494,6 +1550,7 @@ describe('DashboardModel', () => {
         annotations: {
           list: [
             {
+              // @ts-expect-error
               actionPrefix: '',
               alarmNamePrefix: '',
               alias: '',
@@ -1516,6 +1573,7 @@ describe('DashboardModel', () => {
           ],
         },
         panels: [
+          // @ts-expect-error
           {
             gridPos: {
               h: 8,
@@ -1603,6 +1661,7 @@ describe('DashboardModel', () => {
           annotations: {
             list: [
               {
+                // @ts-expect-error
                 actionPrefix: '',
                 alarmNamePrefix: '',
                 alias: '',
@@ -1637,6 +1696,7 @@ describe('DashboardModel', () => {
               title: 'DynamoDB',
               type: 'row',
               panels: [
+                // @ts-expect-error
                 {
                   gridPos: {
                     h: 8,
@@ -1691,6 +1751,7 @@ describe('DashboardModel', () => {
                   title: 'Panel Title',
                   type: 'timeseries',
                 },
+                // @ts-expect-error
                 {
                   gridPos: {
                     h: 8,
@@ -1794,6 +1855,7 @@ describe('DashboardModel', () => {
               name: 'var',
               options: [{ text: 'A', value: 'A' }],
               refresh: 0,
+              // @ts-expect-error
               datasource: 'prom',
             },
           ],
@@ -1801,19 +1863,28 @@ describe('DashboardModel', () => {
         panels: [
           {
             id: 1,
+            // @ts-expect-error
             datasource: 'prom',
           },
           {
             id: 2,
+            // @ts-expect-error
             datasource: null,
           },
           {
             id: 3,
+            // @ts-expect-error
             datasource: MIXED_DATASOURCE_NAME,
             targets: [
               {
                 datasource: 'prom',
               },
+              {
+                datasource: 'default',
+              },
+              {
+                datasource: null,
+              },
             ],
           },
           {
@@ -1822,6 +1893,7 @@ describe('DashboardModel', () => {
             panels: [
               {
                 id: 6,
+                // @ts-expect-error
                 datasource: 'prom',
               },
             ],
@@ -1848,6 +1920,8 @@ describe('DashboardModel', () => {
 
     it('should update target datasource props to refs', () => {
       expect(model.panels[2].targets[0].datasource).toEqual({ type: 'prometheus', uid: 'prom-uid' });
+      expect(model.panels[2].targets[1].datasource).toEqual({ type: 'prometheus', uid: 'prom2-uid' });
+      expect(model.panels[2].targets[2].datasource).toEqual({ type: 'prometheus', uid: 'prom2-uid' });
     });
 
     it('should update datasources in panels collapsed rows', () => {
@@ -1866,6 +1940,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             id: 2,
+            // @ts-expect-error
             datasource: null,
             targets: [
               {
@@ -1887,6 +1962,7 @@ describe('DashboardModel', () => {
     test('preserves x axis visibility', () => {
       const model = new DashboardModel({
         panels: [
+          // @ts-expect-error
           {
             type: 'timeseries',
             fieldConfig: {
@@ -1902,14 +1978,14 @@ describe('DashboardModel', () => {
       });
 
       expect(model.panels[0].fieldConfig.overrides).toMatchInlineSnapshot(`
-        Array [
-          Object {
-            "matcher": Object {
+        [
+          {
+            "matcher": {
               "id": "byType",
               "options": "time",
             },
-            "properties": Array [
-              Object {
+            "properties": [
+              {
                 "id": "custom.axisPlacement",
                 "value": "auto",
               },
@@ -1927,6 +2003,7 @@ describe('DashboardModel', () => {
       model = new DashboardModel({
         templating: {
           list: [
+            // @ts-expect-error
             {
               type: 'query',
               name: 'var',
@@ -1938,10 +2015,12 @@ describe('DashboardModel', () => {
         },
         annotations: {
           list: [
+            // @ts-expect-error
             {
               datasource: null,
             },
             {
+              // @ts-expect-error
               datasource: 'prom',
             },
           ],
@@ -1949,6 +2028,7 @@ describe('DashboardModel', () => {
         panels: [
           {
             id: 2,
+            // @ts-expect-error
             datasource: null,
             targets: [
               {
@@ -1956,6 +2036,7 @@ describe('DashboardModel', () => {
               },
             ],
           },
+          // @ts-expect-error
           {
             id: 3,
             targets: [
@@ -2000,6 +2081,7 @@ describe('DashboardModel', () => {
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
+          // @ts-expect-error
           {
             id: 2,
             targets: [
@@ -2027,6 +2109,298 @@ describe('DashboardModel', () => {
   });
 });
 
+describe('when generating the legend for a panel', () => {
+  let model: DashboardModel;
+
+  beforeEach(() => {
+    model = new DashboardModel({
+      panels: [
+        // @ts-expect-error
+        {
+          id: 0,
+          options: {
+            legend: {
+              displayMode: 'hidden',
+              placement: 'bottom',
+            },
+            tooltipOptions: {
+              mode: 'single',
+            },
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 1,
+          options: {
+            legend: {
+              displayMode: 'list',
+              placement: 'right',
+            },
+            tooltipOptions: {
+              mode: 'single',
+            },
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 2,
+          options: {
+            legend: {
+              displayMode: 'table',
+              placement: 'bottom',
+            },
+            tooltipOptions: {
+              mode: 'single',
+            },
+          },
+        },
+      ],
+      schemaVersion: 30,
+    });
+  });
+
+  it('should update displayMode = hidden to showLegend = false and displayMode = list', () => {
+    expect(model.panels[0].options.legend).toEqual({ displayMode: 'list', showLegend: false, placement: 'bottom' });
+  });
+
+  it('should keep displayMode = list and update to showLegend = true', () => {
+    expect(model.panels[1].options.legend).toEqual({ displayMode: 'list', showLegend: true, placement: 'right' });
+  });
+
+  it('should keep displayMode = table and update to showLegend = true', () => {
+    expect(model.panels[2].options.legend).toEqual({ displayMode: 'table', showLegend: true, placement: 'bottom' });
+  });
+
+  it('should preserve the placement', () => {
+    expect(model.panels[0].options.legend.placement).toEqual('bottom');
+    expect(model.panels[1].options.legend.placement).toEqual('right');
+    expect(model.panels[2].options.legend.placement).toEqual('bottom');
+  });
+});
+
+describe('when migrating table cell display mode to cell options', () => {
+  let model: DashboardModel;
+
+  beforeEach(() => {
+    model = new DashboardModel({
+      panels: [
+        // @ts-expect-error
+        {
+          id: 1,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'color-background',
+                inspect: false,
+              },
+            },
+          } as unknown as FieldConfigSource, // missing overrides
+        },
+        // @ts-expect-error
+        {
+          id: 2,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'color-background-solid',
+                inspect: false,
+              },
+            },
+            overrides: [],
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 3,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'lcd-gauge',
+                inspect: false,
+              },
+            },
+            overrides: [],
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 4,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'gradient-gauge',
+                inspect: false,
+              },
+            },
+            overrides: [],
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 5,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'basic',
+                inspect: false,
+              },
+            },
+            overrides: [],
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 6,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'auto',
+                inspect: false,
+              },
+            },
+            overrides: [
+              {
+                matcher: {
+                  id: 'byName',
+                  options: 'value',
+                },
+                properties: [
+                  {
+                    id: 'custom.displayMode',
+                    value: 'color-background',
+                  },
+                ],
+              },
+              {
+                matcher: {
+                  id: 'byName',
+                  options: 'value2',
+                },
+                properties: [
+                  {
+                    id: 'custom.displayMode',
+                    value: 'lcd-gauge',
+                  },
+                ],
+              },
+              {
+                matcher: {
+                  id: 'byName',
+                  options: 'value3',
+                },
+                properties: [
+                  {
+                    id: 'custom.displayMode',
+                    value: 'gradient-gauge',
+                  },
+                ],
+              },
+              {
+                matcher: {
+                  id: 'byName',
+                  options: 'value4',
+                },
+                properties: [
+                  {
+                    id: 'custom.align',
+                    value: 'left',
+                  },
+                  {
+                    id: 'custom.displayMode',
+                    value: 'gradient-gauge',
+                  },
+                ],
+              },
+            ],
+          },
+        },
+        // @ts-expect-error
+        {
+          id: 7,
+          type: 'table',
+          fieldConfig: {
+            defaults: {
+              custom: {
+                align: 'auto',
+                displayMode: 'auto',
+                inspect: false,
+              },
+            },
+            overrides: [],
+          },
+        },
+      ],
+      schemaVersion: 37,
+    });
+  });
+
+  it('should migrate gradient color background option to the new option format', () => {
+    const cellOptions = model.panels[0].fieldConfig.defaults.custom.cellOptions;
+    expect(cellOptions).toEqual({ type: 'color-background', mode: 'gradient' });
+  });
+
+  it('should migrate solid color background option to the new option format', () => {
+    const cellOptions = model.panels[1].fieldConfig.defaults.custom.cellOptions;
+    expect(cellOptions).toEqual({ type: 'color-background', mode: 'basic' });
+  });
+
+  it('should migrate LCD gauge option to the new option format', () => {
+    const cellOptions = model.panels[2].fieldConfig.defaults.custom.cellOptions;
+    expect(cellOptions).toEqual({ type: 'gauge', mode: 'lcd' });
+  });
+
+  it('should migrate gradient gauge option to the new option format', () => {
+    const cellOptions = model.panels[3].fieldConfig.defaults.custom.cellOptions;
+    expect(cellOptions).toEqual({ type: 'gauge', mode: 'gradient' });
+  });
+
+  it('should migrate basic gauge option to the new option format', () => {
+    const cellOptions = model.panels[4].fieldConfig.defaults.custom.cellOptions;
+    expect(cellOptions).toEqual({ type: 'gauge', mode: 'basic' });
+  });
+
+  it('should migrate from display mode to cell options in field overrides', () => {
+    const fieldConfig = model.panels[5].fieldConfig;
+
+    expect(fieldConfig.overrides[0].properties[0]).toEqual({
+      id: 'custom.cellOptions',
+      value: { type: 'color-background', mode: 'gradient' },
+    });
+
+    expect(fieldConfig.overrides[1].properties[0]).toEqual({
+      id: 'custom.cellOptions',
+      value: { type: 'gauge', mode: 'lcd' },
+    });
+
+    expect(fieldConfig.overrides[2].properties[0]).toEqual({
+      id: 'custom.cellOptions',
+      value: { type: 'gauge', mode: 'gradient' },
+    });
+  });
+
+  it('should migrate from display mode to cell options in field overrides with other overrides present', () => {
+    const override = model.panels[5].fieldConfig.overrides[3];
+    expect(override.properties[1]).toEqual({ id: 'custom.cellOptions', value: { type: 'gauge', mode: 'gradient' } });
+  });
+
+  it('should migrate cell display modes without options', () => {
+    const fieldConfig = model.panels[6].fieldConfig;
+    expect(fieldConfig.defaults.custom.cellOptions).toEqual({ type: 'auto' });
+  });
+});
+
 function createRow(options: any, panelDescriptions: any[]) {
   const PANEL_HEIGHT_STEP = GRID_CELL_HEIGHT + GRID_CELL_VMARGIN;
   const { collapse, showTitle, title, repeat, repeatIteration } = options;
