@@ -1,5 +1,7 @@
 import { keys as _keys } from 'lodash';
 
+import { dateTime, TimeRange, VariableHide } from '@grafana/data';
+import { defaultVariableModel } from '@grafana/schema';
 import { contextSrv } from 'app/core/services/context_srv';
 
 import { getDashboardModel } from '../../../../test/helpers/getDashboardModel';
@@ -11,9 +13,16 @@ import { setTimeSrv, TimeSrv } from '../services/TimeSrv';
 import { DashboardModel } from '../state/DashboardModel';
 import { PanelModel } from '../state/PanelModel';
 
+import {
+  createAnnotationJSONFixture,
+  createDashboardModelFixture,
+  createPanelJSONFixture,
+  createVariableJSONFixture,
+} from './__fixtures__/dashboardFixtures';
+
 jest.mock('app/core/services/context_srv');
 
-const mockContextSrv = jest.mocked(contextSrv, true);
+const mockContextSrv = jest.mocked(contextSrv);
 
 variableAdapters.setInit(() => [
   createQueryVariableAdapter(),
@@ -26,7 +35,7 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({}, {});
+      model = createDashboardModelFixture();
     });
 
     it('should have title', () => {
@@ -47,8 +56,8 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({
-        panels: [{ id: 5 }],
+      model = createDashboardModelFixture({
+        panels: [createPanelJSONFixture({ id: 5 })],
       });
     });
 
@@ -57,10 +66,28 @@ describe('DashboardModel', () => {
     });
   });
 
+  describe('when initalized with duplicate panel ids', () => {
+    let model: DashboardModel;
+
+    beforeEach(() => {
+      model = createDashboardModelFixture({
+        panels: [
+          createPanelJSONFixture({ id: 6 }),
+          createPanelJSONFixture({ id: 2 }),
+          createPanelJSONFixture({}), // undefined
+          createPanelJSONFixture({ id: 2 }),
+        ],
+      });
+    });
+
+    it('should ensure unique panel ids', () => {
+      expect(model.panels.map((p) => p.id)).toEqual([6, 2, 7, 8]);
+    });
+  });
+
   describe('getSaveModelClone', () => {
     it('should sort keys', () => {
-      const model = new DashboardModel({});
-      model.autoUpdate = null;
+      const model = createDashboardModelFixture();
 
       const saveModel = model.getSaveModelClone();
       const keys = _keys(saveModel);
@@ -70,7 +97,7 @@ describe('DashboardModel', () => {
     });
 
     it('should remove add panel panels', () => {
-      const model = new DashboardModel({});
+      const model = createDashboardModelFixture();
       model.addPanel({
         type: 'add-panel',
       });
@@ -87,7 +114,7 @@ describe('DashboardModel', () => {
     });
 
     it('should save model in edit mode', () => {
-      const model = new DashboardModel({});
+      const model = createDashboardModelFixture();
       model.addPanel({ type: 'graph' });
 
       const panel = model.initEditPanel(model.panels[0]);
@@ -105,7 +132,7 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({});
+      dashboard = createDashboardModelFixture();
     });
 
     it('adding panel should new up panel model', () => {
@@ -148,7 +175,7 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({ editable: false });
+      model = createDashboardModelFixture({ editable: false });
     });
 
     it('Should set meta canEdit and canSave to false', () => {
@@ -167,12 +194,11 @@ describe('DashboardModel', () => {
     let target: any;
 
     beforeEach(() => {
-      model = new DashboardModel({
+      model = createDashboardModelFixture({
+        schemaVersion: 1,
         panels: [
-          {
+          createPanelJSONFixture({
             type: 'graph',
-            grid: {},
-            yaxes: [{}, {}],
             targets: [
               {
                 alias: '$tag_datacenter $tag_source $col',
@@ -211,7 +237,7 @@ describe('DashboardModel', () => {
                 ],
               },
             ],
-          },
+          }),
         ],
       });
 
@@ -233,13 +259,9 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({
-        annotations: {
-          enable: true,
-        },
-        templating: {
-          enable: true,
-        },
+      model = createDashboardModelFixture({
+        annotations: {},
+        templating: {},
       });
     });
 
@@ -258,7 +280,7 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({ timezone: 'utc' });
+      dashboard = createDashboardModelFixture({ timezone: 'utc' });
     });
 
     it('Should format timestamp with second resolution by default', () => {
@@ -278,7 +300,7 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({});
+      model = createDashboardModelFixture();
     });
 
     it('should not show submenu', () => {
@@ -290,9 +312,19 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({
+      model = createDashboardModelFixture({
+        schemaVersion: 30,
         annotations: {
-          list: [{}],
+          list: [
+            {
+              datasource: { uid: 'fake-uid', type: 'prometheus' },
+              name: 'Fake annotation',
+              type: 'dashboard',
+              iconColor: 'rgba(0, 211, 255, 1)',
+              enable: true,
+              hide: false,
+            },
+          ],
         },
       });
     });
@@ -306,15 +338,15 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel(
+      model = createDashboardModelFixture(
         {
           templating: {
-            list: [{}],
+            list: [createVariableJSONFixture({})],
           },
         },
         {},
         // getVariablesFromState stub to return a variable
-        () => [{} as any]
+        jest.fn().mockImplementation(() => [{}])
       );
     });
 
@@ -327,9 +359,14 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      model = new DashboardModel({
+      model = createDashboardModelFixture({
         templating: {
-          list: [{ hide: 2 }],
+          list: [
+            {
+              ...defaultVariableModel,
+              hide: VariableHide.hideVariable,
+            },
+          ],
         },
       });
     });
@@ -343,9 +380,9 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({
+      dashboard = createDashboardModelFixture({
         annotations: {
-          list: [{ hide: true }],
+          list: [createAnnotationJSONFixture({ hide: true })],
         },
       });
     });
@@ -359,13 +396,13 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({
+      dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'graph', gridPos: { x: 0, y: 0, w: 24, h: 2 } },
-          { id: 2, type: 'row', gridPos: { x: 0, y: 2, w: 24, h: 2 } },
-          { id: 3, type: 'graph', gridPos: { x: 0, y: 4, w: 12, h: 2 } },
-          { id: 4, type: 'graph', gridPos: { x: 12, y: 4, w: 12, h: 2 } },
-          { id: 5, type: 'row', gridPos: { x: 0, y: 6, w: 24, h: 2 } },
+          createPanelJSONFixture({ id: 1, type: 'graph', gridPos: { x: 0, y: 0, w: 24, h: 2 } }),
+          createPanelJSONFixture({ id: 2, type: 'row', gridPos: { x: 0, y: 2, w: 24, h: 2 } }),
+          createPanelJSONFixture({ id: 3, type: 'graph', gridPos: { x: 0, y: 4, w: 12, h: 2 } }),
+          createPanelJSONFixture({ id: 4, type: 'graph', gridPos: { x: 12, y: 4, w: 12, h: 2 } }),
+          createPanelJSONFixture({ id: 5, type: 'row', gridPos: { x: 0, y: 6, w: 24, h: 2 } }),
         ],
       });
       dashboard.toggleRow(dashboard.panels[1]);
@@ -410,7 +447,7 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({
+      dashboard = createDashboardModelFixture({
         panels: [
           { id: 1, type: 'graph', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           {
@@ -423,7 +460,7 @@ describe('DashboardModel', () => {
               { id: 4, type: 'graph', gridPos: { x: 12, y: 7, w: 12, h: 2 } },
             ],
           },
-          { id: 5, type: 'row', gridPos: { x: 0, y: 7, w: 1, h: 1 } },
+          { id: 5, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 7, w: 1, h: 1 } },
         ],
       });
       dashboard.toggleRow(dashboard.panels[1]);
@@ -481,7 +518,7 @@ describe('DashboardModel', () => {
     let dashboard: DashboardModel;
 
     beforeEach(() => {
-      dashboard = new DashboardModel({
+      dashboard = createDashboardModelFixture({
         panels: [
           { id: 1, type: 'graph', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           {
@@ -490,11 +527,14 @@ describe('DashboardModel', () => {
             gridPos: { x: 0, y: 6, w: 24, h: 1 },
             collapsed: true,
             panels: [
+              // this whole test is about dealing with out-of-spec (or at least ambigious) data...
+              //@ts-expect-error
               { id: 3, type: 'graph', gridPos: { w: 12, h: 2 } },
+              //@ts-expect-error
               { id: 4, type: 'graph', gridPos: { w: 12, h: 2 } },
             ],
           },
-          { id: 5, type: 'row', gridPos: { x: 0, y: 7, w: 1, h: 1 } },
+          { id: 5, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 7, w: 1, h: 1 } },
         ],
       });
       dashboard.toggleRow(dashboard.panels[1]);
@@ -523,7 +563,7 @@ describe('DashboardModel', () => {
 
     beforeEach(() => {
       consoleWarnSpy = jest.spyOn(console, 'warn').mockImplementation(() => {});
-      model = new DashboardModel({
+      model = createDashboardModelFixture({
         time: {
           from: 'now-6h',
           to: 'now',
@@ -621,8 +661,8 @@ describe('DashboardModel', () => {
       model.processRepeats();
       expect(model.panels.filter((x) => x.type === 'row')).toHaveLength(2);
       expect(model.panels.filter((x) => x.type !== 'row')).toHaveLength(4);
-      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.dc.value).toBe('dc1');
-      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.app.value).toBe('se1');
+      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.dc?.value).toBe('dc1');
+      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.app?.value).toBe('se1');
 
       const saveModel = model.getSaveModelClone();
       expect(saveModel.panels.length).toBe(2);
@@ -630,8 +670,8 @@ describe('DashboardModel', () => {
       expect(saveModel.panels[1].scopedVars).toBe(undefined);
 
       model.collapseRows();
-      const savedModelWithCollapsedRows: any = model.getSaveModelClone();
-      expect(savedModelWithCollapsedRows.panels[0].panels.length).toBe(1);
+      const savedModelWithCollapsedRows = model.getSaveModelClone();
+      expect(savedModelWithCollapsedRows.panels[0].panels!.length).toBe(1);
     });
 
     it('getSaveModelClone should not remove repeated panels and scopedVars during snapshot', () => {
@@ -674,19 +714,19 @@ describe('DashboardModel', () => {
       model.processRepeats();
       expect(model.panels.filter((x) => x.type === 'row')).toHaveLength(2);
       expect(model.panels.filter((x) => x.type !== 'row')).toHaveLength(4);
-      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.dc.value).toBe('dc1');
-      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.app.value).toBe('se1');
+      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.dc?.value).toBe('dc1');
+      expect(model.panels.find((x) => x.type !== 'row')?.scopedVars?.app?.value).toBe('se1');
 
       model.snapshot = { timestamp: new Date() };
       const saveModel = model.getSaveModelClone();
       expect(saveModel.panels.filter((x) => x.type === 'row')).toHaveLength(2);
       expect(saveModel.panels.filter((x) => x.type !== 'row')).toHaveLength(4);
-      expect(saveModel.panels.find((x) => x.type !== 'row')?.scopedVars?.dc.value).toBe('dc1');
-      expect(saveModel.panels.find((x) => x.type !== 'row')?.scopedVars?.app.value).toBe('se1');
+      expect(saveModel.panels.find((x) => x.type !== 'row')?.scopedVars?.dc?.value).toBe('dc1');
+      expect(saveModel.panels.find((x) => x.type !== 'row')?.scopedVars?.app?.value).toBe('se1');
 
       model.collapseRows();
-      const savedModelWithCollapsedRows: any = model.getSaveModelClone();
-      expect(savedModelWithCollapsedRows.panels[0].panels.length).toBe(2);
+      const savedModelWithCollapsedRows = model.getSaveModelClone();
+      expect(savedModelWithCollapsedRows.panels[0].panels!.length).toBe(2);
     });
   });
 
@@ -838,14 +878,13 @@ describe('DashboardModel', () => {
     let model: DashboardModel;
 
     beforeEach(() => {
-      const data = {
+      model = createDashboardModelFixture({
         panels: [
           { id: 1, type: 'graph', gridPos: { x: 0, y: 0, w: 24, h: 2 }, legend: { show: true } },
           { id: 3, type: 'graph', gridPos: { x: 0, y: 4, w: 12, h: 2 }, legend: { show: false } },
           { id: 4, type: 'graph', gridPos: { x: 12, y: 4, w: 12, h: 2 }, legend: { show: false } },
         ],
-      };
-      model = new DashboardModel(data);
+      });
     });
 
     it('toggleLegendsForAll should toggle all legends on on first execution', () => {
@@ -876,7 +915,7 @@ describe('DashboardModel', () => {
     `(
       'when called with canEdit:{$canEdit}, canMakeEditable:{$canMakeEditable}, canAdd:{$canAdd} and expected:{$expected}',
       ({ canEdit, canMakeEditable, canAdd, expected }) => {
-        const dashboard = new DashboardModel(
+        const dashboard = createDashboardModelFixture(
           {},
           {
             annotationsPermissions: {
@@ -909,7 +948,7 @@ describe('DashboardModel', () => {
     `(
       'when called with canEdit:{$canEdit}, canMakeEditable:{$canMakeEditable}, canEditWithOrgPermission:{$canEditWithOrgPermission} and expected:{$expected}',
       ({ canEdit, canMakeEditable, canEditWithOrgPermission, expected }) => {
-        const dashboard = new DashboardModel(
+        const dashboard = createDashboardModelFixture(
           {},
           {
             annotationsPermissions: {
@@ -940,7 +979,7 @@ describe('DashboardModel', () => {
     `(
       'when called with canEdit:{$canEdit}, canMakeEditable:{$canMakeEditable}, canEditWithDashboardPermission:{$canEditWithDashboardPermission} and expected:{$expected}',
       ({ canEdit, canMakeEditable, canEditWithDashboardPermission, expected }) => {
-        const dashboard = new DashboardModel(
+        const dashboard = createDashboardModelFixture(
           {},
           {
             annotationsPermissions: {
@@ -973,7 +1012,7 @@ describe('DashboardModel', () => {
     `(
       'when called with canEdit:{$canEdit}, canMakeEditable:{$canMakeEditable}, canDeleteWithOrgPermission:{$canDeleteWithOrgPermission} and expected:{$expected}',
       ({ canEdit, canMakeEditable, canDeleteWithOrgPermission, expected }) => {
-        const dashboard = new DashboardModel(
+        const dashboard = createDashboardModelFixture(
           {},
           {
             annotationsPermissions: {
@@ -1004,7 +1043,7 @@ describe('DashboardModel', () => {
     `(
       'when called with canEdit:{$canEdit}, canMakeEditable:{$canMakeEditable}, canDeleteWithDashboardPermission:{$canDeleteWithDashboardPermission} and expected:{$expected}',
       ({ canEdit, canMakeEditable, canDeleteWithDashboardPermission, expected }) => {
-        const dashboard = new DashboardModel(
+        const dashboard = createDashboardModelFixture(
           {},
           {
             annotationsPermissions: {
@@ -1025,9 +1064,9 @@ describe('DashboardModel', () => {
 
   describe('canEditPanel', () => {
     it('returns false if the dashboard cannot be edited', () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'row', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
+          { id: 1, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           { id: 2, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 } },
         ],
       });
@@ -1037,9 +1076,9 @@ describe('DashboardModel', () => {
     });
 
     it('returns false if no panel is passed in', () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'row', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
+          { id: 1, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           { id: 2, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 } },
         ],
       });
@@ -1047,9 +1086,9 @@ describe('DashboardModel', () => {
     });
 
     it('returns false if the panel is a repeat', () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'row', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
+          { id: 1, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           { id: 2, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 } },
           { id: 3, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 }, repeatPanelId: 2 },
         ],
@@ -1059,9 +1098,9 @@ describe('DashboardModel', () => {
     });
 
     it('returns false if the panel is a row', () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'row', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
+          { id: 1, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           { id: 2, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 } },
         ],
       });
@@ -1070,9 +1109,9 @@ describe('DashboardModel', () => {
     });
 
     it('returns true otherwise', () => {
-      const dashboard = new DashboardModel({
+      const dashboard = createDashboardModelFixture({
         panels: [
-          { id: 1, type: 'row', gridPos: { x: 0, y: 0, w: 24, h: 6 } },
+          { id: 1, type: 'row', collapsed: false, panels: [], gridPos: { x: 0, y: 0, w: 24, h: 6 } },
           { id: 2, type: 'graph', gridPos: { x: 0, y: 7, w: 12, h: 2 } },
         ],
       });
@@ -1084,8 +1123,8 @@ describe('DashboardModel', () => {
 
 describe('exitViewPanel', () => {
   function getTestContext() {
-    const panel: any = { setIsViewing: jest.fn() };
-    const dashboard = new DashboardModel({});
+    const panel = new PanelModel({ setIsViewing: jest.fn() });
+    const dashboard = createDashboardModelFixture();
     dashboard.startRefresh = jest.fn();
     dashboard.panelInView = panel;
 
@@ -1119,10 +1158,37 @@ describe('exitViewPanel', () => {
   });
 });
 
-describe('exitPanelEditor', () => {
-  function getTestContext(pauseAutoRefresh = false) {
-    const panel: any = { destroy: jest.fn() };
-    const dashboard = new DashboardModel({});
+describe('when initEditPanel is called', () => {
+  function getTestContext() {
+    const dashboard = createDashboardModelFixture();
+    const timeSrvMock = {
+      pauseAutoRefresh: jest.fn(),
+      resumeAutoRefresh: jest.fn(),
+      stopAutoRefresh: jest.fn(),
+    } as unknown as TimeSrv;
+    setTimeSrv(timeSrvMock);
+    return { dashboard, timeSrvMock };
+  }
+
+  it('should set panelInEdit', () => {
+    const { dashboard } = getTestContext();
+    dashboard.addPanel({ type: 'timeseries' });
+    dashboard.initEditPanel(dashboard.panels[0]);
+    expect(dashboard.panelInEdit).not.toBeUndefined();
+  });
+
+  it('should stop auto-refresh', () => {
+    const { dashboard, timeSrvMock } = getTestContext();
+    dashboard.addPanel({ type: 'timeseries' });
+    dashboard.initEditPanel(dashboard.panels[0]);
+    expect(timeSrvMock.stopAutoRefresh).toHaveBeenCalled();
+  });
+});
+
+describe('when exitPanelEditor is called', () => {
+  function getTestContext() {
+    const panel = new PanelModel({ destroy: jest.fn() });
+    const dashboard = createDashboardModelFixture();
     const timeSrvMock = {
       pauseAutoRefresh: jest.fn(),
       resumeAutoRefresh: jest.fn(),
@@ -1130,70 +1196,54 @@ describe('exitPanelEditor', () => {
     } as unknown as TimeSrv;
     dashboard.startRefresh = jest.fn();
     dashboard.panelInEdit = panel;
-    if (pauseAutoRefresh) {
-      timeSrvMock.autoRefreshPaused = true;
-    }
     setTimeSrv(timeSrvMock);
     return { dashboard, panel, timeSrvMock };
   }
 
-  describe('when called', () => {
-    it('then panelInEdit is set to undefined', () => {
-      const { dashboard } = getTestContext();
+  it('should set panelInEdit to undefined', () => {
+    const { dashboard } = getTestContext();
 
-      dashboard.exitPanelEditor();
+    dashboard.exitPanelEditor();
 
-      expect(dashboard.panelInEdit).toBeUndefined();
-    });
+    expect(dashboard.panelInEdit).toBeUndefined();
+  });
 
-    it('then destroy is called on panel', () => {
-      const { dashboard, panel } = getTestContext();
+  it('should destroy panel', () => {
+    const { dashboard, panel } = getTestContext();
 
-      dashboard.exitPanelEditor();
+    dashboard.exitPanelEditor();
 
-      expect(panel.destroy).toHaveBeenCalled();
-    });
+    expect(panel.destroy).toHaveBeenCalled();
+  });
 
-    it('then startRefresh is not called', () => {
-      const { dashboard } = getTestContext();
+  it('should not call startRefresh', () => {
+    const { dashboard } = getTestContext();
 
-      dashboard.exitPanelEditor();
+    dashboard.exitPanelEditor();
 
-      expect(dashboard.startRefresh).not.toHaveBeenCalled();
-    });
+    expect(dashboard.startRefresh).not.toHaveBeenCalled();
+  });
 
-    it('then auto refresh property is resumed', () => {
-      const { dashboard, timeSrvMock } = getTestContext(true);
-      dashboard.exitPanelEditor();
-      expect(timeSrvMock.resumeAutoRefresh).toHaveBeenCalled();
-    });
-  });
-});
+  it('should call startRefresh if time range changed during edit', () => {
+    const { dashboard } = getTestContext();
 
-describe('initEditPanel', () => {
-  function getTestContext() {
-    const dashboard = new DashboardModel({});
-    const timeSrvMock = {
-      pauseAutoRefresh: jest.fn(),
-      resumeAutoRefresh: jest.fn(),
-    } as unknown as TimeSrv;
-    setTimeSrv(timeSrvMock);
-    return { dashboard, timeSrvMock };
-  }
+    const range: TimeRange = {
+      from: dateTime(new Date().getTime()).subtract(1, 'minutes'),
+      to: dateTime(new Date().getTime()),
+      raw: {
+        from: 'now-1m',
+        to: 'now',
+      },
+    };
+    dashboard.timeRangeUpdated(range);
+    dashboard.exitPanelEditor();
 
-  describe('when called', () => {
-    it('then panelInEdit is not undefined', () => {
-      const { dashboard } = getTestContext();
-      dashboard.addPanel({ type: 'timeseries' });
-      dashboard.initEditPanel(dashboard.panels[0]);
-      expect(dashboard.panelInEdit).not.toBeUndefined();
-    });
+    expect(dashboard.startRefresh).toHaveBeenCalled();
+  });
 
-    it('then auto-refresh is paused', () => {
-      const { dashboard, timeSrvMock } = getTestContext();
-      dashboard.addPanel({ type: 'timeseries' });
-      dashboard.initEditPanel(dashboard.panels[0]);
-      expect(timeSrvMock.pauseAutoRefresh).toHaveBeenCalled();
-    });
+  it('then auto refresh property is resumed', () => {
+    const { dashboard, timeSrvMock } = getTestContext();
+    dashboard.exitPanelEditor();
+    expect(timeSrvMock.resumeAutoRefresh).toHaveBeenCalled();
   });
 });
