@@ -1,15 +1,19 @@
 import { DataSourcePluginMeta, DataSourceSettings, UrlQueryValue } from '@grafana/data';
-import { DataSourcesState } from '../../../types/datasources';
+import { DataSourcesState } from 'app/types/datasources';
 
 export const getDataSources = (state: DataSourcesState) => {
   const regex = new RegExp(state.searchQuery, 'i');
 
-  return state.dataSources.filter((dataSource: DataSourceSettings) => {
+  const filteredDataSources = state.dataSources.filter((dataSource: DataSourceSettings) => {
     return regex.test(dataSource.name) || regex.test(dataSource.database) || regex.test(dataSource.type);
   });
+
+  return filteredDataSources.sort((a, b) =>
+    state.isSortAscending ? a.name.localeCompare(b.name) : b.name.localeCompare(a.name)
+  );
 };
 
-export const getDataSourcePlugins = (state: DataSourcesState) => {
+export const getFilteredDataSourcePlugins = (state: DataSourcesState) => {
   const regex = new RegExp(state.dataSourceTypeSearchQuery, 'i');
 
   return state.plugins.filter((type: DataSourcePluginMeta) => {
@@ -18,7 +22,7 @@ export const getDataSourcePlugins = (state: DataSourcesState) => {
 };
 
 export const getDataSource = (state: DataSourcesState, dataSourceId: UrlQueryValue): DataSourceSettings => {
-  if (state.dataSource.id === parseInt(dataSourceId as string, 10)) {
+  if (state.dataSource.uid === dataSourceId) {
     return state.dataSource;
   }
   return {} as DataSourceSettings;
@@ -35,3 +39,4 @@ export const getDataSourceMeta = (state: DataSourcesState, type: string): DataSo
 export const getDataSourcesSearchQuery = (state: DataSourcesState) => state.searchQuery;
 export const getDataSourcesLayoutMode = (state: DataSourcesState) => state.layoutMode;
 export const getDataSourcesCount = (state: DataSourcesState) => state.dataSourcesCount;
+export const getDataSourcesSort = (state: DataSourcesState) => state.isSortAscending;
