@@ -1,6 +1,7 @@
 import { DataFrame } from '@grafana/data';
+import { ResourceDimensionConfig, ResourceDimensionMode } from '@grafana/schema';
 
-import { DimensionSupplier, ResourceDimensionConfig, ResourceDimensionMode } from './types';
+import { DimensionSupplier } from './types';
 import { findField, getLastNotNullFieldValue } from './utils';
 
 //---------------------------------------------------------
@@ -43,7 +44,7 @@ export function getResourceDimension(
     const mapper = (v: string) => getPublicOrAbsoluteUrl(`${v}`);
     return {
       field,
-      get: (i) => mapper(field.values.get(i)),
+      get: (i) => mapper(field.values[i]),
       value: () => mapper(getLastNotNullFieldValue(field)),
     };
   }
@@ -60,7 +61,7 @@ export function getResourceDimension(
 
   return {
     field,
-    get: (index: number): string => getIcon(field.values.get(index)),
+    get: (index: number): string => getIcon(field.values[index]),
     value: () => getIcon(getLastNotNullFieldValue(field)),
   };
 }
