@@ -1,8 +1,8 @@
-import { css, cx } from '@emotion/css';
+import { css } from '@emotion/css';
 import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Button, HorizontalGroup, useTheme2 } from '@grafana/ui';
+import { HorizontalGroup, ToolbarButton, useTheme2 } from '@grafana/ui';
 
 type Props = {
   addQueryRowButtonDisabled?: boolean;
@@ -23,6 +23,7 @@ const getStyles = (theme: GrafanaTheme2) => {
     `,
   };
 };
+
 export function SecondaryActions(props: Props) {
   const theme = useTheme2();
   const styles = getStyles(theme);
@@ -30,36 +31,34 @@ export function SecondaryActions(props: Props) {
     <div className={styles.containerMargin}>
       <HorizontalGroup>
         {!props.addQueryRowButtonHidden && (
-          <Button
-            variant="secondary"
+          <ToolbarButton
+            variant="canvas"
             aria-label="Add row button"
             onClick={props.onClickAddQueryRowButton}
             disabled={props.addQueryRowButtonDisabled}
             icon="plus"
           >
             Add query
-          </Button>
+          </ToolbarButton>
         )}
         {!props.richHistoryRowButtonHidden && (
-          <Button
-            variant="secondary"
+          <ToolbarButton
+            variant={props.richHistoryButtonActive ? 'active' : 'canvas'}
             aria-label="Rich history button"
-            className={cx({ ['explore-active-button']: props.richHistoryButtonActive })}
             onClick={props.onClickRichHistoryButton}
             icon="history"
           >
             Query history
-          </Button>
+          </ToolbarButton>
         )}
-        <Button
-          variant="secondary"
+        <ToolbarButton
+          variant={props.queryInspectorButtonActive ? 'active' : 'canvas'}
           aria-label="Query inspector button"
-          className={cx({ ['explore-active-button']: props.queryInspectorButtonActive })}
           onClick={props.onClickQueryInspectorButton}
           icon="info-circle"
         >
           Inspector
-        </Button>
+        </ToolbarButton>
       </HorizontalGroup>
     </div>
   );
