@@ -1,33 +1,56 @@
-import React from 'react';
-import { shallow } from 'enzyme';
-import { render, prettyDOM } from '@testing-library/react';
+import { render, prettyDOM, screen } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
+import React, { createRef } from 'react';
+import { Provider } from 'react-redux';
+
+import { DataFrame, MutableDataFrame, getDefaultTimeRange, LoadingState } from '@grafana/data';
+import { DataSourceSrv, setDataSourceSrv } from '@grafana/runtime';
+
+import { configureStore } from '../../../store/configureStore';
+
 import { TraceView } from './TraceView';
-import { TracePageHeader, TraceTimelineViewer } from '@jaegertracing/jaeger-ui-components';
-import { setDataSourceSrv } from '@grafana/runtime';
-import { ExploreId } from 'app/types';
-import { TraceData, TraceSpanData } from '@jaegertracing/jaeger-ui-components/src/types/trace';
-import { MutableDataFrame } from '@grafana/data';
+import { TopOfViewRefType } from './components/TraceTimelineViewer/VirtualizedTraceView';
+import { TraceData, TraceSpanData } from './components/types/trace';
+import { transformDataFrames } from './utils/transform';
 
-jest.mock('react-redux', () => ({
-  useSelector: jest.fn(() => undefined),
-}));
+function getTraceView(frames: DataFrame[]) {
+  const store = configureStore();
+  const mockPanelData = {
+    state: LoadingState.Done,
+    series: [],
+    timeRange: getDefaultTimeRange(),
+  };
+  const topOfViewRef = createRef<HTMLDivElement>();
+
+  return (
+    <Provider store={store}>
+      <TraceView
+        exploreId="left"
+        dataFrames={frames}
+        splitOpenFn={() => {}}
+        traceProp={transformDataFrames(frames[0])!}
+        queryResponse={mockPanelData}
+        datasource={undefined}
+        topOfViewRef={topOfViewRef}
+        topOfViewRefType={TopOfViewRefType.Explore}
+      />
+    </Provider>
+  );
+}
+
+function renderTraceView(frames = [frameOld]) {
+  const { container, baseElement } = render(getTraceView(frames));
 
-function renderTraceView() {
-  const wrapper = shallow(<TraceView exploreId={ExploreId.left} dataFrames={[frameOld]} splitOpenFn={() => {}} />);
   return {
-    timeline: wrapper.find(TraceTimelineViewer),
-    header: wrapper.find(TracePageHeader),
-    wrapper,
+    header: container.children[0],
+    timeline: container.children[1],
+    container,
+    baseElement,
   };
 }
 
 function renderTraceViewNew() {
-  const wrapper = shallow(<TraceView exploreId={ExploreId.left} dataFrames={[frameNew]} splitOpenFn={() => {}} />);
-  return {
-    timeline: wrapper.find(TraceTimelineViewer),
-    header: wrapper.find(TracePageHeader),
-    wrapper,
-  };
+  return renderTraceView([frameNew]);
 }
 
 describe('TraceView', () => {
@@ -36,137 +59,89 @@ describe('TraceView', () => {
       getInstanceSettings() {
         return undefined;
       },
-    } as any);
+    } as DataSourceSrv);
   });
 
   it('renders TraceTimelineViewer', () => {
     const { timeline, header } = renderTraceView();
-    expect(timeline).toHaveLength(1);
-    expect(header).toHaveLength(1);
+    expect(timeline).toBeDefined();
+    expect(header).toBeDefined();
   });
 
   it('renders TraceTimelineViewer with new format', () => {
     const { timeline, header } = renderTraceViewNew();
-    expect(timeline).toHaveLength(1);
-    expect(header).toHaveLength(1);
+    expect(timeline).toBeDefined();
+    expect(header).toBeDefined();
   });
 
   it('renders renders the same for old and new format', () => {
-    const { baseElement } = render(
-      <TraceView exploreId={ExploreId.left} dataFrames={[frameNew]} splitOpenFn={() => {}} />
-    );
-    const { baseElement: baseElementOld } = render(
-      <TraceView exploreId={ExploreId.left} dataFrames={[frameOld]} splitOpenFn={() => {}} />
-    );
+    const { baseElement } = renderTraceViewNew();
+    const { baseElement: baseElementOld } = renderTraceView();
     expect(prettyDOM(baseElement)).toEqual(prettyDOM(baseElementOld));
   });
 
-  it('does not render anything on missing trace', () => {
+  it('only renders noDataMsg on missing trace', () => {
     // Simulating Explore's access to empty response data
-    const { container } = render(<TraceView exploreId={ExploreId.left} dataFrames={[]} splitOpenFn={() => {}} />);
-    expect(container.hasChildNodes()).toBeFalsy();
+    const { container } = renderTraceView([]);
+    expect(container.childNodes.length === 1).toBeTruthy();
   });
 
-  it('toggles detailState', () => {
-    let { timeline, wrapper } = renderTraceViewNew();
-    expect(timeline.props().traceTimeline.detailStates.size).toBe(0);
+  it('toggles detailState', async () => {
+    renderTraceViewNew();
+    expect(screen.queryByText(/Span Attributes/)).toBeFalsy();
+    const spanView = screen.getAllByText('', { selector: 'div[data-testid="span-view"]' })[0];
+    await userEvent.click(spanView);
+    expect(screen.queryByText(/Span Attributes/)).toBeTruthy();
 
-    timeline.props().detailToggle('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.detailStates.size).toBe(1);
-    expect(timeline.props().traceTimeline.detailStates.get('1')).not.toBeUndefined();
-
-    timeline.props().detailToggle('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.detailStates.size).toBe(0);
+    await userEvent.click(spanView);
+    screen.debug(screen.queryAllByText(/Span Attributes/));
+    expect(screen.queryByText(/Span Attributes/)).toBeFalsy();
   });
 
-  it('toggles children visibility', () => {
-    let { timeline, wrapper } = renderTraceViewNew();
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
-
-    timeline.props().childrenToggle('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(1);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.has('1')).toBeTruthy();
-
-    timeline.props().childrenToggle('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
+  it('shows timeline ticks', () => {
+    renderTraceViewNew();
+    function ticks() {
+      return screen.getByText('', { selector: 'div[data-testid="TimelineHeaderRow"]' }).children[1].children[1]
+        .textContent;
+    }
+    expect(ticks()).toBe('0μs274.5μs549μs823.5μs1.1ms');
   });
 
-  it('toggles adds and removes hover indent guides', () => {
-    let { timeline, wrapper } = renderTraceViewNew();
-    expect(timeline.props().traceTimeline.hoverIndentGuideIds.size).toBe(0);
+  it('correctly shows processes for each span', async () => {
+    renderTraceView();
+    let table: HTMLElement;
+    expect(screen.queryAllByText('', { selector: 'div[data-testid="span-view"]' }).length).toBe(3);
 
-    timeline.props().addHoverIndentGuideId('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.hoverIndentGuideIds.size).toBe(1);
-    expect(timeline.props().traceTimeline.hoverIndentGuideIds.has('1')).toBeTruthy();
+    const firstSpan = screen.getAllByText('', { selector: 'div[data-testid="span-view"]' })[0];
+    await userEvent.click(firstSpan);
+    await userEvent.click(screen.getByText(/Resource/));
+    table = screen.getByText('', { selector: 'div[data-testid="KeyValueTable"]' });
+    expect(table.innerHTML).toContain('client-uuid-1');
+    await userEvent.click(firstSpan);
 
-    timeline.props().removeHoverIndentGuideId('1');
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.hoverIndentGuideIds.size).toBe(0);
+    const secondSpan = screen.getAllByText('', { selector: 'div[data-testid="span-view"]' })[1];
+    await userEvent.click(secondSpan);
+    await userEvent.click(screen.getByText(/Resource/));
+    table = screen.getByText('', { selector: 'div[data-testid="KeyValueTable"]' });
+    expect(table.innerHTML).toContain('client-uuid-2');
+    await userEvent.click(secondSpan);
+
+    const thirdSpan = screen.getAllByText('', { selector: 'div[data-testid="span-view"]' })[2];
+    await userEvent.click(thirdSpan);
+    await userEvent.click(screen.getByText(/Resource/));
+    table = screen.getByText('', { selector: 'div[data-testid="KeyValueTable"]' });
+    expect(table.innerHTML).toContain('client-uuid-3');
   });
 
-  it('toggles collapses and expands one level of spans', () => {
-    let { timeline, wrapper } = renderTraceViewNew();
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
-    const spans = timeline.props().trace.spans;
+  it('resets detail view for new trace with the identical spanID', async () => {
+    const { rerender } = render(getTraceView([frameOld]));
+    const span = screen.getAllByText('', { selector: 'div[data-testid="span-view"]' })[2];
+    await userEvent.click(span);
+    //Process is in detail view
+    expect(screen.getByText(/Resource/)).toBeInTheDocument();
 
-    timeline.props().collapseOne(spans);
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(1);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.has('3fb050342773d333')).toBeTruthy();
-
-    timeline.props().expandOne(spans);
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
-  });
-
-  it('toggles collapses and expands all levels', () => {
-    let { timeline, wrapper } = renderTraceViewNew();
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
-    const spans = timeline.props().trace.spans;
-
-    timeline.props().collapseAll(spans);
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(2);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.has('3fb050342773d333')).toBeTruthy();
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.has('1ed38015486087ca')).toBeTruthy();
-
-    timeline.props().expandAll();
-    timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().traceTimeline.childrenHiddenIDs.size).toBe(0);
-  });
-
-  it('searches for spans', () => {
-    let { wrapper, header } = renderTraceViewNew();
-    header.props().onSearchValueChange('HTTP POST - api_prom_push');
-
-    const timeline = wrapper.find(TraceTimelineViewer);
-    expect(timeline.props().findMatchesIDs?.has('1ed38015486087ca')).toBeTruthy();
-  });
-
-  it('change viewRange', () => {
-    let { header, timeline, wrapper } = renderTraceViewNew();
-    const defaultRange = { time: { current: [0, 1] } };
-    expect(timeline.props().viewRange).toEqual(defaultRange);
-    expect(header.props().viewRange).toEqual(defaultRange);
-    header.props().updateViewRangeTime(0.2, 0.8);
-
-    let newRange = { time: { current: [0.2, 0.8] } };
-    timeline = wrapper.find(TraceTimelineViewer);
-    header = wrapper.find(TracePageHeader);
-    expect(timeline.props().viewRange).toEqual(newRange);
-    expect(header.props().viewRange).toEqual(newRange);
-
-    newRange = { time: { current: [0.3, 0.7] } };
-    timeline.props().updateViewRangeTime(0.3, 0.7);
-    timeline = wrapper.find(TraceTimelineViewer);
-    header = wrapper.find(TracePageHeader);
-    expect(timeline.props().viewRange).toEqual(newRange);
-    expect(header.props().viewRange).toEqual(newRange);
+    rerender(getTraceView([frameNew]));
+    expect(screen.queryByText(/Resource/)).not.toBeInTheDocument();
   });
 });
 
@@ -178,7 +153,7 @@ const response: TraceData & { spans: TraceSpanData[] } = {
       spanID: '1ed38015486087ca',
       flags: 1,
       operationName: 'HTTP POST - api_prom_push',
-      references: [] as any,
+      references: [],
       startTime: 1585244579835187,
       duration: 1098,
       tags: [
@@ -211,8 +186,8 @@ const response: TraceData & { spans: TraceSpanData[] } = {
           ],
         },
       ],
-      processID: 'p1',
-      warnings: null as any,
+      processID: '1ed38015486087ca',
+      warnings: null,
     },
     {
       traceID: '1ed38015486087ca',
@@ -228,7 +203,7 @@ const response: TraceData & { spans: TraceSpanData[] } = {
         { key: 'internal.span.format', type: 'string', value: 'proto' },
       ],
       logs: [],
-      processID: 'p1',
+      processID: '3fb050342773d333',
       warnings: null,
     },
     {
@@ -244,26 +219,44 @@ const response: TraceData & { spans: TraceSpanData[] } = {
         { key: 'component', type: 'string', value: 'gRPC' },
         { key: 'internal.span.format', type: 'string', value: 'proto' },
       ],
-      logs: [] as any,
-      processID: 'p1',
-      warnings: null as any,
+      logs: [],
+      processID: '35118c298fc91f68',
+      warnings: null,
     },
   ],
   processes: {
-    p1: {
+    '1ed38015486087ca': {
       serviceName: 'loki-all',
       tags: [
-        { key: 'client-uuid', type: 'string', value: '2a59d08899ef6a8a' },
+        { key: 'client-uuid', type: 'string', value: 'client-uuid-1' },
+        { key: 'hostname', type: 'string', value: '0080b530fae3' },
+        { key: 'ip', type: 'string', value: '172.18.0.6' },
+        { key: 'jaeger.version', type: 'string', value: 'Go-2.20.1' },
+      ],
+    },
+    '3fb050342773d333': {
+      serviceName: 'loki-all',
+      tags: [
+        { key: 'client-uuid', type: 'string', value: 'client-uuid-2' },
+        { key: 'hostname', type: 'string', value: '0080b530fae3' },
+        { key: 'ip', type: 'string', value: '172.18.0.6' },
+        { key: 'jaeger.version', type: 'string', value: 'Go-2.20.1' },
+      ],
+    },
+    '35118c298fc91f68': {
+      serviceName: 'loki-all',
+      tags: [
+        { key: 'client-uuid', type: 'string', value: 'client-uuid-3' },
         { key: 'hostname', type: 'string', value: '0080b530fae3' },
         { key: 'ip', type: 'string', value: '172.18.0.6' },
         { key: 'jaeger.version', type: 'string', value: 'Go-2.20.1' },
       ],
     },
   },
-  warnings: null as any,
+  warnings: null,
 };
 
-const frameOld = new MutableDataFrame({
+export const frameOld = new MutableDataFrame({
   fields: [
     {
       name: 'trace',
