@@ -1,26 +1,41 @@
 import React, { PureComponent } from 'react';
-import { hot } from 'react-hot-loader';
-import { connect } from 'react-redux';
-import { NavModel } from '@grafana/data';
-import { LegacyForms } from '@grafana/ui';
+import { connect, ConnectedProps } from 'react-redux';
+
+import { Button, LegacyForms } from '@grafana/ui';
 const { Input } = LegacyForms;
-import Page from 'app/core/components/Page/Page';
 import appEvents from 'app/core/app_events';
+import { Page } from 'app/core/components/Page/Page';
+import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
 import { getNavModel } from 'app/core/selectors/navModel';
-import { CoreEvents, FolderState, StoreState } from 'app/types';
+import { StoreState } from 'app/types';
+
+import { ShowConfirmModalEvent } from '../../types/events';
+
 import { deleteFolder, getFolderByUid, saveFolder } from './state/actions';
 import { getLoadingNav } from './state/navModel';
 import { setFolderTitle } from './state/reducers';
 
-export interface Props {
-  navModel: NavModel;
-  folderUid: string;
-  folder: FolderState;
-  getFolderByUid: typeof getFolderByUid;
-  setFolderTitle: typeof setFolderTitle;
-  saveFolder: typeof saveFolder;
-  deleteFolder: typeof deleteFolder;
-}
+export interface OwnProps extends GrafanaRouteComponentProps<{ uid: string }> {}
+
+const mapStateToProps = (state: StoreState, props: OwnProps) => {
+  const uid = props.match.params.uid;
+  return {
+    pageNav: getNavModel(state.navIndex, `folder-settings-${uid}`, getLoadingNav(2)),
+    folderUid: uid,
+    folder: state.folder,
+  };
+};
+
+const mapDispatchToProps = {
+  getFolderByUid,
+  saveFolder,
+  setFolderTitle,
+  deleteFolder,
+};
+
+const connector = connect(mapStateToProps, mapDispatchToProps);
+
+export type Props = OwnProps & ConnectedProps<typeof connector>;
 
 export interface State {
   isLoading: boolean;
@@ -54,43 +69,49 @@ export class FolderSettingsPage extends PureComponent<Props, State> {
     evt.stopPropagation();
     evt.preventDefault();
 
-    appEvents.emit(CoreEvents.showConfirmModal, {
-      title: 'Delete',
-      text: `Do you want to delete this folder and all its dashboards?`,
-      icon: 'trash-alt',
-      yesText: 'Delete',
-      onConfirm: () => {
-        this.props.deleteFolder(this.props.folder.uid);
-      },
-    });
+    const confirmationText = `Do you want to delete this folder and all its dashboards and alerts?`;
+    appEvents.publish(
+      new ShowConfirmModalEvent({
+        title: 'Delete',
+        text: confirmationText,
+        icon: 'trash-alt',
+        yesText: 'Delete',
+        onConfirm: () => {
+          this.props.deleteFolder(this.props.folder.uid);
+        },
+      })
+    );
   };
 
   render() {
-    const { navModel, folder } = this.props;
+    const { pageNav, folder } = this.props;
 
     return (
-      <Page navModel={navModel}>
+      <Page navId="dashboards/browse" pageNav={pageNav.main}>
         <Page.Contents isLoading={this.state.isLoading}>
-          <h3 className="page-sub-heading">Folder Settings</h3>
+          <h3 className="page-sub-heading">Folder settings</h3>
 
           <div className="section gf-form-group">
             <form name="folderSettingsForm" onSubmit={this.onSave}>
               <div className="gf-form">
-                <label className="gf-form-label width-7">Name</label>
+                <label htmlFor="folder-title" className="gf-form-label width-7">
+                  Name
+                </label>
                 <Input
                   type="text"
                   className="gf-form-input width-30"
+                  id="folder-title"
                   value={folder.title}
                   onChange={this.onTitleChange}
                 />
               </div>
               <div className="gf-form-button-row">
-                <button type="submit" className="btn btn-primary" disabled={!folder.canSave || !folder.hasChanged}>
+                <Button type="submit" disabled={!folder.canSave || !folder.hasChanged}>
                   Save
-                </button>
-                <button className="btn btn-danger" onClick={this.onDelete} disabled={!folder.canSave}>
+                </Button>
+                <Button variant="destructive" onClick={this.onDelete} disabled={!folder.canDelete}>
                   Delete
-                </button>
+                </Button>
               </div>
             </form>
           </div>
@@ -100,21 +121,4 @@ export class FolderSettingsPage extends PureComponent<Props, State> {
   }
 }
 
-const mapStateToProps = (state: StoreState) => {
-  const uid = state.location.routeParams.uid;
-
-  return {
-    navModel: getNavModel(state.navIndex, `folder-settings-${uid}`, getLoadingNav(2)),
-    folderUid: uid,
-    folder: state.folder,
-  };
-};
-
-const mapDispatchToProps = {
-  getFolderByUid,
-  saveFolder,
-  setFolderTitle,
-  deleteFolder,
-};
-
-export default hot(module)(connect(mapStateToProps, mapDispatchToProps)(FolderSettingsPage));
+export default connector(FolderSettingsPage);
