@@ -1,15 +1,15 @@
 import { Feature } from 'ol';
-import { Geometry } from 'ol/geom';
+import { Geometry, LineString, Point } from 'ol/geom';
 import VectorSource from 'ol/source/Vector';
 
-import { DataFrame } from '@grafana/data';
+import { DataFrame, Field } from '@grafana/data';
 
 import { getGeometryField, LocationFieldMatchers } from './location';
 
 export interface FrameVectorSourceOptions {}
 
 export class FrameVectorSource<T extends Geometry = Geometry> extends VectorSource<T> {
-  constructor(private location: LocationFieldMatchers) {
+  constructor(public location: LocationFieldMatchers) {
     super({});
   }
 
@@ -26,7 +26,7 @@ export class FrameVectorSource<T extends Geometry = Geometry> extends VectorSour
         new Feature({
           frame,
           rowIndex: i,
-          geometry: info.field.values.get(i) as T,
+          geometry: info.field.values[i] as T,
         })
       );
     }
@@ -34,4 +34,27 @@ export class FrameVectorSource<T extends Geometry = Geometry> extends VectorSour
     // only call this at the end
     this.changed();
   }
+
+  updateLineString(frame: DataFrame) {
+    this.clear(true);
+    const info = getGeometryField(frame, this.location);
+    if (!info.field) {
+      this.changed();
+      return;
+    }
+
+    //eslint-disable-next-line
+    const field = info.field as unknown as Field<Point>;
+    const geometry = new LineString(field.values.map((p) => p.getCoordinates())) as Geometry;
+    this.addFeatureInternal(
+      new Feature({
+        frame,
+        rowIndex: 0,
+        geometry: geometry as T,
+      })
+    );
+
+    // only call this at the end
+    this.changed();
+  }
 }
