@@ -1,10 +1,10 @@
 import React from 'react';
 
 import { DataQueryError } from '@grafana/data';
-import { JSONFormatter } from '@grafana/ui';
+import { Alert, JSONFormatter } from '@grafana/ui';
 
 interface InspectErrorTabProps {
-  error?: DataQueryError;
+  errors?: DataQueryError[];
 }
 
 const parseErrorMessage = (message: string): { msg: string; json?: any } => {
@@ -20,10 +20,7 @@ const parseErrorMessage = (message: string): { msg: string; json?: any } => {
   }
 };
 
-export const InspectErrorTab: React.FC<InspectErrorTabProps> = ({ error }) => {
-  if (!error) {
-    return null;
-  }
+function renderError(error: DataQueryError) {
   if (error.data) {
     return (
       <>
@@ -35,15 +32,45 @@ export const InspectErrorTab: React.FC<InspectErrorTabProps> = ({ error }) => {
   if (error.message) {
     const { msg, json } = parseErrorMessage(error.message);
     if (!json) {
-      return <div>{msg}</div>;
+      return (
+        <>
+          {error.status && <>Status: {error.status}. Message: </>}
+          {msg}
+          {error.traceId != null && (
+            <>
+              <br />
+              (Trace ID: {error.traceId})
+            </>
+          )}
+        </>
+      );
     } else {
       return (
         <>
           {msg !== '' && <h3>{msg}</h3>}
+          {error.status && <>Status: {error.status}</>}
           <JSONFormatter json={json} open={5} />
         </>
       );
     }
   }
   return <JSONFormatter json={error} open={2} />;
+}
+
+export const InspectErrorTab = ({ errors }: InspectErrorTabProps) => {
+  if (!errors?.length) {
+    return null;
+  }
+  if (errors.length === 1) {
+    return renderError(errors[0]);
+  }
+  return (
+    <>
+      {errors.map((error, index) => (
+        <Alert title={error.refId || `Query ${index + 1}`} severity="error" key={index}>
+          {renderError(error)}
+        </Alert>
+      ))}
+    </>
+  );
 };
