@@ -1,4 +1,3 @@
-import mockConsole, { RestoreConsole } from 'jest-mock-console';
 import { mapValues } from 'lodash';
 import { Observable, Subject, Subscription, Unsubscribable } from 'rxjs';
 
@@ -14,10 +13,10 @@ import {
   LiveChannelLeaveEvent,
   LiveChannelScope,
   LoadingState,
+  StreamingDataFrame,
 } from '@grafana/data';
 import { StreamingFrameAction } from '@grafana/runtime';
 
-import { StreamingDataFrame } from '../data/StreamingDataFrame';
 import { isStreamingResponseData, StreamingResponseData, StreamingResponseDataType } from '../data/utils';
 
 import { DataStreamHandlerDeps, LiveDataStream } from './LiveDataStream';
@@ -123,14 +122,12 @@ const dummyErrorMessage = 'dummy-error';
 describe('LiveDataStream', () => {
   jest.useFakeTimers();
 
-  let restoreConsole: RestoreConsole | undefined;
-
   beforeEach(() => {
-    restoreConsole = mockConsole();
+    jest.spyOn(console, 'log').mockImplementation(jest.fn);
   });
 
   afterEach(() => {
-    restoreConsole?.();
+    jest.clearAllMocks();
   });
 
   const expectValueCollectionState = <T>(
@@ -303,17 +300,13 @@ describe('LiveDataStream', () => {
           config: {},
           name: 'time',
           type: 'time',
-          values: {
-            buffer: [100, 101],
-          },
+          values: [100, 101],
         },
         {
           config: {},
           name: 'b',
           type: 'number',
-          values: {
-            buffer: [1, 2],
-          },
+          values: [1, 2],
         },
       ]);
       expect(deserializedFrame.length).toEqual(dataFrameJsons.schema1().data.values[0].length);
@@ -353,6 +346,7 @@ describe('LiveDataStream', () => {
           values: [undefined, 'y'], //  bug in streamingDataFrame - fix!
         },
       ]);
+      expect(StreamingDataFrame.deserialize(data.frame).length).toEqual(2);
     });
 
     it('should emit a full frame if received a status live channel event with error', async () => {
@@ -369,6 +363,7 @@ describe('LiveDataStream', () => {
       const response = valuesCollection.lastValue();
 
       expectErrorResponse(response, StreamingResponseDataType.FullFrame);
+      expect(StreamingDataFrame.deserialize(response.data[0].frame).length).toEqual(2); // contains previously populated values
     });
 
     it('should buffer new values until subscriber is ready', async () => {
@@ -431,6 +426,7 @@ describe('LiveDataStream', () => {
           values: [2, 3],
         },
       ]);
+      expect(StreamingDataFrame.deserialize(response.data[0].frame).length).toEqual(2);
     });
 
     it(`should reduce buffer to a full frame with last error if one or more errors occur during subscriber's unavailability`, async () => {
@@ -529,17 +525,13 @@ describe('LiveDataStream', () => {
           config: {},
           name: 'time',
           type: 'time',
-          values: {
-            buffer: [100, 101],
-          },
+          values: [100, 101],
         },
         {
           config: {},
           name: 'b',
           type: 'number',
-          values: {
-            buffer: [1, 2],
-          },
+          values: [1, 2],
         },
       ]);
       expect(deserializedFrame.length).toEqual(dataFrameJsons.schema1().data.values[0].length);
@@ -579,6 +571,8 @@ describe('LiveDataStream', () => {
           values: ['y'],
         },
       ]);
+      const deserializedFrame = StreamingDataFrame.deserialize(data.frame);
+      expect(deserializedFrame.length).toEqual(1);
     });
 
     it('should emit a full frame if received a status live channel event with error', async () => {
@@ -595,6 +589,7 @@ describe('LiveDataStream', () => {
       const response = valuesCollection.lastValue();
 
       expectErrorResponse(response, StreamingResponseDataType.FullFrame);
+      expect(StreamingDataFrame.deserialize(response.data[0].frame).length).toEqual(0);
     });
 
     it('should buffer new values until subscriber is ready', async () => {
@@ -654,6 +649,8 @@ describe('LiveDataStream', () => {
           values: [3],
         },
       ]);
+      const data = response.data[0] as StreamingResponseData<StreamingResponseDataType.FullFrame>;
+      expect(StreamingDataFrame.deserialize(data.frame).length).toEqual(1);
     });
 
     it(`should reduce buffer to an empty full frame with last error if one or more errors occur during subscriber's unavailability`, async () => {
@@ -688,6 +685,7 @@ describe('LiveDataStream', () => {
           values: [],
         },
       ]);
+      expect(StreamingDataFrame.deserialize(response.data[0].frame).length).toEqual(0);
     });
 
     it('should ignore messages without payload', async () => {
@@ -751,6 +749,7 @@ describe('LiveDataStream', () => {
           values: ['y'], //  bug in streamingDataFrame - fix!
         },
       ]);
+      expect(StreamingDataFrame.deserialize(response.data[0].frame).length).toEqual(1);
     });
   });
 
