@@ -4,7 +4,7 @@ import { notifyApp } from 'app/core/actions';
 import { createErrorNotification } from 'app/core/copy/appNotification';
 import { SaveDashboardCommand } from 'app/features/dashboard/components/SaveDashboard/types';
 import { dashboardWatcher } from 'app/features/live/dashboard/dashboardWatcher';
-import { DashboardDTO, FolderInfo, PermissionLevelString, ThunkResult } from 'app/types';
+import { DashboardDTO, FolderInfo, PermissionLevelString, SearchQueryType, ThunkResult } from 'app/types';
 
 import { LibraryElementExport } from '../../dashboard/components/DashExportModal/DashboardExporter';
 import { getLibraryPanel } from '../../library-panels/state/api';
@@ -101,8 +101,6 @@ function processElements(dashboardJson?: { __elements?: Record<string, LibraryEl
           uid,
           name,
           version: 0,
-          meta: {},
-          id: 0,
           type,
           kind: LibraryElementKind.Panel,
           description,
@@ -166,7 +164,7 @@ export function importDashboard(importDashboardForm: ImportDashboardDTO): ThunkR
       dashboard: { ...dashboard, title: importDashboardForm.title, uid: importDashboardForm.uid || dashboard.uid },
       overwrite: true,
       inputs: inputsToPersist,
-      folderId: importDashboardForm.folder.id,
+      folderUid: importDashboardForm.folder.uid,
     });
 
     const dashboardUrl = locationUtil.stripBaseFromUrl(result.importedUrl);
@@ -184,6 +182,26 @@ const getDataSourceOptions = (input: { pluginId: string; pluginName: string }, i
   }
 };
 
+export async function moveFolders(folderUIDs: string[], toFolder: FolderInfo) {
+  const result = {
+    totalCount: folderUIDs.length,
+    successCount: 0,
+  };
+
+  for (const folderUID of folderUIDs) {
+    try {
+      const newFolderDTO = await moveFolder(folderUID, toFolder);
+      if (newFolderDTO !== null) {
+        result.successCount += 1;
+      }
+    } catch (err) {
+      console.error('Failed to move a folder', err);
+    }
+  }
+
+  return result;
+}
+
 export function moveDashboards(dashboardUids: string[], toFolder: FolderInfo) {
   const tasks = [];
 
@@ -203,13 +221,16 @@ export function moveDashboards(dashboardUids: string[], toFolder: FolderInfo) {
 async function moveDashboard(uid: string, toFolder: FolderInfo) {
   const fullDash: DashboardDTO = await getBackendSrv().get(`/api/dashboards/uid/${uid}`);
 
-  if ((!fullDash.meta.folderId && toFolder.id === 0) || fullDash.meta.folderId === toFolder.id) {
+  if (
+    ((fullDash.meta.folderUid === undefined || fullDash.meta.folderUid === null) && toFolder.uid === '') ||
+    fullDash.meta.folderUid === toFolder.uid
+  ) {
     return { alreadyInFolder: true };
   }
 
   const options = {
     dashboard: fullDash.dashboard,
-    folderId: toFolder.id,
+    folderUid: toFolder.uid,
     overwrite: false,
   };
 
@@ -271,7 +292,7 @@ export function saveDashboard(options: SaveDashboardCommand) {
     dashboard: options.dashboard,
     message: options.message ?? '',
     overwrite: options.overwrite ?? false,
-    folderId: options.folderId,
+    folderUid: options.folderUid,
   });
 }
 
@@ -283,19 +304,31 @@ export function createFolder(payload: any) {
   return getBackendSrv().post('/api/folders', payload);
 }
 
+export function moveFolder(uid: string, toFolder: FolderInfo) {
+  const payload = {
+    parentUid: toFolder.uid,
+  };
+  return getBackendSrv().post(`/api/folders/${uid}/move`, payload, { showErrorAlert: false });
+}
+
+export const SLICE_FOLDER_RESULTS_TO = 1000;
+
 export function searchFolders(
   query: any,
   permission?: PermissionLevelString,
-  withAccessControl = false
+  type: SearchQueryType = SearchQueryType.Folder
 ): Promise<DashboardSearchHit[]> {
   return getBackendSrv().get('/api/search', {
     query,
-    type: 'dash-folder',
+    type: type,
     permission,
-    accesscontrol: withAccessControl,
+    limit: SLICE_FOLDER_RESULTS_TO,
   });
 }
 
+export function getFolderByUid(uid: string): Promise<{ uid: string; title: string }> {
+  return getBackendSrv().get(`/api/folders/${uid}`);
+}
 export function getFolderById(id: number): Promise<{ id: number; title: string }> {
   return getBackendSrv().get(`/api/folders/id/${id}`);
 }
@@ -304,7 +337,7 @@ export function deleteDashboard(uid: string, showSuccessAlert: boolean) {
   return getBackendSrv().delete<DeleteDashboardResponse>(`/api/dashboards/uid/${uid}`, { showSuccessAlert });
 }
 
-function executeInOrder(tasks: any[]) {
+function executeInOrder(tasks: any[]): Promise<unknown> {
   return tasks.reduce((acc, task) => {
     return Promise.resolve(acc).then(task);
   }, []);
