@@ -1,5 +1,8 @@
-import React, { FC } from 'react';
+import React from 'react';
+
 import { Input, Field, FieldSet, Button, Form } from '@grafana/ui';
+import { contextSrv } from 'app/core/core';
+import { AccessControlAction } from 'app/types';
 
 export interface Props {
   orgName: string;
@@ -10,13 +13,15 @@ interface FormDTO {
   orgName: string;
 }
 
-const OrgProfile: FC<Props> = ({ onSubmit, orgName }) => {
+const OrgProfile = ({ onSubmit, orgName }: Props) => {
+  const canWriteOrg = contextSrv.hasPermission(AccessControlAction.OrgsWrite);
+
   return (
     <Form defaultValues={{ orgName }} onSubmit={({ orgName }: FormDTO) => onSubmit(orgName)}>
       {({ register }) => (
-        <FieldSet label="Organization profile">
+        <FieldSet label="Organization profile" disabled={!canWriteOrg}>
           <Field label="Organization name">
-            <Input name="orgName" type="text" ref={register({ required: true })} />
+            <Input id="org-name-input" type="text" {...register('orgName', { required: true })} />
           </Field>
 
           <Button type="submit">Update organization name</Button>
