@@ -37,9 +37,12 @@ export const PanelTypeCard = ({
   });
 
   return (
+    // TODO: fix keyboard a11y
+    // eslint-disable-next-line jsx-a11y/click-events-have-key-events
     <div
       className={cssClass}
       aria-label={selectors.components.PluginVisualization.item(plugin.name)}
+      data-testid={selectors.components.PluginVisualization.item(plugin.name)}
       onClick={isDisabled ? undefined : onClick}
       title={isCurrent ? 'Click again to close this section' : plugin.name}
     >
@@ -64,6 +67,7 @@ export const PanelTypeCard = ({
           }}
           className={styles.deleteButton}
           aria-label="Delete button on panel type card"
+          tooltip="Delete"
         />
       )}
     </div>
@@ -115,7 +119,7 @@ const getStyles = (theme: GrafanaTheme2) => {
       background: ${theme.colors.action.selected};
     `,
     disabled: css`
-      opacity: ${theme.colors.action.disabledOpacity};
+      opacity: 0.6;
       filter: grayscale(1);
       cursor: default;
       pointer-events: none;
