@@ -1,60 +1,52 @@
-import { FieldType, locationUtil, toDataFrame, VariableOrigin } from '@grafana/data';
+import { FieldType, GrafanaConfig, locationUtil, toDataFrame, VariableOrigin } from '@grafana/data';
 import { setTemplateSrv } from '@grafana/runtime';
-import { getDataFrameVars, LinkSrv } from '../link_srv';
-import { TimeSrv } from 'app/features/dashboard/services/TimeSrv';
+import { ContextSrv } from 'app/core/services/context_srv';
+import { getTimeSrv, setTimeSrv, TimeSrv } from 'app/features/dashboard/services/TimeSrv';
+import { TimeModel } from 'app/features/dashboard/state/TimeModel';
 import { TemplateSrv } from 'app/features/templating/template_srv';
 import { variableAdapters } from 'app/features/variables/adapters';
 import { createQueryVariableAdapter } from 'app/features/variables/query/adapter';
-import { updateConfig } from '../../../../core/config';
+
 import { initTemplateSrv } from '../../../../../test/helpers/initTemplateSrv';
+import { updateConfig } from '../../../../core/config';
+import { getDataFrameVars, LinkSrv } from '../link_srv';
 
 jest.mock('app/core/core', () => ({
   appEvents: {
-    on: () => {},
+    subscribe: () => {},
   },
 }));
 
 describe('linkSrv', () => {
   let linkSrv: LinkSrv;
   let templateSrv: TemplateSrv;
+  let originalTimeService: TimeSrv;
 
   function initLinkSrv() {
-    const rootScope = {
-      $on: jest.fn(),
-      onAppEvent: jest.fn(),
-      appEvent: jest.fn(),
-    };
-
-    const timer = {
-      register: jest.fn(),
-      cancel: jest.fn(),
-      cancelAll: jest.fn(),
-    };
-
-    const location = {
-      search: jest.fn(() => ({})),
-    };
-
-    const _dashboard: any = {
+    const _dashboard = {
       time: { from: 'now-6h', to: 'now' },
       getTimezone: jest.fn(() => 'browser'),
-    };
+      timeRangeUpdated: () => {},
+    } as unknown as TimeModel;
 
-    const timeSrv = new TimeSrv(rootScope as any, jest.fn() as any, location as any, timer, {} as any);
+    const timeSrv = new TimeSrv({} as ContextSrv);
     timeSrv.init(_dashboard);
     timeSrv.setTime({ from: 'now-1h', to: 'now' });
     _dashboard.refresh = false;
-    templateSrv = initTemplateSrv([
+    setTimeSrv(timeSrv);
+
+    templateSrv = initTemplateSrv('key', [
       { type: 'query', name: 'home', current: { value: '127.0.0.1' } },
       { type: 'query', name: 'server1', current: { value: '192.168.0.100' } },
     ]);
 
     setTemplateSrv(templateSrv);
 
-    linkSrv = new LinkSrv(templateSrv, timeSrv);
+    linkSrv = new LinkSrv();
   }
 
   beforeAll(() => {
+    originalTimeService = getTimeSrv();
     variableAdapters.register(createQueryVariableAdapter());
   });
 
@@ -64,6 +56,10 @@ describe('linkSrv', () => {
     jest.resetAllMocks();
   });
 
+  afterAll(() => {
+    setTimeSrv(originalTimeService);
+  });
+
   describe('getDataLinkUIModel', () => {
     describe('built in variables', () => {
       it('should not trim white space from data links', () => {
@@ -133,13 +129,9 @@ describe('linkSrv', () => {
         "when link '$url' and config.appSubUrl set to '$appSubUrl' then result should be '$expected'",
         ({ url, appSubUrl, expected }) => {
           locationUtil.initialize({
-            getConfig: () => {
-              return { appSubUrl } as any;
-            },
-            // @ts-ignore
-            buildParamsFromVariables: () => {},
-            // @ts-ignore
-            getTimeRangeForUrl: () => {},
+            config: { appSubUrl } as GrafanaConfig,
+            getVariablesUrlParams: jest.fn(),
+            getTimeRangeForUrl: jest.fn(),
           });
 
           const link = linkSrv.getDataLinkUIModel(
@@ -434,4 +426,28 @@ describe('getDataFrameVars', () => {
       ]);
     });
   });
+
+  describe('when called with multiple DataFrames', () => {
+    it('it should not return any suggestions', () => {
+      const frame1 = toDataFrame({
+        name: 'server1',
+        fields: [
+          { name: 'time', type: FieldType.time, values: [1, 2, 3] },
+          { name: 'value', type: FieldType.number, values: [10, 11, 12] },
+        ],
+      });
+
+      const frame2 = toDataFrame({
+        name: 'server2',
+        fields: [
+          { name: 'time', type: FieldType.time, values: [1, 2, 3] },
+          { name: 'value', type: FieldType.number, values: [10, 11, 12] },
+        ],
+      });
+
+      const suggestions = getDataFrameVars([frame1, frame2]);
+
+      expect(suggestions).toEqual([]);
+    });
+  });
 });
