@@ -10,15 +10,23 @@ export function getAllPanelPluginMeta(): PanelPluginMeta[] {
     .sort((a: PanelPluginMeta, b: PanelPluginMeta) => a.sort - b.sort);
 }
 
+export function getWidgetPluginMeta(): PanelPluginMeta[] {
+  return getAllPanelPluginMeta().filter((panel) => !!panel.skipDataQuery);
+}
+
+export function getVizPluginMeta(): PanelPluginMeta[] {
+  return getAllPanelPluginMeta().filter((panel) => !panel.skipDataQuery);
+}
+
 export function filterPluginList(
   pluginsList: PanelPluginMeta[],
   searchQuery: string, // Note: this will be an escaped regex string as it comes from `FilterInput`
-  current: PanelPluginMeta
+  current?: PanelPluginMeta
 ): PanelPluginMeta[] {
   if (!searchQuery.length) {
     return pluginsList.filter((p) => {
       if (p.state === PluginState.deprecated) {
-        return current.id === p.id;
+        return current?.id === p.id;
       }
       return true;
     });
@@ -30,7 +38,7 @@ export function filterPluginList(
   const isGraphQuery = 'graph'.startsWith(query);
 
   for (const item of pluginsList) {
-    if (item.state === PluginState.deprecated && current.id !== item.id) {
+    if (item.state === PluginState.deprecated && current?.id !== item.id) {
       continue;
     }
 
