@@ -57,6 +57,7 @@ export interface CatalogPlugin extends WithAccessControlMetadata {
   installedVersion?: string;
   details?: CatalogPluginDetails;
   error?: PluginErrorCode;
+  angularDetected?: boolean;
 }
 
 export interface CatalogPluginDetails {
@@ -123,6 +124,7 @@ export type RemotePlugin = {
   versionSignedByOrg: string;
   versionSignedByOrgName: string;
   versionStatus: string;
+  angularDetected?: boolean;
 };
 
 export type LocalPlugin = WithAccessControlMetadata & {
@@ -156,6 +158,7 @@ export type LocalPlugin = WithAccessControlMetadata & {
   state: string;
   type: PluginType;
   dependencies: PluginDependencies;
+  angularDetected: boolean;
 };
 
 interface Rel {
