@@ -2,15 +2,10 @@ import React, { useMemo, useState } from 'react';
 import { useObservable } from 'react-use';
 import AutoSizer from 'react-virtualized-auto-sizer';
 
-import {
-  ApplyFieldOverrideOptions,
-  DataTransformerConfig,
-  dateMath,
-  FieldColorModeId,
-  NavModelItem,
-  PanelData,
-} from '@grafana/data';
-import { Button, Table } from '@grafana/ui';
+import { ApplyFieldOverrideOptions, dateMath, FieldColorModeId, NavModelItem, PanelData } from '@grafana/data';
+import { getPluginExtensions, isPluginExtensionLink } from '@grafana/runtime';
+import { DataTransformerConfig } from '@grafana/schema';
+import { Button, HorizontalGroup, LinkButton, Table } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { config } from 'app/core/config';
 import { useAppNotification } from 'app/core/copy/appNotification';
@@ -66,6 +61,9 @@ export const TestStuffPage = () => {
   return (
     <Page navModel={{ node: node, main: node }}>
       <Page.Contents>
+        <HorizontalGroup>
+          <LinkToBasicApp extensionPointId="grafana/sandbox/testing" />
+        </HorizontalGroup>
         {data && (
           <AutoSizer style={{ width: '100%', height: '600px' }}>
             {({ width }) => {
@@ -149,4 +147,27 @@ export function getDefaultState(): State {
   };
 }
 
+function LinkToBasicApp({ extensionPointId }: { extensionPointId: string }) {
+  const { extensions } = getPluginExtensions({ extensionPointId });
+
+  if (extensions.length === 0) {
+    return null;
+  }
+
+  return (
+    <div>
+      {extensions.map((extension, i) => {
+        if (!isPluginExtensionLink(extension)) {
+          return null;
+        }
+        return (
+          <LinkButton href={extension.path} title={extension.description} key={extension.id}>
+            {extension.title}
+          </LinkButton>
+        );
+      })}
+    </div>
+  );
+}
+
 export default TestStuffPage;
