@@ -1,17 +1,14 @@
 import { render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import React from 'react';
-import { Provider } from 'react-redux';
-import { mockToolkitActionCreator } from 'test/core/redux/mocks';
+import { TestProvider } from 'test/helpers/TestProvider';
 
 import { contextSrv, User } from 'app/core/services/context_srv';
 
-import { configureStore } from '../../store/configureStore';
 import { OrgRole, Team } from '../../types';
 
 import { Props, TeamList } from './TeamList';
 import { getMockTeam, getMultipleMockTeams } from './__mocks__/teamMocks';
-import { setSearchQuery, setTeamsSearchPage } from './state/reducers';
 
 jest.mock('app/core/config', () => ({
   ...jest.requireActual('app/core/config'),
@@ -19,16 +16,16 @@ jest.mock('app/core/config', () => ({
 }));
 
 const setup = (propOverrides?: object) => {
-  const store = configureStore();
   const props: Props = {
     teams: [] as Team[],
+    noTeams: false,
     loadTeams: jest.fn(),
     deleteTeam: jest.fn(),
-    setSearchQuery: mockToolkitActionCreator(setSearchQuery),
-    setTeamsSearchPage: mockToolkitActionCreator(setTeamsSearchPage),
-    searchQuery: '',
-    searchPage: 1,
-    teamsCount: 0,
+    changePage: jest.fn(),
+    changeQuery: jest.fn(),
+    query: '',
+    page: 1,
+    totalPages: 0,
     hasFetched: false,
     editorsCanAdmin: false,
     signedInUser: {
@@ -42,9 +39,9 @@ const setup = (propOverrides?: object) => {
   contextSrv.user = props.signedInUser;
 
   render(
-    <Provider store={store}>
+    <TestProvider>
       <TeamList {...props} />
-    </Provider>
+    </TestProvider>
   );
 };
 
@@ -59,7 +56,7 @@ describe('TeamList', () => {
       it('should enable the new team button', () => {
         setup({
           teams: getMultipleMockTeams(1),
-          teamsCount: 1,
+          totalCount: 1,
           hasFetched: true,
           editorsCanAdmin: true,
           signedInUser: {
@@ -76,7 +73,7 @@ describe('TeamList', () => {
       it('should disable the new team button', () => {
         setup({
           teams: getMultipleMockTeams(1),
-          teamsCount: 1,
+          totalCount: 1,
           hasFetched: true,
           editorsCanAdmin: true,
           signedInUser: {
@@ -94,7 +91,7 @@ describe('TeamList', () => {
 it('should call delete team', async () => {
   const mockDelete = jest.fn();
   const mockTeam = getMockTeam();
-  setup({ deleteTeam: mockDelete, teams: [mockTeam], teamsCount: 1, hasFetched: true });
+  setup({ deleteTeam: mockDelete, teams: [mockTeam], totalCount: 1, hasFetched: true });
   await userEvent.click(screen.getByRole('button', { name: `Delete team ${mockTeam.name}` }));
   await userEvent.click(screen.getByRole('button', { name: 'Delete' }));
   await waitFor(() => {
