@@ -1,5 +1,7 @@
 import { dateTime, TimeRange } from '@grafana/data';
-import { setDataSourceSrv } from '@grafana/runtime';
+import { setDataSourceSrv, VariableInterpolation } from '@grafana/runtime';
+import { TestVariable } from '@grafana/scenes';
+import { VariableFormatID } from '@grafana/schema';
 
 import { silenceConsoleOutput } from '../../../test/core/utils/silenceConsoleOutput';
 import { initTemplateSrv } from '../../../test/helpers/initTemplateSrv';
@@ -9,7 +11,7 @@ import { createAdHocVariableAdapter } from '../variables/adhoc/adapter';
 import { createQueryVariableAdapter } from '../variables/query/adapter';
 import { VariableModel } from '../variables/types';
 
-import { FormatRegistryID } from './formatRegistry';
+import { TemplateSrv } from './template_srv';
 
 const key = 'key';
 
@@ -18,9 +20,18 @@ variableAdapters.setInit(() => [
   createAdHocVariableAdapter() as unknown as VariableAdapter<VariableModel>,
 ]);
 
+const interpolateMock = jest.fn();
+
+jest.mock('@grafana/scenes', () => ({
+  ...jest.requireActual('@grafana/scenes'),
+  sceneGraph: {
+    interpolate: (...args: unknown[]) => interpolateMock(...args),
+  },
+}));
+
 describe('templateSrv', () => {
   silenceConsoleOutput();
-  let _templateSrv: any;
+  let _templateSrv: TemplateSrv;
 
   describe('init', () => {
     beforeEach(() => {
@@ -40,7 +51,7 @@ describe('templateSrv', () => {
 
     it('scoped vars should support objects', () => {
       const target = _templateSrv.replace('${series.name} ${series.nested.field}', {
-        series: { value: { name: 'Server1', nested: { field: 'nested' } } },
+        series: { value: { name: 'Server1', nested: { field: 'nested' } }, text: 'foo' },
       });
       expect(target).toBe('Server1 nested');
     });
@@ -55,14 +66,14 @@ describe('templateSrv', () => {
 
     it('scoped vars should support objects with propert names with dot', () => {
       const target = _templateSrv.replace('${series.name} ${series.nested["field.with.dot"]}', {
-        series: { value: { name: 'Server1', nested: { 'field.with.dot': 'nested' } } },
+        series: { value: { name: 'Server1', nested: { 'field.with.dot': 'nested' } }, text: 'foo' },
       });
       expect(target).toBe('Server1 nested');
     });
 
     it('scoped vars should support arrays of objects', () => {
       const target = _templateSrv.replace('${series.rows[0].name} ${series.rows[1].name}', {
-        series: { value: { rows: [{ name: 'first' }, { name: 'second' }] } },
+        series: { value: { rows: [{ name: 'first' }, { name: 'second' }] }, text: 'foo' },
       });
       expect(target).toBe('first second');
     });
@@ -117,6 +128,70 @@ describe('templateSrv', () => {
     });
   });
 
+  describe('replace with interpolations map', function () {
+    beforeEach(() => {
+      _templateSrv = initTemplateSrv(key, [{ type: 'query', name: 'test', current: { value: 'testValue' } }]);
+    });
+
+    it('replace can save interpolation result', () => {
+      let interpolations: VariableInterpolation[] = [];
+
+      const target = _templateSrv.replace(
+        'test.${test}.${scoped}.${nested.name}.${test}.${optionTest:raw}.$notfound',
+        {
+          scoped: { value: 'scopedValue', text: 'scopedText' },
+          optionTest: { value: 'optionTestValue', text: 'optionTestText' },
+          nested: { value: { name: 'nestedValue' } },
+        },
+        undefined,
+        interpolations
+      );
+
+      expect(target).toBe('test.testValue.scopedValue.nestedValue.testValue.optionTestValue.$notfound');
+      expect(interpolations.length).toBe(6);
+      expect(interpolations).toEqual([
+        {
+          match: '${test}',
+          found: true,
+          value: 'testValue',
+          variableName: 'test',
+        },
+        {
+          match: '${scoped}',
+          found: true,
+          value: 'scopedValue',
+          variableName: 'scoped',
+        },
+        {
+          fieldPath: 'name',
+          match: '${nested.name}',
+          found: true,
+          value: 'nestedValue',
+          variableName: 'nested',
+        },
+        {
+          match: '${test}',
+          found: true,
+          value: 'testValue',
+          variableName: 'test',
+        },
+        {
+          format: 'raw',
+          match: '${optionTest:raw}',
+          found: true,
+          value: 'optionTestValue',
+          variableName: 'optionTest',
+        },
+        {
+          match: '$notfound',
+          found: false,
+          value: '$notfound',
+          variableName: 'notfound',
+        },
+      ]);
+    });
+  });
+
   describe('getAdhocFilters', () => {
     beforeEach(() => {
       _templateSrv = initTemplateSrv(key, [
@@ -298,6 +373,25 @@ describe('templateSrv', () => {
       const target = _templateSrv.replace('${test:queryparam}', {});
       expect(target).toBe('var-test=All');
     });
+
+    describe('percentencode option', () => {
+      beforeEach(() => {
+        _templateSrv = initTemplateSrv(key, [
+          {
+            type: 'query',
+            name: 'test',
+            current: { value: '$__all' },
+            allValue: '.+',
+            options: [{ value: 'value1' }, { value: 'value2' }],
+          },
+        ]);
+      });
+
+      it('should respect percentencode format', () => {
+        const target = _templateSrv.replace('this.${test:percentencode}', {}, 'regex');
+        expect(target).toBe('this..%2B');
+      });
+    });
   });
 
   describe('lucene format', () => {
@@ -330,104 +424,6 @@ describe('templateSrv', () => {
     });
   });
 
-  describe('format variable to string values', () => {
-    it('single value should return value', () => {
-      const result = _templateSrv.formatValue('test');
-      expect(result).toBe('test');
-    });
-
-    it('should use glob format when unknown format provided', () => {
-      let result = _templateSrv.formatValue('test', 'nonexistentformat');
-      expect(result).toBe('test');
-      result = _templateSrv.formatValue(['test', 'test1'], 'nonexistentformat');
-      expect(result).toBe('{test,test1}');
-    });
-
-    it('multi value and glob format should render glob string', () => {
-      const result = _templateSrv.formatValue(['test', 'test2'], 'glob');
-      expect(result).toBe('{test,test2}');
-    });
-
-    it('multi value and lucene should render as lucene expr', () => {
-      const result = _templateSrv.formatValue(['test', 'test2'], 'lucene');
-      expect(result).toBe('("test" OR "test2")');
-    });
-
-    it('multi value and regex format should render regex string', () => {
-      const result = _templateSrv.formatValue(['test.', 'test2'], 'regex');
-      expect(result).toBe('(test\\.|test2)');
-    });
-
-    it('multi value and pipe should render pipe string', () => {
-      const result = _templateSrv.formatValue(['test', 'test2'], 'pipe');
-      expect(result).toBe('test|test2');
-    });
-
-    it('multi value and distributed should render distributed string', () => {
-      const result = _templateSrv.formatValue(['test', 'test2'], 'distributed', {
-        name: 'build',
-      });
-      expect(result).toBe('test,build=test2');
-    });
-
-    it('multi value and distributed should render when not string', () => {
-      const result = _templateSrv.formatValue(['test'], 'distributed', {
-        name: 'build',
-      });
-      expect(result).toBe('test');
-    });
-
-    it('multi value and csv format should render csv string', () => {
-      const result = _templateSrv.formatValue(['test', 'test2'], 'csv');
-      expect(result).toBe('test,test2');
-    });
-
-    it('multi value and percentencode format should render percent-encoded string', () => {
-      const result = _templateSrv.formatValue(['foo()bar BAZ', 'test2'], 'percentencode');
-      expect(result).toBe('%7Bfoo%28%29bar%20BAZ%2Ctest2%7D');
-    });
-
-    it('slash should be properly escaped in regex format', () => {
-      const result = _templateSrv.formatValue('Gi3/14', 'regex');
-      expect(result).toBe('Gi3\\/14');
-    });
-
-    it('single value and singlequote format should render string with value enclosed in single quotes', () => {
-      const result = _templateSrv.formatValue('test', 'singlequote');
-      expect(result).toBe("'test'");
-    });
-
-    it('multi value and singlequote format should render string with values enclosed in single quotes', () => {
-      const result = _templateSrv.formatValue(['test', "test'2"], 'singlequote');
-      expect(result).toBe("'test','test\\'2'");
-    });
-
-    it('single value and doublequote format should render string with value enclosed in double quotes', () => {
-      const result = _templateSrv.formatValue('test', 'doublequote');
-      expect(result).toBe('"test"');
-    });
-
-    it('multi value and doublequote format should render string with values enclosed in double quotes', () => {
-      const result = _templateSrv.formatValue(['test', 'test"2'], 'doublequote');
-      expect(result).toBe('"test","test\\"2"');
-    });
-
-    it('single value and sqlstring format should render string with value enclosed in single quotes', () => {
-      const result = _templateSrv.formatValue("test'value", 'sqlstring');
-      expect(result).toBe(`'test''value'`);
-    });
-
-    it('multi value and sqlstring format should render string with values enclosed in single quotes', () => {
-      const result = _templateSrv.formatValue(['test', "test'value2"], 'sqlstring');
-      expect(result).toBe(`'test','test''value2'`);
-    });
-
-    it('raw format should leave value intact and do no escaping', () => {
-      const result = _templateSrv.formatValue("'test\n", 'raw');
-      expect(result).toBe("'test\n");
-    });
-  });
-
   describe('can check if variable exists', () => {
     beforeEach(() => {
       _templateSrv = initTemplateSrv(key, [{ type: 'query', name: 'test', current: { value: 'oogle' } }]);
@@ -650,9 +646,10 @@ describe('templateSrv', () => {
     });
 
     it('should not pass object to custom function', () => {
-      let passedValue: any = null;
-      _templateSrv.replace('this.${test}.filters', {}, (value: any) => {
+      let passedValue: string | null = null;
+      _templateSrv.replace('this.${test}.filters', {}, (value: string) => {
         passedValue = value;
+        return '';
       });
 
       expect(passedValue).toBe('[object Object]');
@@ -666,9 +663,10 @@ describe('templateSrv', () => {
     });
 
     it('should not pass object to custom function', () => {
-      let passedValue: any = null;
-      _templateSrv.replace('this.${test}.filters', {}, (value: any) => {
+      let passedValue: string | null = null;
+      _templateSrv.replace('this.${test}.filters', {}, (value: string) => {
         passedValue = value;
+        return '';
       });
 
       expect(passedValue).toBe('hello');
@@ -700,9 +698,9 @@ describe('templateSrv', () => {
     });
 
     it(`should not be handled by any registry items except for queryparam`, () => {
-      const registryItems = Object.values(FormatRegistryID);
+      const registryItems = Object.values(VariableFormatID);
       for (const registryItem of registryItems) {
-        if (registryItem === FormatRegistryID.queryParam) {
+        if (registryItem === VariableFormatID.QueryParam) {
           continue;
         }
 
@@ -811,4 +809,19 @@ describe('templateSrv', () => {
       expect(target).toBe('var-adhoc=value2');
     });
   });
+
+  describe('scenes compatibility', () => {
+    beforeEach(() => {
+      _templateSrv = initTemplateSrv(key, []);
+    });
+    it('should use scene interpolator when scoped var provided', () => {
+      const variable = new TestVariable({});
+
+      _templateSrv.replace('test ${test}', { __sceneObject: { value: variable, text: 'foo' } });
+
+      expect(interpolateMock).toHaveBeenCalledTimes(1);
+      expect(interpolateMock.mock.calls[0][0]).toEqual(variable);
+      expect(interpolateMock.mock.calls[0][1]).toEqual('test ${test}');
+    });
+  });
 });
