@@ -1,13 +1,17 @@
-import React from 'react';
-
-import { DataTransformerID, standardTransformers, TransformerRegistryItem, TransformerUIProps } from '@grafana/data';
+import {
+  DataTransformerID,
+  standardTransformers,
+  TransformerRegistryItem,
+  TransformerUIProps,
+  TransformerCategory,
+} from '@grafana/data';
 import { SeriesToRowsTransformerOptions } from '@grafana/data/src/transformations/transformers/seriesToRows';
 
-export const SeriesToRowsTransformerEditor: React.FC<TransformerUIProps<SeriesToRowsTransformerOptions>> = ({
+export const SeriesToRowsTransformerEditor = ({
   input,
   options,
   onChange,
-}) => {
+}: TransformerUIProps<SeriesToRowsTransformerOptions>) => {
   return null;
 };
 
@@ -18,4 +22,5 @@ export const seriesToRowsTransformerRegistryItem: TransformerRegistryItem<Series
   name: 'Series to rows',
   description: `Merge many series and return a single series with time, metric and value as columns.
                 Useful for showing multiple time series visualized in a table.`,
+  categories: new Set([TransformerCategory.Combine, TransformerCategory.Reformat]),
 };
