@@ -1,4 +1,4 @@
-import React, { FC } from 'react';
+import React from 'react';
 
 import { DataSourceRef, MetricFindValue, SelectableValue } from '@grafana/data';
 import { SegmentAsync } from '@grafana/ui';
@@ -11,15 +11,17 @@ interface Props {
   filterValue?: string;
   onChange: (item: SelectableValue<string>) => void;
   placeHolder?: string;
+  disabled?: boolean;
 }
 
-export const AdHocFilterValue: FC<Props> = ({ datasource, onChange, filterKey, filterValue, placeHolder }) => {
+export const AdHocFilterValue = ({ datasource, disabled, onChange, filterKey, filterValue, placeHolder }: Props) => {
   const loadValues = () => fetchFilterValues(datasource, filterKey);
 
   return (
     <div className="gf-form" data-testid="AdHocFilterValue-value-wrapper">
       <SegmentAsync
         className="query-segment-value"
+        disabled={disabled}
         placeholder={placeHolder}
         value={filterValue}
         onChange={onChange}
