@@ -1,45 +1,44 @@
-import React, { ChangeEvent, FocusEvent, PureComponent } from 'react';
-import { selectors } from '@grafana/e2e-selectors';
-import { VerticalGroup } from '@grafana/ui';
+import React, { FormEvent, PureComponent } from 'react';
 
-import { ConstantVariableModel } from '../types';
-import { VariableEditorProps } from '../editor/types';
-import { VariableSectionHeader } from '../editor/VariableSectionHeader';
+import { selectors } from '@grafana/e2e-selectors';
+
+import { VariableLegend } from '../editor/VariableLegend';
 import { VariableTextField } from '../editor/VariableTextField';
+import { VariableEditorProps } from '../editor/types';
+import { ConstantVariableModel } from '../types';
 
 export interface Props extends VariableEditorProps<ConstantVariableModel> {}
 
 export class ConstantVariableEditor extends PureComponent<Props> {
-  onChange = (event: ChangeEvent<HTMLInputElement>) => {
+  onChange = (event: FormEvent<HTMLInputElement>) => {
     this.props.onPropChange({
       propName: 'query',
-      propValue: event.target.value,
+      propValue: event.currentTarget.value,
     });
   };
 
-  onBlur = (event: FocusEvent<HTMLInputElement>) => {
+  onBlur = (event: FormEvent<HTMLInputElement>) => {
     this.props.onPropChange({
       propName: 'query',
-      propValue: event.target.value,
+      propValue: event.currentTarget.value,
       updateOptions: true,
     });
   };
 
   render() {
     return (
-      <VerticalGroup spacing="xs">
-        <VariableSectionHeader name="Constant Options" />
+      <>
+        <VariableLegend>Constant options</VariableLegend>
         <VariableTextField
           value={this.props.variable.query}
           name="Value"
           placeholder="your metric prefix"
           onChange={this.onChange}
           onBlur={this.onBlur}
-          labelWidth={20}
-          ariaLabel={selectors.pages.Dashboard.Settings.Variables.Edit.ConstantVariable.constantOptionsQueryInput}
-          grow
+          testId={selectors.pages.Dashboard.Settings.Variables.Edit.ConstantVariable.constantOptionsQueryInputV2}
+          width={30}
         />
-      </VerticalGroup>
+      </>
     );
   }
 }
