@@ -11,9 +11,7 @@ export interface VariableValuesPreviewProps {
   variable: VariableWithOptions;
 }
 
-export const VariableValuesPreview: React.FunctionComponent<VariableValuesPreviewProps> = ({
-  variable: { options },
-}) => {
+export const VariableValuesPreview = ({ variable: { options } }: VariableValuesPreviewProps) => {
   const [previewLimit, setPreviewLimit] = useState(20);
   const [previewOptions, setPreviewOptions] = useState<VariableOption[]>([]);
   const showMoreOptions = useCallback(
