@@ -3,8 +3,9 @@ import { connect, ConnectedProps } from 'react-redux';
 
 import { DataSourceInstanceSettings, getDataSourceRef, LoadingState, SelectableValue } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { DataSourcePicker, getTemplateSrv } from '@grafana/runtime';
+import { getTemplateSrv } from '@grafana/runtime';
 import { Field } from '@grafana/ui';
+import { DataSourcePicker } from 'app/features/datasources/components/picker/DataSourcePicker';
 
 import { StoreState } from '../../../types';
 import { getTimeSrv } from '../../dashboard/services/TimeSrv';
@@ -134,14 +135,25 @@ export class QueryVariableEditorUnConnected extends PureComponent<Props, State>
       return null;
     }
 
-    const query = variable.query;
     const datasource = extended.dataSource;
     const VariableQueryEditor = extended.VariableQueryEditor;
 
+    let query = variable.query;
+
+    if (typeof query === 'string') {
+      query = query || (datasource.variables?.getDefaultQuery?.() ?? '');
+    } else {
+      query = {
+        ...datasource.variables?.getDefaultQuery?.(),
+        ...variable.query,
+      };
+    }
+
     if (isLegacyQueryEditor(VariableQueryEditor, datasource)) {
       return (
         <Field label="Query">
           <VariableQueryEditor
+            key={datasource.uid}
             datasource={datasource}
             query={query}
             templateSrv={getTemplateSrv()}
@@ -157,6 +169,7 @@ export class QueryVariableEditorUnConnected extends PureComponent<Props, State>
       return (
         <Field label="Query">
           <VariableQueryEditor
+            key={datasource.uid}
             datasource={datasource}
             query={query}
             onChange={this.onQueryChange}
