@@ -27,12 +27,12 @@ export function QueryVariableSortSelect({ onChange, sort }: PropsWithChildren<Pr
   return (
     <VariableSelectField
       name="Sort"
+      description="How to sort the values of this variable"
       value={value}
       options={SORT_OPTIONS}
       onChange={onChange}
-      labelWidth={10}
       testId={selectors.pages.Dashboard.Settings.Variables.Edit.QueryVariable.queryOptionsSortSelectV2}
-      tooltip="How to sort the values of this variable."
+      width={25}
     />
   );
 }
