@@ -1,6 +1,6 @@
 import { of } from 'rxjs';
 
-import { FieldType, toDataFrame } from '@grafana/data';
+import { FieldType, PanelData, toDataFrame } from '@grafana/data';
 
 import { queryBuilder } from '../shared/testing/builders';
 import { toKeyedAction } from '../state/keyedVariablesReducer';
@@ -130,7 +130,7 @@ describe('operators', () => {
     ].map((scenario) => {
       it(`when called with series:${JSON.stringify(scenario.series, null, 0)}`, async () => {
         const { series, expected } = scenario;
-        const panelData: any = { series };
+        const panelData = { series } as PanelData;
         const observable = of(panelData).pipe(toMetricFindValues());
 
         await expect(observable).toEmitValuesWith((received) => {
@@ -146,7 +146,7 @@ describe('operators', () => {
           fields: [{ name: 'time', type: FieldType.time, values: [1, 2, 3] }],
         });
 
-        const panelData: any = { series: [frameWithTimeField] };
+        const panelData = { series: [frameWithTimeField] } as PanelData;
         const observable = of(panelData).pipe(toMetricFindValues());
 
         await expect(observable).toEmitValuesWith((received) => {
