@@ -1,8 +1,10 @@
-import { DataSourceVariableModel, VariableRefresh } from 'app/features/variables/types';
+import { DataSourceVariableModel, QueryVariableModel, VariableRefresh } from 'app/features/variables/types';
 
 import { MultiVariableBuilder } from './multiVariableBuilder';
 
-export class DatasourceVariableBuilder<T extends DataSourceVariableModel> extends MultiVariableBuilder<T> {
+export class DatasourceVariableBuilder<
+  T extends DataSourceVariableModel | QueryVariableModel,
+> extends MultiVariableBuilder<T> {
   withRefresh(refresh: VariableRefresh) {
     this.variable.refresh = refresh;
     return this;
