@@ -1,6 +1,6 @@
 import { isArray, isEqual } from 'lodash';
 
-import { ScopedVars, UrlQueryMap, UrlQueryValue, VariableType } from '@grafana/data';
+import { UrlQueryMap, UrlQueryValue, VariableType } from '@grafana/data';
 import { getTemplateSrv } from '@grafana/runtime';
 import { safeStringifyValue } from 'app/core/utils/explore';
 
@@ -9,16 +9,17 @@ import { StoreState } from '../../types';
 import { getTimeSrv } from '../dashboard/services/TimeSrv';
 
 import { variableAdapters } from './adapters';
-import { ALL_VARIABLE_TEXT, ALL_VARIABLE_VALUE } from './constants';
+import { ALL_VARIABLE_TEXT, ALL_VARIABLE_VALUE, VARIABLE_PREFIX } from './constants';
 import { getVariablesState } from './state/selectors';
 import { KeyedVariableIdentifier, VariableIdentifier, VariablePayload } from './state/types';
 import { QueryVariableModel, TransactionStatus, VariableModel, VariableRefresh, VariableWithOptions } from './types';
 
 /*
  * This regex matches 3 types of variable reference with an optional format specifier
- * \$(\w+)                          $var1
- * \[\[(\w+?)(?::(\w+))?\]\]        [[var2]] or [[var2:fmt2]]
- * \${(\w+)(?::(\w+))?}             ${var3} or ${var3:fmt3}
+ * There are 6 capture groups that replace will return
+ * \$(\w+)                                    $var1
+ * \[\[(\w+?)(?::(\w+))?\]\]                  [[var2]] or [[var2:fmt2]]
+ * \${(\w+)(?:\.([^:^\}]+))?(?::([^\}]+))?}   ${var3} or ${var3.fieldPath} or ${var3:fmt3} (or ${var3.fieldPath:fmt3} but that is not a separate capture group)
  */
 export const variableRegex = /\$(\w+)|\[\[(\w+?)(?::(\w+))?\]\]|\${(\w+)(?:\.([^:^\}]+))?(?::([^\}]+))?}/g;
 
@@ -28,38 +29,6 @@ export const variableRegexExec = (variableString: string) => {
   return variableRegex.exec(variableString);
 };
 
-export const SEARCH_FILTER_VARIABLE = '__searchFilter';
-
-export const containsSearchFilter = (query: string | unknown): boolean =>
-  query && typeof query === 'string' ? query.indexOf(SEARCH_FILTER_VARIABLE) !== -1 : false;
-
-export interface SearchFilterOptions {
-  searchFilter?: string;
-}
-
-export const getSearchFilterScopedVar = (args: {
-  query: string;
-  wildcardChar: string;
-  options?: SearchFilterOptions;
-}): ScopedVars => {
-  const { query, wildcardChar } = args;
-  if (!containsSearchFilter(query)) {
-    return {};
-  }
-
-  let { options } = args;
-
-  options = options || { searchFilter: '' };
-  const value = options.searchFilter ? `${options.searchFilter}${wildcardChar}` : `${wildcardChar}`;
-
-  return {
-    __searchFilter: {
-      value,
-      text: '',
-    },
-  };
-};
-
 export function containsVariable(...args: any[]) {
   const variableName = args[args.length - 1];
   args[0] = typeof args[0] === 'string' ? args[0] : safeStringifyValue(args[0]);
@@ -224,7 +193,7 @@ export function findTemplateVarChanges(query: UrlQueryMap, old: UrlQueryMap): Ex
   const changes: ExtendedUrlQueryMap = {};
 
   for (const key in query) {
-    if (!key.startsWith('var-')) {
+    if (!key.startsWith(VARIABLE_PREFIX)) {
       continue;
     }
 
@@ -238,7 +207,7 @@ export function findTemplateVarChanges(query: UrlQueryMap, old: UrlQueryMap): Ex
   }
 
   for (const key in old) {
-    if (!key.startsWith('var-')) {
+    if (!key.startsWith(VARIABLE_PREFIX)) {
       continue;
     }
 
