@@ -1,8 +1,9 @@
-import isString from 'lodash/isString';
-import { alignmentPeriods, MetricKind, selectors, ValueTypes } from './constants';
-import CloudMonitoringDatasource from './datasource';
-import { CloudMonitoringVariableQuery, MetricFindQueryTypes } from './types';
+import { isString } from 'lodash';
+
 import { SelectableValue } from '@grafana/data';
+
+import { ALIGNMENT_PERIODS, SELECTORS } from './constants';
+import CloudMonitoringDatasource from './datasource';
 import {
   extractServicesFromMetricDescriptors,
   getAggregationOptionsByMetric,
@@ -10,6 +11,8 @@ import {
   getLabelKeys,
   getMetricTypesByService,
 } from './functions';
+import { MetricKind, ValueTypes, MetricFindQueryTypes } from './types/query';
+import { CloudMonitoringVariableQuery, MetricDescriptor } from './types/types';
 
 export default class CloudMonitoringMetricFindQuery {
   constructor(private datasource: CloudMonitoringDatasource) {}
@@ -65,7 +68,7 @@ export default class CloudMonitoringMetricFindQuery {
 
   async handleServiceQuery({ projectName }: CloudMonitoringVariableQuery) {
     const metricDescriptors = await this.datasource.getMetricTypes(projectName);
-    const services: any[] = extractServicesFromMetricDescriptors(metricDescriptors);
+    const services: MetricDescriptor[] = extractServicesFromMetricDescriptors(metricDescriptors);
     return services.map((s) => ({
       text: s.serviceShortName,
       value: s.service,
@@ -79,7 +82,7 @@ export default class CloudMonitoringMetricFindQuery {
     }
     const metricDescriptors = await this.datasource.getMetricTypes(projectName);
     return getMetricTypesByService(metricDescriptors, this.datasource.templateSrv.replace(selectedService)).map(
-      (s: any) => ({
+      (s) => ({
         text: s.displayName,
         value: s.type,
         expandable: true,
@@ -100,7 +103,11 @@ export default class CloudMonitoringMetricFindQuery {
       return [];
     }
     const refId = 'handleLabelValuesQuery';
-    const labels = await this.datasource.getLabels(selectedMetricType, refId, projectName, [labelKey]);
+    // REDUCE_MEAN is needed so the groupBy is not ignored
+    const labels = await this.datasource.getLabels(selectedMetricType, refId, projectName, {
+      groupBys: [labelKey],
+      crossSeriesReducer: 'REDUCE_MEAN',
+    });
     const interpolatedKey = this.datasource.templateSrv.replace(labelKey);
     const values = labels.hasOwnProperty(interpolatedKey) ? labels[interpolatedKey] : [];
     return values.map(this.toFindQueryResult);
@@ -121,7 +128,7 @@ export default class CloudMonitoringMetricFindQuery {
     }
     const metricDescriptors = await this.datasource.getMetricTypes(projectName);
     const descriptor = metricDescriptors.find(
-      (m: any) => m.type === this.datasource.templateSrv.replace(selectedMetricType)
+      (m) => m.type === this.datasource.templateSrv.replace(selectedMetricType)
     );
 
     if (!descriptor) {
@@ -138,7 +145,7 @@ export default class CloudMonitoringMetricFindQuery {
 
     const metricDescriptors = await this.datasource.getMetricTypes(projectName);
     const descriptor = metricDescriptors.find(
-      (m: any) => m.type === this.datasource.templateSrv.replace(selectedMetricType)
+      (m) => m.type === this.datasource.templateSrv.replace(selectedMetricType)
     );
 
     if (!descriptor) {
@@ -161,11 +168,11 @@ export default class CloudMonitoringMetricFindQuery {
   }
 
   async handleSelectorQuery() {
-    return selectors.map(this.toFindQueryResult);
+    return SELECTORS.map(this.toFindQueryResult);
   }
 
   handleAlignmentPeriodQuery() {
-    return alignmentPeriods.map(this.toFindQueryResult);
+    return ALIGNMENT_PERIODS.map(this.toFindQueryResult);
   }
 
   toFindQueryResult(x: any) {
