@@ -1,3 +1,4 @@
+import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { TemplateSrv } from 'app/features/templating/template_srv';
 import { TemplateSrvMock } from 'app/features/templating/template_srv.mock';
 
@@ -13,9 +14,12 @@ export const createMockDatasource = (overrides?: Partial<Datasource>) => {
     getProjects: jest.fn().mockResolvedValue([]),
     getDefaultProject: jest.fn().mockReturnValue('cloud-monitoring-default-project'),
     templateSrv,
+    filterMetricsByType: jest.fn().mockResolvedValue([]),
     getSLOServices: jest.fn().mockResolvedValue([]),
+    migrateQuery: jest.fn().mockImplementation((query) => query),
+    timeSrv: getTimeSrv(),
     ...overrides,
   };
 
-  return jest.mocked(datasource as Datasource, true);
+  return jest.mocked(datasource as Datasource);
 };
