@@ -1,13 +1,16 @@
-import React, { FunctionComponent, useState } from 'react';
 import { debounce } from 'lodash';
-import { QueryInlineField } from '.';
+import React, { useState } from 'react';
+
+import { EditorField } from '@grafana/experimental';
+import { Input } from '@grafana/ui';
 
 export interface Props {
+  refId: string;
   onChange: (alias: any) => void;
   value?: string;
 }
 
-export const AliasBy: FunctionComponent<Props> = ({ value = '', onChange }) => {
+export const AliasBy = ({ refId, value = '', onChange }: Props) => {
   const [alias, setAlias] = useState(value ?? '');
 
   const propagateOnChange = debounce(onChange, 1000);
@@ -18,8 +21,8 @@ export const AliasBy: FunctionComponent<Props> = ({ value = '', onChange }) => {
   };
 
   return (
-    <QueryInlineField label="Alias By">
-      <input type="text" className="gf-form-input width-26" value={alias} onChange={onChange} />
-    </QueryInlineField>
+    <EditorField label="Alias by">
+      <Input id={`${refId}-alias-by`} value={alias} onChange={onChange} />
+    </EditorField>
   );
 };
