@@ -19,24 +19,26 @@ export type Props = {
   datasource: CloudWatchDatasource;
   disableExpressions?: boolean;
   onChange: (value: MetricStat) => void;
-  onRunQuery: () => void;
 };
 
+const percentileSyntaxRE = /^(p|tm|tc|ts|wm)\d{2}(?:\.\d{1,2})?$/;
+const boundariesInnerParenthesesSyntax = `\\d*(\\.\\d+)?%?:\\d*(\\.\\d+)?%?`;
+const boundariesSyntaxRE = new RegExp(`^(PR|TM|TC|TS|WM)\\((${boundariesInnerParenthesesSyntax})\\)$`);
+
 export function MetricStatEditor({
   refId,
   metricStat,
   datasource,
   disableExpressions = false,
   onChange,
-  onRunQuery,
 }: React.PropsWithChildren<Props>) {
   const namespaces = useNamespaces(datasource);
   const metrics = useMetrics(datasource, metricStat);
   const dimensionKeys = useDimensionKeys(datasource, { ...metricStat, dimensionFilters: metricStat.dimensions });
-  const accountState = useAccountOptions(datasource.api, metricStat.region);
+  const accountState = useAccountOptions(datasource.resources, metricStat.region);
 
   useEffect(() => {
-    datasource.api.isMonitoringAccount(metricStat.region).then((isMonitoringAccount) => {
+    datasource.resources.isMonitoringAccount(metricStat.region).then((isMonitoringAccount) => {
       if (isMonitoringAccount && !accountState.loading && accountState.value?.length && !metricStat.accountId) {
         onChange({ ...metricStat, accountId: 'all' });
       }
@@ -45,16 +47,11 @@ export function MetricStatEditor({
         onChange({ ...metricStat, accountId: undefined });
       }
     });
-  }, [accountState, metricStat, onChange, datasource.api]);
-
-  const onMetricStatChange = (metricStat: MetricStat) => {
-    onChange(metricStat);
-    onRunQuery();
-  };
+  }, [accountState, metricStat, onChange, datasource.resources]);
 
   const onNamespaceChange = async (metricStat: MetricStat) => {
     const validatedQuery = await validateMetricName(metricStat);
-    onMetricStatChange(validatedQuery);
+    onChange(validatedQuery);
   };
 
   const validateMetricName = async (metricStat: MetricStat) => {
@@ -62,7 +59,7 @@ export function MetricStatEditor({
     if (!metricName) {
       return metricStat;
     }
-    await datasource.api.getMetrics({ namespace, region }).then((result: Array<SelectableValue<string>>) => {
+    await datasource.resources.getMetrics({ namespace, region }).then((result: Array<SelectableValue<string>>) => {
       if (!result.find((metric) => metric.value === metricName)) {
         metricName = '';
       }
@@ -78,7 +75,6 @@ export function MetricStatEditor({
             accountId={metricStat.accountId}
             onChange={(accountId?: string) => {
               onChange({ ...metricStat, accountId });
-              onRunQuery();
             }}
             accountOptions={accountState?.value || []}
           ></Account>
@@ -105,7 +101,7 @@ export function MetricStatEditor({
               options={metrics}
               onChange={({ value: metricName }) => {
                 if (metricName) {
-                  onMetricStatChange({ ...metricStat, metricName });
+                  onChange({ ...metricStat, metricName });
                 }
               }}
             />
@@ -124,13 +120,13 @@ export function MetricStatEditor({
                 if (
                   !statistic ||
                   (!standardStatistics.includes(statistic) &&
-                    !/^p\d{2}(?:\.\d{1,2})?$/.test(statistic) &&
-                    !statistic.startsWith('$'))
+                    !(percentileSyntaxRE.test(statistic) || boundariesSyntaxRE.test(statistic)) &&
+                    !datasource.templateSrv.containsTemplate(statistic))
                 ) {
                   return;
                 }
 
-                onMetricStatChange({ ...metricStat, statistic });
+                onChange({ ...metricStat, statistic });
               }}
             />
           </EditorField>
@@ -141,7 +137,7 @@ export function MetricStatEditor({
         <EditorField label="Dimensions">
           <Dimensions
             metricStat={metricStat}
-            onChange={(dimensions) => onMetricStatChange({ ...metricStat, dimensions })}
+            onChange={(dimensions) => onChange({ ...metricStat, dimensions })}
             dimensionKeys={dimensionKeys}
             disableExpressions={disableExpressions}
             datasource={datasource}
@@ -157,7 +153,7 @@ export function MetricStatEditor({
               id={`${refId}-cloudwatch-match-exact`}
               value={!!metricStat.matchExact}
               onChange={(e) => {
-                onMetricStatChange({
+                onChange({
                   ...metricStat,
                   matchExact: e.currentTarget.checked,
                 });
