@@ -1,8 +1,7 @@
 export { Dimensions } from './Dimensions/Dimensions';
 export { QueryInlineField, QueryField } from './Forms';
-export { PanelQueryEditor } from './PanelQueryEditor';
+export { QueryEditor as PanelQueryEditor } from './QueryEditor';
 export { CloudWatchLogsQueryEditor } from './LogsQueryEditor';
 export { MetricStatEditor } from './MetricStatEditor';
 export { SQLBuilderEditor } from './SQLBuilderEditor';
 export { MathExpressionQueryField } from './MathExpressionQueryField';
-export { SQLCodeEditor } from './SQLCodeEditor';
