@@ -1,9 +1,11 @@
-import React, { FunctionComponent } from 'react';
-import { css, cx } from 'emotion';
+import { css, cx } from '@emotion/css';
+import React from 'react';
+
 import { SelectableValue } from '@grafana/data';
 import { Segment } from '@grafana/ui';
+
+import { MetricAggregation } from '../types';
 import { describeMetric } from '../utils';
-import { MetricAggregation } from './QueryEditor/MetricAggregationsEditor/aggregations';
 
 const noWrap = css`
   white-space: nowrap;
@@ -23,12 +25,16 @@ interface Props {
   value?: string;
 }
 
-export const MetricPicker: FunctionComponent<Props> = ({ options, onChange, className, value }) => (
-  <Segment
-    className={cx(className, noWrap)}
-    options={toOptions(options)}
-    onChange={onChange}
-    placeholder="Select Metric"
-    value={!!value ? toOption(options.find((option) => option.id === value)!) : null}
-  />
-);
+export const MetricPicker = ({ options, onChange, className, value }: Props) => {
+  const selectedOption = options.find((option) => option.id === value);
+
+  return (
+    <Segment
+      className={cx(className, noWrap)}
+      options={toOptions(options)}
+      onChange={onChange}
+      placeholder="Select Metric"
+      value={!!selectedOption ? toOption(selectedOption) : undefined}
+    />
+  );
+};
