@@ -1,20 +1,20 @@
-import _ from 'lodash';
-import queryPart from './query_part';
-import kbn from 'app/core/utils/kbn';
-import { InfluxQuery, InfluxQueryTag } from './types';
-import { ScopedVars } from '@grafana/data';
+import { filter, find, indexOf, map } from 'lodash';
+
+import { escapeRegex, ScopedVars } from '@grafana/data';
 import { TemplateSrv } from '@grafana/runtime';
 
+import queryPart from './query_part';
+import { InfluxQuery, InfluxQueryTag } from './types';
+
 export default class InfluxQueryModel {
   target: InfluxQuery;
-  selectModels: any[];
+  selectModels: any[] = [];
   queryBuilder: any;
   groupByParts: any;
   templateSrv: any;
   scopedVars: any;
   refId?: string;
 
-  /** @ngInject */
   constructor(target: InfluxQuery, templateSrv?: TemplateSrv, scopedVars?: ScopedVars) {
     this.target = target;
     this.templateSrv = templateSrv;
@@ -39,26 +39,26 @@ export default class InfluxQueryModel {
   }
 
   updateProjection() {
-    this.selectModels = _.map(this.target.select, (parts: any) => {
-      return _.map(parts, queryPart.create);
+    this.selectModels = map(this.target.select, (parts: any) => {
+      return map(parts, queryPart.create);
     });
-    this.groupByParts = _.map(this.target.groupBy, queryPart.create);
+    this.groupByParts = map(this.target.groupBy, queryPart.create);
   }
 
   updatePersistedParts() {
-    this.target.select = _.map(this.selectModels, (selectParts) => {
-      return _.map(selectParts, (part: any) => {
+    this.target.select = map(this.selectModels, (selectParts) => {
+      return map(selectParts, (part: any) => {
         return { type: part.def.type, params: part.params };
       });
     });
   }
 
   hasGroupByTime() {
-    return _.find(this.target.groupBy, (g: any) => g.type === 'time');
+    return find(this.target.groupBy, (g: any) => g.type === 'time');
   }
 
   hasFill() {
-    return _.find(this.target.groupBy, (g: any) => g.type === 'fill');
+    return find(this.target.groupBy, (g: any) => g.type === 'fill');
   }
 
   addGroupBy(value: string) {
@@ -95,10 +95,10 @@ export default class InfluxQueryModel {
 
     if (part.def.type === 'time') {
       // remove fill
-      this.target.groupBy = _.filter(this.target.groupBy, (g: any) => g.type !== 'fill');
+      this.target.groupBy = filter(this.target.groupBy, (g: any) => g.type !== 'fill');
       // remove aggregations
-      this.target.select = _.map(this.target.select, (s: any) => {
-        return _.filter(s, (part: any) => {
+      this.target.select = map(this.target.select, (s: any) => {
+        return filter(s, (part: any) => {
           const partModel = queryPart.create(part);
           if (partModel.def.category === categories.Aggregations) {
             return false;
@@ -124,11 +124,11 @@ export default class InfluxQueryModel {
     // if we remove the field remove the whole statement
     if (part.def.type === 'field') {
       if (this.selectModels.length > 1) {
-        const modelsIndex = _.indexOf(this.selectModels, selectParts);
+        const modelsIndex = indexOf(this.selectModels, selectParts);
         this.selectModels.splice(modelsIndex, 1);
       }
     } else {
-      const partIndex = _.indexOf(selectParts, part);
+      const partIndex = indexOf(selectParts, part);
       selectParts.splice(partIndex, 1);
     }
 
@@ -142,6 +142,7 @@ export default class InfluxQueryModel {
   }
 
   private renderTagCondition(tag: InfluxQueryTag, index: number, interpolate?: boolean) {
+    // FIXME: merge this function with query_builder/renderTagCondition
     let str = '';
     let operator = tag.operator;
     let value = tag.value;
@@ -169,10 +170,20 @@ export default class InfluxQueryModel {
       value = this.templateSrv.replace(value, this.scopedVars, 'regex');
     }
 
-    return str + '"' + tag.key + '" ' + operator + ' ' + value;
+    let escapedKey = `"${tag.key}"`;
+
+    if (tag.key.endsWith('::tag')) {
+      escapedKey = `"${tag.key.slice(0, -5)}"::tag`;
+    }
+
+    if (tag.key.endsWith('::field')) {
+      escapedKey = `"${tag.key.slice(0, -7)}"::field`;
+    }
+
+    return str + escapedKey + ' ' + operator + ' ' + value;
   }
 
-  getMeasurementAndPolicy(interpolate: any) {
+  getMeasurementAndPolicy(interpolate?: boolean) {
     let policy = this.target.policy;
     let measurement = this.target.measurement || 'measurement';
 
@@ -198,10 +209,10 @@ export default class InfluxQueryModel {
     }
 
     if (typeof value === 'string') {
-      return kbn.regexEscape(value);
+      return escapeRegex(value);
     }
 
-    const escapedValues = _.map(value, kbn.regexEscape);
+    const escapedValues = map(value, escapeRegex);
     return '(' + escapedValues.join('|') + ')';
   }
 
@@ -233,7 +244,7 @@ export default class InfluxQueryModel {
     }
 
     query += ' FROM ' + this.getMeasurementAndPolicy(interpolate) + ' WHERE ';
-    const conditions = _.map(target.tags, (tag, index) => {
+    const conditions = map(target.tags, (tag, index) => {
       return this.renderTagCondition(tag, index, interpolate);
     });
 
@@ -281,7 +292,7 @@ export default class InfluxQueryModel {
   }
 
   renderAdhocFilters(filters: any[]) {
-    const conditions = _.map(filters, (tag, index) => {
+    const conditions = map(filters, (tag, index) => {
       return this.renderTagCondition(tag, index, true);
     });
     return conditions.join(' ');
