@@ -1,7 +1,7 @@
 import { each, flatten, groupBy, isArray } from 'lodash';
 
-import { AnnotationEvent, DataFrame, DataQuery, FieldType, QueryResultMeta } from '@grafana/data';
-import { toDataQueryResponse } from '@grafana/runtime';
+import { AnnotationEvent, DataFrame, FieldType, QueryResultMeta } from '@grafana/data';
+import { BackendDataSourceResponse, FetchResponse, toDataQueryResponse } from '@grafana/runtime';
 import TableModel from 'app/core/TableModel';
 
 import { InfluxQuery } from './types';
@@ -18,8 +18,8 @@ export default class ResponseParser {
     }
 
     const normalizedQuery = query.toLowerCase();
-    const isValueFirst =
-      normalizedQuery.indexOf('show field keys') >= 0 || normalizedQuery.indexOf('show retention policies') >= 0;
+    const isRetentionPolicyQuery = normalizedQuery.indexOf('show retention policies') >= 0;
+    const isValueFirst = normalizedQuery.indexOf('show field keys') >= 0 || isRetentionPolicyQuery;
 
     const res = new Set<string>();
     each(influxResults.series, (serie) => {
@@ -38,14 +38,14 @@ export default class ResponseParser {
           // (while the newer versions—first).
 
           if (isValueFirst) {
-            addUnique(res, value[0]);
+            res.add(value[0].toString());
           } else if (value[1] !== undefined) {
-            addUnique(res, value[1]);
+            res.add(value[1].toString());
           } else {
-            addUnique(res, value[0]);
+            res.add(value[0].toString());
           }
         } else {
-          addUnique(res, value);
+          res.add(value.toString());
         }
       });
     });
@@ -71,14 +71,14 @@ export default class ResponseParser {
 
       // if group by tag(s) added
       if (dfs[0].fields[1] && dfs[0].fields[1].labels) {
-        let dfsByLabels: any = groupBy(dfs, (df: DataFrame) =>
+        let dfsByLabels = groupBy(dfs, (df: DataFrame) =>
           df.fields[1].labels ? Object.values(df.fields[1].labels!) : null
         );
         const labels = Object.keys(dfsByLabels);
-        dfsByLabels = Object.values(dfsByLabels);
+        const dfsByLabelValues = Object.values(dfsByLabels);
 
-        for (let i = 0; i < dfsByLabels.length; i++) {
-          table = getTableRows(dfsByLabels[i], table, [...labels[i].split(',')]);
+        for (let i = 0; i < dfsByLabelValues.length; i++) {
+          table = getTableRows(dfsByLabelValues[i], table, [...labels[i].split(',')]);
         }
       } else {
         table = getTableRows(dfs, table, []);
@@ -88,77 +88,82 @@ export default class ResponseParser {
     return table;
   }
 
-  async transformAnnotationResponse(annotation: any, data: any, target: InfluxQuery): Promise<AnnotationEvent[]> {
-    const rsp = toDataQueryResponse(data, [target] as DataQuery[]);
+  async transformAnnotationResponse(
+    annotation: InfluxQuery,
+    data: FetchResponse<BackendDataSourceResponse>,
+    target: InfluxQuery
+  ): Promise<AnnotationEvent[]> {
+    const rsp = toDataQueryResponse(data, [target]);
 
-    if (rsp) {
-      const table = this.getTable(rsp.data, target, {});
-      const list: any[] = [];
-      let titleCol: any = null;
-      let timeCol: any = null;
-      let timeEndCol: any = null;
-      const tagsCol: any = [];
-      let textCol: any = null;
-
-      each(table.columns, (column, index) => {
-        if (column.text.toLowerCase() === 'time') {
-          timeCol = index;
-          return;
-        }
-        if (column.text === annotation.titleColumn) {
-          titleCol = index;
-          return;
-        }
-        if (colContainsTag(column.text, annotation.tagsColumn)) {
-          tagsCol.push(index);
-          return;
-        }
-        if (column.text.includes(annotation.textColumn)) {
-          textCol = index;
-          return;
-        }
-        if (column.text === annotation.timeEndColumn) {
-          timeEndCol = index;
-          return;
-        }
-        // legacy case
-        if (!titleCol && textCol !== index) {
-          titleCol = index;
-        }
-      });
-
-      each(table.rows, (value) => {
-        const data = {
-          annotation: annotation,
-          time: +new Date(value[timeCol]),
-          title: value[titleCol],
-          timeEnd: value[timeEndCol],
-          // Remove empty values, then split in different tags for comma separated values
-          tags: flatten(
-            tagsCol
-              .filter((t: any) => {
-                return value[t];
-              })
-              .map((t: any) => {
-                return value[t].split(',');
-              })
-          ),
-          text: value[textCol],
-        };
-
-        list.push(data);
-      });
-
-      return list;
+    if (!rsp) {
+      return [];
     }
-    return [];
+
+    const table = this.getTable(rsp.data, target, {});
+    const list: any[] = [];
+    let titleColIndex = 0;
+    let timeColIndex = 0;
+    let timeEndColIndex = 0;
+    let textColIndex = 0;
+    const tagsColIndexes: number[] = [];
+
+    each(table.columns, (column, index) => {
+      if (column.text.toLowerCase() === 'time') {
+        timeColIndex = index;
+        return;
+      }
+      if (column.text === annotation.titleColumn) {
+        titleColIndex = index;
+        return;
+      }
+      if (colContainsTag(column.text, annotation.tagsColumn)) {
+        tagsColIndexes.push(index);
+        return;
+      }
+      if (annotation.textColumn && column.text.includes(annotation.textColumn)) {
+        textColIndex = index;
+        return;
+      }
+      if (column.text === annotation.timeEndColumn) {
+        timeEndColIndex = index;
+        return;
+      }
+      // legacy case
+      if (!titleColIndex && textColIndex !== index) {
+        titleColIndex = index;
+      }
+    });
+
+    each(table.rows, (value) => {
+      const data = {
+        annotation: annotation,
+        time: +new Date(value[timeColIndex]),
+        title: value[titleColIndex],
+        timeEnd: value[timeEndColIndex],
+        // Remove empty values, then split in different tags for comma separated values
+        tags: flatten(
+          tagsColIndexes
+            .filter((t) => {
+              return value[t];
+            })
+            .map((t) => {
+              return value[t].split(',');
+            })
+        ),
+        text: value[textColIndex],
+      };
+
+      list.push(data);
+    });
+
+    return list;
   }
 }
 
-function colContainsTag(colText: string, tagsColumn: string): boolean {
+function colContainsTag(colText: string, tagsColumn?: string): boolean {
   const tags = (tagsColumn || '').replace(' ', '').split(',');
   for (const tag of tags) {
-    if (colText.includes(tag)) {
+    if (tag !== '' && colText.includes(tag)) {
       return true;
     }
   }
@@ -170,12 +175,12 @@ function getTableCols(dfs: DataFrame[], table: TableModel, target: InfluxQuery):
 
   dfs[0].fields.forEach((field) => {
     // Time col
-    if (field.name === 'time') {
+    if (field.name.toLowerCase() === 'time') {
       table.columns.push({ text: 'Time', type: FieldType.time });
     }
 
     // Group by (label) column(s)
-    else if (field.name === 'value') {
+    else if (field.name.toLowerCase() === 'value') {
       if (field.labels) {
         Object.keys(field.labels).forEach((key) => {
           table.columns.push({ text: key });
@@ -198,16 +203,35 @@ function getTableCols(dfs: DataFrame[], table: TableModel, target: InfluxQuery):
     table.columns.push({ text: selectedParams[i] });
   }
 
+  // ISSUE: https://github.com/grafana/grafana/issues/63842
+  // if rawQuery and
+  // has other selected fields in the query and
+  // dfs field names are in the rawQuery but
+  // the selected params object doesn't exist in the query then
+  // add columns to the table
+  if (
+    target.rawQuery &&
+    selectedParams.length === 0 &&
+    rawQuerySelectedFieldsInDataframe(target.query, dfs) &&
+    dfs[0].refId !== 'metricFindQuery'
+  ) {
+    dfs.map((df) => {
+      if (df.name) {
+        table.columns.push({ text: df.name });
+      }
+    });
+  }
+
   return table;
 }
 
 function getTableRows(dfs: DataFrame[], table: TableModel, labels: string[]): TableModel {
-  const values = dfs[0].fields[0].values.toArray();
+  const values = dfs[0].fields[0].values;
 
   for (let i = 0; i < values.length; i++) {
     const time = values[i];
     const metrics = dfs.map((df: DataFrame) => {
-      return df.fields[1] ? df.fields[1].values.toArray()[i] : null;
+      return df.fields[1] ? df.fields[1].values[i] : null;
     });
     if (metrics.indexOf(null) < 0) {
       table.rows.push([time, ...labels, ...metrics]);
@@ -221,7 +245,12 @@ export function getSelectedParams(target: InfluxQuery): string[] {
   target.select?.forEach((select) => {
     const selector = select.filter((x) => x.type !== 'field');
     if (selector.length > 0) {
-      allParams.push(selector[0].type);
+      const aliasIfExist = selector.find((s) => s.type === 'alias');
+      if (aliasIfExist) {
+        allParams.push(aliasIfExist.params?.[0].toString() ?? '');
+      } else {
+        allParams.push(selector[0].type);
+      }
     } else {
       if (select[0] && select[0].params && select[0].params[0]) {
         allParams.push(select[0].params[0].toString());
@@ -237,14 +266,37 @@ export function getSelectedParams(target: InfluxQuery): string[] {
   return uniqueParams;
 }
 
-function incrementName(name: string, nameIncremenet: string, params: string[], index: number): string {
-  if (params.indexOf(nameIncremenet) > -1) {
+function incrementName(name: string, nameIncrement: string, params: string[], index: number): string {
+  if (params.indexOf(nameIncrement) > -1) {
     index++;
     return incrementName(name, name + '_' + index, params, index);
   }
-  return nameIncremenet;
+  return nameIncrement;
 }
 
-function addUnique(s: Set<string>, value: string | number) {
-  s.add(value.toString());
+function rawQuerySelectedFieldsInDataframe(query: string | undefined, dfs: DataFrame[]) {
+  const names: Array<string | undefined> = dfs.map((df: DataFrame) => df.name);
+
+  const colsInRawQuery = names.every((name: string | undefined) => {
+    if (name && query) {
+      // table name and field, i.e. cpu.usage_guest_nice becomes ['cpu', 'usage_guest_nice']
+      const nameParts = name.split('.');
+
+      return nameParts.every((np) => query.toLowerCase().includes(np.toLowerCase()));
+    }
+
+    return false;
+  });
+
+  const queryChecks = ['*', 'SHOW'];
+
+  const otherChecks: boolean = queryChecks.some((qc: string) => {
+    if (query) {
+      return query.toLowerCase().includes(qc.toLowerCase());
+    }
+
+    return false;
+  });
+
+  return colsInRawQuery || otherChecks;
 }
