@@ -1,7 +1,9 @@
+import { TemplateSrv } from 'app/features/templating/template_srv';
+
 import InfluxQueryModel from '../influx_query_model';
 
 describe('InfluxQuery', () => {
-  const templateSrv: any = { replace: (val: any) => val };
+  const templateSrv = { replace: (val) => val } as TemplateSrv;
 
   describe('render series with measurement only', () => {
     it('should generate correct query', () => {
@@ -9,13 +11,16 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
         },
         templateSrv,
         {}
       );
 
       const queryText = query.render();
-      expect(queryText).toBe('SELECT mean("value") FROM "cpu" WHERE $timeFilter GROUP BY time($__interval) fill(null)');
+      expect(queryText).toBe(
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE $timeFilter GROUP BY time($__interval)' + ' fill(null)'
+      );
     });
   });
 
@@ -44,6 +49,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           select: [
             [
               { type: 'field', params: ['value'] },
@@ -59,7 +65,7 @@ describe('InfluxQuery', () => {
 
       const queryText = query.render();
       expect(queryText).toBe(
-        'SELECT mean("value") /100 AS "text" FROM "cpu" WHERE $timeFilter GROUP BY time($__interval) fill(null)'
+        'SELECT mean("value") /100 AS "text" FROM "autogen"."cpu" WHERE $timeFilter GROUP BY time($__interval) fill(null)'
       );
     });
   });
@@ -70,6 +76,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time', params: ['auto'] }],
           tags: [{ key: 'hostname', value: 'server\\1' }],
         },
@@ -80,7 +87,7 @@ describe('InfluxQuery', () => {
       const queryText = query.render();
 
       expect(queryText).toBe(
-        'SELECT mean("value") FROM "cpu" WHERE ("hostname" = \'server\\\\1\') AND $timeFilter' +
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE ("hostname" = \'server\\\\1\') AND $timeFilter' +
           ' GROUP BY time($__interval)'
       );
     });
@@ -90,6 +97,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time', params: ['auto'] }],
           tags: [{ key: 'app', value: '/e.*/' }],
         },
@@ -99,7 +107,7 @@ describe('InfluxQuery', () => {
 
       const queryText = query.render();
       expect(queryText).toBe(
-        'SELECT mean("value") FROM "cpu" WHERE ("app" =~ /e.*/) AND $timeFilter GROUP BY time($__interval)'
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE ("app" =~ /e.*/) AND $timeFilter GROUP BY time($__interval)'
       );
     });
   });
@@ -110,6 +118,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time', params: ['auto'] }],
           tags: [
             { key: 'hostname', value: 'server1' },
@@ -122,7 +131,7 @@ describe('InfluxQuery', () => {
 
       const queryText = query.render();
       expect(queryText).toBe(
-        'SELECT mean("value") FROM "cpu" WHERE ("hostname" = \'server1\' AND "app" = \'email\') AND ' +
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE ("hostname" = \'server1\' AND "app" = \'email\') AND ' +
           '$timeFilter GROUP BY time($__interval)'
       );
     });
@@ -134,6 +143,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time', params: ['auto'] }],
           tags: [
             { key: 'hostname', value: 'server1' },
@@ -146,7 +156,7 @@ describe('InfluxQuery', () => {
 
       const queryText = query.render();
       expect(queryText).toBe(
-        'SELECT mean("value") FROM "cpu" WHERE ("hostname" = \'server1\' OR "hostname" = \'server2\') AND ' +
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE ("hostname" = \'server1\' OR "hostname" = \'server2\') AND ' +
           '$timeFilter GROUP BY time($__interval)'
       );
     });
@@ -158,6 +168,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time', params: ['auto'] }],
           tags: [
             { key: 'name', value: "Let's encrypt." },
@@ -170,7 +181,7 @@ describe('InfluxQuery', () => {
 
       const queryText = query.render();
       expect(queryText).toBe(
-        'SELECT mean("value") FROM "cpu" WHERE ("name" = \'Let\\\'s encrypt.\' OR "hostname" = \'server2\') AND ' +
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE ("name" = \'Let\\\'s encrypt.\' OR "hostname" = \'server2\') AND ' +
           '$timeFilter GROUP BY time($__interval)'
       );
     });
@@ -182,6 +193,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [],
           tags: [{ key: 'value', value: '5', operator: '>' }],
         },
@@ -190,7 +202,7 @@ describe('InfluxQuery', () => {
       );
 
       const queryText = query.render();
-      expect(queryText).toBe('SELECT mean("value") FROM "cpu" WHERE ("value" > 5) AND $timeFilter');
+      expect(queryText).toBe('SELECT mean("value") FROM "autogen"."cpu" WHERE ("value" > 5) AND $timeFilter');
     });
   });
 
@@ -200,6 +212,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           tags: [],
           groupBy: [
             { type: 'time', interval: 'auto' },
@@ -211,7 +224,9 @@ describe('InfluxQuery', () => {
       );
 
       const queryText = query.render();
-      expect(queryText).toBe('SELECT mean("value") FROM "cpu" WHERE $timeFilter GROUP BY time($__interval), "host"');
+      expect(queryText).toBe(
+        'SELECT mean("value") FROM "autogen"."cpu" WHERE $timeFilter GROUP BY time($__interval), "host"'
+      );
     });
   });
 
@@ -221,6 +236,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           select: [[{ type: 'field', params: ['value'] }]],
           groupBy: [],
         },
@@ -228,7 +244,7 @@ describe('InfluxQuery', () => {
         {}
       );
       const queryText = query.render();
-      expect(queryText).toBe('SELECT "value" FROM "cpu" WHERE $timeFilter');
+      expect(queryText).toBe('SELECT "value" FROM "autogen"."cpu" WHERE $timeFilter');
     });
   });
 
@@ -238,6 +254,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           select: [[{ type: 'field', params: ['value'] }]],
           groupBy: [{ type: 'time' }, { type: 'fill', params: ['0'] }],
         },
@@ -245,7 +262,9 @@ describe('InfluxQuery', () => {
         {}
       );
       const queryText = query.render();
-      expect(queryText).toBe('SELECT "value" FROM "cpu" WHERE $timeFilter GROUP BY time($__interval) fill(0)');
+      expect(queryText).toBe(
+        'SELECT "value" FROM "autogen"."cpu" WHERE $timeFilter GROUP BY time($__interval) fill(0)'
+      );
     });
   });
 
@@ -255,6 +274,7 @@ describe('InfluxQuery', () => {
         {
           refId: 'A',
           measurement: 'cpu',
+          policy: 'autogen',
           groupBy: [{ type: 'time' }, { type: 'fill' }],
         },
         templateSrv,
