@@ -1,27 +1,27 @@
+import { isEqual } from 'lodash';
 import React, { SyntheticEvent, useCallback, useEffect, useState } from 'react';
+import { usePrevious } from 'react-use';
 
 import { CoreApp, LoadingState } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { EditorHeader, EditorRows, FlexItem, Space } from '@grafana/experimental';
-import { reportInteraction } from '@grafana/runtime';
+import { EditorHeader, EditorRows, FlexItem, Space, Stack } from '@grafana/experimental';
+import { config, reportInteraction } from '@grafana/runtime';
 import { Button, ConfirmModal } from '@grafana/ui';
 import { QueryEditorModeToggle } from 'app/plugins/datasource/prometheus/querybuilder/shared/QueryEditorModeToggle';
 import { QueryHeaderSwitch } from 'app/plugins/datasource/prometheus/querybuilder/shared/QueryHeaderSwitch';
 import { QueryEditorMode } from 'app/plugins/datasource/prometheus/querybuilder/shared/types';
 
-import {
-  lokiQueryEditorExplainKey,
-  lokiQueryEditorRawQueryKey,
-  useFlag,
-} from '../../prometheus/querybuilder/shared/hooks/useFlag';
+import { lokiQueryEditorExplainKey, useFlag } from '../../prometheus/querybuilder/shared/hooks/useFlag';
+import { LabelBrowserModal } from '../querybuilder/components/LabelBrowserModal';
 import { LokiQueryBuilderContainer } from '../querybuilder/components/LokiQueryBuilderContainer';
 import { LokiQueryBuilderOptions } from '../querybuilder/components/LokiQueryBuilderOptions';
 import { LokiQueryCodeEditor } from '../querybuilder/components/LokiQueryCodeEditor';
 import { QueryPatternsModal } from '../querybuilder/components/QueryPatternsModal';
 import { buildVisualQueryFromString } from '../querybuilder/parsing';
 import { changeEditorMode, getQueryWithDefaults } from '../querybuilder/state';
-import { LokiQuery } from '../types';
+import { LokiQuery, QueryStats } from '../types';
 
+import { getStats, shouldUpdateStats } from './stats';
 import { LokiQueryEditorProps } from './types';
 
 export const testIds = {
@@ -29,14 +29,24 @@ export const testIds = {
 };
 
 export const LokiQueryEditor = React.memo<LokiQueryEditorProps>((props) => {
-  const { onChange, onRunQuery, onAddQuery, data, app, queries } = props;
+  const { onChange, onRunQuery, onAddQuery, data, app, queries, datasource } = props;
   const [parseModalOpen, setParseModalOpen] = useState(false);
   const [queryPatternsModalOpen, setQueryPatternsModalOpen] = useState(false);
   const [dataIsStale, setDataIsStale] = useState(false);
+  const [labelBrowserVisible, setLabelBrowserVisible] = useState(false);
+  const [queryStats, setQueryStats] = useState<QueryStats | null>(null);
   const { flag: explain, setFlag: setExplain } = useFlag(lokiQueryEditorExplainKey);
-  const { flag: rawQuery, setFlag: setRawQuery } = useFlag(lokiQueryEditorRawQueryKey, true);
+
+  const timerange = datasource.getTimeRange();
+  const predefinedOperations = datasource.predefinedOperations;
+  const previousTimerange = usePrevious(timerange);
 
   const query = getQueryWithDefaults(props.query);
+  if (config.featureToggles.lokiPredefinedOperations && !query.expr && predefinedOperations) {
+    query.expr = `{} ${predefinedOperations}`;
+  }
+  const previousQuery = usePrevious(query.expr);
+
   // This should be filled in from the defaults by now.
   const editorMode = query.editorMode!;
 
@@ -71,15 +81,31 @@ export const LokiQueryEditor = React.memo<LokiQueryEditorProps>((props) => {
   }, [data]);
 
   const onChangeInternal = (query: LokiQuery) => {
-    setDataIsStale(true);
+    if (!isEqual(query, props.query)) {
+      setDataIsStale(true);
+    }
     onChange(query);
   };
 
-  const onQueryPreviewChange = (event: SyntheticEvent<HTMLInputElement>) => {
-    const isEnabled = event.currentTarget.checked;
-    setRawQuery(isEnabled);
+  const onClickLabelBrowserButton = () => {
+    reportInteraction('grafana_loki_label_browser_opened', {
+      app: app,
+    });
+
+    setLabelBrowserVisible((visible) => !visible);
   };
 
+  useEffect(() => {
+    const update = shouldUpdateStats(query.expr, previousQuery, timerange, previousTimerange);
+    if (update) {
+      const makeAsyncRequest = async () => {
+        const stats = await getStats(datasource, query.expr);
+        setQueryStats(stats);
+      };
+      makeAsyncRequest();
+    }
+  }, [datasource, timerange, previousTimerange, query, previousQuery, setQueryStats]);
+
   return (
     <>
       <ConfirmModal
@@ -102,34 +128,43 @@ export const LokiQueryEditor = React.memo<LokiQueryEditorProps>((props) => {
         onChange={onChange}
         onAddQuery={onAddQuery}
       />
+      <LabelBrowserModal
+        isOpen={labelBrowserVisible}
+        datasource={datasource}
+        query={query}
+        app={app}
+        onClose={() => setLabelBrowserVisible(false)}
+        onChange={onChangeInternal}
+        onRunQuery={onRunQuery}
+      />
       <EditorHeader>
-        <Button
-          aria-label={selectors.components.QueryBuilder.queryPatterns}
-          variant="secondary"
-          size="sm"
-          onClick={() => {
-            setQueryPatternsModalOpen((prevValue) => !prevValue);
+        <Stack gap={1}>
+          <Button
+            aria-label={selectors.components.QueryBuilder.queryPatterns}
+            variant="secondary"
+            size="sm"
+            onClick={() => {
+              setQueryPatternsModalOpen((prevValue) => !prevValue);
 
-            const visualQuery = buildVisualQueryFromString(query.expr || '');
-            reportInteraction('grafana_loki_query_patterns_opened', {
-              version: 'v2',
-              app: app ?? '',
-              editorMode: query.editorMode,
-              preSelectedOperationsCount: visualQuery.query.operations.length,
-              preSelectedLabelsCount: visualQuery.query.labels.length,
-            });
-          }}
-        >
-          Kick start your query
-        </Button>
-        <QueryHeaderSwitch label="Explain" value={explain} onChange={onExplainChange} />
-        {editorMode === QueryEditorMode.Builder && (
-          <>
-            <QueryHeaderSwitch label="Raw query" value={rawQuery} onChange={onQueryPreviewChange} />
-          </>
-        )}
+              const visualQuery = buildVisualQueryFromString(query.expr || '');
+              reportInteraction('grafana_loki_query_patterns_opened', {
+                version: 'v2',
+                app: app ?? '',
+                editorMode: query.editorMode,
+                preSelectedOperationsCount: visualQuery.query.operations.length,
+                preSelectedLabelsCount: visualQuery.query.labels.length,
+              });
+            }}
+          >
+            Kick start your query
+          </Button>
+          <Button variant="secondary" size="sm" onClick={onClickLabelBrowserButton} data-testid="label-browser-button">
+            Label browser
+          </Button>
+        </Stack>
+        <QueryHeaderSwitch label="Explain query" value={explain} onChange={onExplainChange} />
         <FlexItem grow={1} />
-        {app !== CoreApp.Explore && (
+        {app !== CoreApp.Explore && app !== CoreApp.Correlations && (
           <Button
             variant={dataIsStale ? 'primary' : 'secondary'}
             size="sm"
@@ -145,7 +180,13 @@ export const LokiQueryEditor = React.memo<LokiQueryEditorProps>((props) => {
       <Space v={0.5} />
       <EditorRows>
         {editorMode === QueryEditorMode.Code && (
-          <LokiQueryCodeEditor {...props} query={query} onChange={onChangeInternal} showExplain={explain} />
+          <LokiQueryCodeEditor
+            {...props}
+            query={query}
+            onChange={onChangeInternal}
+            showExplain={explain}
+            setQueryStats={setQueryStats}
+          />
         )}
         {editorMode === QueryEditorMode.Builder && (
           <LokiQueryBuilderContainer
@@ -153,11 +194,17 @@ export const LokiQueryEditor = React.memo<LokiQueryEditorProps>((props) => {
             query={query}
             onChange={onChangeInternal}
             onRunQuery={props.onRunQuery}
-            showRawQuery={rawQuery}
             showExplain={explain}
           />
         )}
-        <LokiQueryBuilderOptions query={query} onChange={onChange} onRunQuery={onRunQuery} app={app} />
+        <LokiQueryBuilderOptions
+          query={query}
+          onChange={onChange}
+          onRunQuery={onRunQuery}
+          app={app}
+          maxLines={datasource.maxLines}
+          queryStats={queryStats}
+        />
       </EditorRows>
     </>
   );
