@@ -2,7 +2,6 @@ import { render, screen } from '@testing-library/react';
 import React, { ComponentProps } from 'react';
 
 import { dateTime } from '@grafana/data';
-import { config } from '@grafana/runtime';
 
 import { createLokiDatasource } from '../mocks';
 
@@ -29,7 +28,6 @@ describe('LokiQueryField', () => {
     };
     jest.spyOn(props.datasource.languageProvider, 'start').mockResolvedValue([]);
     jest.spyOn(props.datasource.languageProvider, 'fetchLabels').mockResolvedValue(['label1']);
-    config.featureToggles.lokiMonacoEditor = true;
   });
 
   it('refreshes metrics when time range changes over 1 minute', async () => {
@@ -73,12 +71,4 @@ describe('LokiQueryField', () => {
     rerender(<LokiQueryField {...props} range={newRange} />);
     expect(props.datasource.languageProvider.fetchLabels).not.toHaveBeenCalled();
   });
-
-  it('can fall back to the legacy editor', async () => {
-    config.featureToggles.lokiMonacoEditor = false;
-    render(<LokiQueryField {...props} />);
-
-    expect(await screen.findByText('Enter a Loki query (run with Shift+Enter)')).toBeInTheDocument();
-    expect(screen.queryByText('Loading...')).not.toBeInTheDocument();
-  });
 });
