@@ -1,28 +1,21 @@
 import { render, screen } from '@testing-library/react';
 import React from 'react';
 
-import LokiLanguageProvider from '../../LanguageProvider';
 import { createLokiDatasource } from '../../mocks';
 
 import { MonacoQueryFieldWrapper, Props } from './MonacoQueryFieldWrapper';
 
-function renderComponent({
-  initialValue = '',
-  onChange = jest.fn(),
-  onRunQuery = jest.fn(),
-  runQueryOnBlur = false,
-}: Partial<Props> = {}) {
+function renderComponent({ initialValue = '', onChange = jest.fn(), onRunQuery = jest.fn() }: Partial<Props> = {}) {
   const datasource = createLokiDatasource();
-  const languageProvider = new LokiLanguageProvider(datasource);
 
   render(
     <MonacoQueryFieldWrapper
-      languageProvider={languageProvider}
+      datasource={datasource}
       history={[]}
       initialValue={initialValue}
       onChange={onChange}
       onRunQuery={onRunQuery}
-      runQueryOnBlur={runQueryOnBlur}
+      placeholder="Enter a Loki query (run with Shift+Enter)"
     />
   );
 }
