@@ -6,12 +6,12 @@ import { Props as MonacoProps } from './MonacoQueryFieldProps';
 export type Props = Omit<MonacoProps, 'onRunQuery' | 'onBlur'> & {
   onChange: (query: string) => void;
   onRunQuery: () => void;
-  runQueryOnBlur: boolean;
+  onQueryType?: (query: string) => void;
 };
 
 export const MonacoQueryFieldWrapper = (props: Props) => {
   const lastRunValueRef = useRef<string | null>(null);
-  const { runQueryOnBlur, onRunQuery, onChange, ...rest } = props;
+  const { onRunQuery, onChange, ...rest } = props;
 
   const handleRunQuery = (value: string) => {
     lastRunValueRef.current = value;
@@ -20,14 +20,7 @@ export const MonacoQueryFieldWrapper = (props: Props) => {
   };
 
   const handleBlur = (value: string) => {
-    if (runQueryOnBlur) {
-      // run handleRunQuery only if the current value is different from the last-time-executed value
-      if (value !== lastRunValueRef.current) {
-        handleRunQuery(value);
-      }
-    } else {
-      onChange(value);
-    }
+    onChange(value);
   };
 
   return <MonacoQueryFieldLazy onRunQuery={handleRunQuery} onBlur={handleBlur} {...rest} />;
