@@ -16,7 +16,6 @@ export interface Props {
   datasource: LokiDatasource;
   onChange: (update: LokiQuery) => void;
   onRunQuery: () => void;
-  showRawQuery: boolean;
   showExplain: boolean;
 }
 
@@ -29,7 +28,7 @@ export interface State {
  * This component is here just to contain the translation logic between string query and the visual query builder model.
  */
 export function LokiQueryBuilderContainer(props: Props) {
-  const { query, onChange, onRunQuery, datasource, showRawQuery, showExplain } = props;
+  const { query, onChange, onRunQuery, datasource, showExplain } = props;
   const [state, dispatch] = useReducer(stateSlice.reducer, {
     expr: query.expr,
     // Use initial visual query only if query.expr is empty string
@@ -67,14 +66,16 @@ export function LokiQueryBuilderContainer(props: Props) {
         showExplain={showExplain}
         data-testid={testIds.editor}
       />
-      {showRawQuery && <QueryPreview query={query.expr} />}
+      {query.expr !== '' && <QueryPreview query={query.expr} />}
     </>
   );
 }
 
+const initialState: State = { expr: '' };
+
 const stateSlice = createSlice({
   name: 'loki-builder-container',
-  initialState: { expr: '' } as State,
+  initialState,
   reducers: {
     visualQueryChange: (state, action: PayloadAction<{ visQuery: LokiVisualQuery; expr: string }>) => {
       state.expr = action.payload.expr;
