@@ -40,6 +40,7 @@ export enum LokiOperationId {
   Unpack = 'unpack',
   LineFormat = 'line_format',
   LabelFormat = 'label_format',
+  Decolorize = 'decolorize',
   Rate = 'rate',
   RateCounter = 'rate_counter',
   CountOverTime = 'count_over_time',
@@ -95,10 +96,24 @@ export enum LokiOperationId {
 
 export enum LokiOperationOrder {
   LineFilters = 1,
-  LineFormats = 2,
-  LabelFilters = 3,
+  Parsers = 2,
+  PipeOperations = 3,
+  // Unwrap is a special case, as it is usually the last operation, so the order is after pipeOperations
   Unwrap = 4,
   NoErrors = 5,
   RangeVectorFunction = 5,
   Last = 6,
 }
+
+export const lokiOperators = {
+  equals: { label: '=', value: '=', description: 'Equals', isMultiValue: false },
+  doesNotEqual: { label: '!=', value: '!=', description: 'Does not equal', isMultiValue: false },
+  matchesRegex: { label: '=~', value: '=~', description: 'Matches regex', isMultiValue: true },
+  doesNotMatchRegex: { label: '!~', value: '!~', description: 'Does not match regex', isMultiValue: true },
+  greaterThan: { label: '>', value: '>', description: 'Greater than', isMultiValue: false },
+  greaterThanOrEqual: { label: '>=', value: '>=', description: 'Greater than or equal to', isMultiValue: false },
+  lessThan: { label: '<', value: '<', description: 'Less than', isMultiValue: false },
+  lessThanOrEqual: { label: '<=', value: '<=', description: 'Less than or equal to', isMultiValue: false },
+  contains: { label: '|=', value: '|=', description: 'Contains', isMultiValue: false },
+  doesNotContain: { label: '!=', value: '!=', description: 'Does not contain', isMultiValue: false },
+};
