@@ -1,9 +1,13 @@
 import React from 'react';
-import { DataSourceHttpSettings } from '@grafana/ui';
+
 import { DataSourcePluginOptionsEditorProps } from '@grafana/data';
-import { OpenTsdbDetails } from './OpenTsdbDetails';
+import { config } from '@grafana/runtime';
+import { DataSourceHttpSettings } from '@grafana/ui';
+
 import { OpenTsdbOptions } from '../types';
 
+import { OpenTsdbDetails } from './OpenTsdbDetails';
+
 export const ConfigEditor = (props: DataSourcePluginOptionsEditorProps<OpenTsdbOptions>) => {
   const { options, onOptionsChange } = props;
 
@@ -13,6 +17,7 @@ export const ConfigEditor = (props: DataSourcePluginOptionsEditorProps<OpenTsdbO
         defaultUrl="http://localhost:4242"
         dataSourceConfig={options}
         onChange={onOptionsChange}
+        secureSocksDSProxyEnabled={config.secureSocksDSProxyEnabled}
       />
       <OpenTsdbDetails value={options} onChange={onOptionsChange} />
     </>
