@@ -1,7 +1,8 @@
 import { DataSourcePlugin } from '@grafana/data';
 import { SQLQuery } from 'app/features/plugins/sql/types';
 
-import { QueryEditor } from './QueryEditor';
+import { CheatSheet } from './CheatSheet';
+import { PostgresQueryEditor } from './PostgresQueryEditor';
 import { PostgresConfigEditor } from './configuration/ConfigurationEditor';
 import { PostgresDatasource } from './datasource';
 import { PostgresOptions, SecureJsonData } from './types';
@@ -9,5 +10,6 @@ import { PostgresOptions, SecureJsonData } from './types';
 export const plugin = new DataSourcePlugin<PostgresDatasource, SQLQuery, PostgresOptions, SecureJsonData>(
   PostgresDatasource
 )
-  .setQueryEditor(QueryEditor)
+  .setQueryEditor(PostgresQueryEditor)
+  .setQueryEditorHelp(CheatSheet)
   .setConfigEditor(PostgresConfigEditor);
