@@ -1,24 +1,54 @@
 import { Editor as SlateEditor } from 'slate';
 import Plain from 'slate-plain-serializer';
 
-import { AbstractLabelOperator, HistoryItem } from '@grafana/data';
+import { AbstractLabelOperator, dateTime, HistoryItem, TimeRange } from '@grafana/data';
+import { config } from '@grafana/runtime';
 import { SearchFunctionType } from '@grafana/ui';
 
 import { Label } from './components/monaco-query-field/monaco-completion-provider/situation';
 import { PrometheusDatasource } from './datasource';
 import LanguageProvider from './language_provider';
-import { PromQuery } from './types';
+import { getClientCacheDurationInMinutes, getPrometheusTime, getRangeSnapInterval } from './language_utils';
+import { PrometheusCacheLevel, PromQuery } from './types';
+
+const now = new Date(1681300293392).getTime();
+const timeRangeDurationSeconds = 1;
+const toPrometheusTime = getPrometheusTime(dateTime(now), false);
+const fromPrometheusTime = getPrometheusTime(dateTime(now - timeRangeDurationSeconds * 1000), false);
+const toPrometheusTimeString = toPrometheusTime.toString(10);
+const fromPrometheusTimeString = fromPrometheusTime.toString(10);
+
+const getTimeRangeParams = (override?: Partial<{ start: string; end: string }>): { start: string; end: string } => ({
+  start: fromPrometheusTimeString,
+  end: toPrometheusTimeString,
+  ...override,
+});
+
+const getMockQuantizedTimeRangeParams = (override?: Partial<TimeRange>): TimeRange => ({
+  from: dateTime(fromPrometheusTime * 1000),
+  to: dateTime(toPrometheusTime * 1000),
+  raw: {
+    from: `now-${timeRangeDurationSeconds}s`,
+    to: 'now',
+  },
+  ...override,
+});
 
 describe('Language completion provider', () => {
-  const datasource: PrometheusDatasource = {
-    metadataRequest: () => ({ data: { data: [] as any[] } }),
-    getTimeRangeParams: () => ({ start: '0', end: '1' }),
+  const defaultDatasource: PrometheusDatasource = {
+    metadataRequest: () => ({ data: { data: [] } }),
+    getTimeRangeParams: getTimeRangeParams,
     interpolateString: (string: string) => string,
     hasLabelsMatchAPISupport: () => false,
+    getQuantizedTimeRangeParams: () =>
+      getRangeSnapInterval(PrometheusCacheLevel.None, getMockQuantizedTimeRangeParams()),
+    getDaysToCacheMetadata: () => 1,
+    getAdjustedInterval: () => getRangeSnapInterval(PrometheusCacheLevel.None, getMockQuantizedTimeRangeParams()),
+    cacheLevel: PrometheusCacheLevel.None,
   } as unknown as PrometheusDatasource;
 
   describe('cleanText', () => {
-    const cleanText = new LanguageProvider(datasource).cleanText;
+    const cleanText = new LanguageProvider(defaultDatasource).cleanText;
     it('does not remove metric or label keys', () => {
       expect(cleanText('foo')).toBe('foo');
       expect(cleanText('foo_bar')).toBe('foo_bar');
@@ -68,26 +98,14 @@ describe('Language completion provider', () => {
     });
   });
 
-  describe('getSeriesLabels', () => {
-    it('should call series endpoint', () => {
-      const languageProvider = new LanguageProvider({ ...datasource } as PrometheusDatasource);
-      const getSeriesLabels = languageProvider.getSeriesLabels;
-      const requestSpy = jest.spyOn(languageProvider, 'request');
-
-      const labelName = 'job';
-      const labelValue = 'grafana';
-      getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
-      expect(requestSpy).toHaveBeenCalled();
-      expect(requestSpy).toHaveBeenCalledWith('/api/v1/series', [], {
-        end: '1',
-        'match[]': '{job="grafana"}',
-        start: '0',
-      });
+  // @todo clean up prometheusResourceBrowserCache feature flag
+  describe('getSeriesLabelsDeprecatedLRU', () => {
+    beforeEach(() => {
+      config.featureToggles.prometheusResourceBrowserCache = false;
     });
-
     it('should call labels endpoint', () => {
       const languageProvider = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         hasLabelsMatchAPISupport: () => true,
       } as PrometheusDatasource);
       const getSeriesLabels = languageProvider.getSeriesLabels;
@@ -98,30 +116,145 @@ describe('Language completion provider', () => {
       getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
       expect(requestSpy).toHaveBeenCalled();
       expect(requestSpy).toHaveBeenCalledWith(`/api/v1/labels`, [], {
-        end: '1',
+        end: toPrometheusTimeString,
         'match[]': '{job="grafana"}',
-        start: '0',
+        start: fromPrometheusTimeString,
       });
     });
+
+    it('should call series endpoint', () => {
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+        getAdjustedInterval: () => getRangeSnapInterval(PrometheusCacheLevel.None, getMockQuantizedTimeRangeParams()),
+      } as PrometheusDatasource);
+      const getSeriesLabels = languageProvider.getSeriesLabels;
+      const requestSpy = jest.spyOn(languageProvider, 'request');
+
+      const labelName = 'job';
+      const labelValue = 'grafana';
+      getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
+      expect(requestSpy).toHaveBeenCalled();
+      expect(requestSpy).toHaveBeenCalledWith('/api/v1/series', [], {
+        end: toPrometheusTimeString,
+        'match[]': '{job="grafana"}',
+        start: fromPrometheusTimeString,
+      });
+    });
+  });
+  describe('getSeriesLabels', () => {
+    beforeEach(() => {
+      config.featureToggles.prometheusResourceBrowserCache = true;
+    });
+    it('should call labels endpoint', () => {
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+        hasLabelsMatchAPISupport: () => true,
+      } as PrometheusDatasource);
+      const getSeriesLabels = languageProvider.getSeriesLabels;
+      const requestSpy = jest.spyOn(languageProvider, 'request');
+
+      const labelName = 'job';
+      const labelValue = 'grafana';
+      getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
+      expect(requestSpy).toHaveBeenCalled();
+      expect(requestSpy).toHaveBeenCalledWith(
+        `/api/v1/labels`,
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': '{job="grafana"}',
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
+    });
+
+    it('should call series endpoint', () => {
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+        getAdjustedInterval: () => getRangeSnapInterval(PrometheusCacheLevel.None, getMockQuantizedTimeRangeParams()),
+      } as PrometheusDatasource);
+      const getSeriesLabels = languageProvider.getSeriesLabels;
+      const requestSpy = jest.spyOn(languageProvider, 'request');
+
+      const labelName = 'job';
+      const labelValue = 'grafana';
+      getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
+      expect(requestSpy).toHaveBeenCalled();
+      expect(requestSpy).toHaveBeenCalledWith(
+        '/api/v1/series',
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': '{job="grafana"}',
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
+    });
+
+    it('should call labels endpoint with quantized start', () => {
+      const timeSnapMinutes = getClientCacheDurationInMinutes(PrometheusCacheLevel.Low);
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+        hasLabelsMatchAPISupport: () => true,
+        cacheLevel: PrometheusCacheLevel.Low,
+        getAdjustedInterval: () => getRangeSnapInterval(PrometheusCacheLevel.Low, getMockQuantizedTimeRangeParams()),
+        getCacheDurationInMinutes: () => timeSnapMinutes,
+      } as PrometheusDatasource);
+      const getSeriesLabels = languageProvider.getSeriesLabels;
+      const requestSpy = jest.spyOn(languageProvider, 'request');
+
+      const labelName = 'job';
+      const labelValue = 'grafana';
+      getSeriesLabels(`{${labelName}="${labelValue}"}`, [{ name: labelName, value: labelValue, op: '=' }] as Label[]);
+      expect(requestSpy).toHaveBeenCalled();
+      expect(requestSpy).toHaveBeenCalledWith(
+        `/api/v1/labels`,
+        [],
+        {
+          end: (
+            dateTime(fromPrometheusTime * 1000)
+              .add(timeSnapMinutes, 'minute')
+              .startOf('minute')
+              .valueOf() / 1000
+          ).toString(),
+          'match[]': '{job="grafana"}',
+          start: (
+            dateTime(toPrometheusTime * 1000)
+              .startOf('minute')
+              .valueOf() / 1000
+          ).toString(),
+        },
+        { headers: { 'X-Grafana-Cache': `private, max-age=${timeSnapMinutes * 60}` } }
+      );
+    });
   });
 
   describe('getSeriesValues', () => {
     it('should call old series endpoint and should use match[] parameter', () => {
-      const languageProvider = new LanguageProvider(datasource);
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+      } as PrometheusDatasource);
       const getSeriesValues = languageProvider.getSeriesValues;
       const requestSpy = jest.spyOn(languageProvider, 'request');
       getSeriesValues('job', '{job="grafana"}');
       expect(requestSpy).toHaveBeenCalled();
-      expect(requestSpy).toHaveBeenCalledWith('/api/v1/series', [], {
-        end: '1',
-        'match[]': '{job="grafana"}',
-        start: '0',
-      });
+      expect(requestSpy).toHaveBeenCalledWith(
+        '/api/v1/series',
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': '{job="grafana"}',
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
     });
 
     it('should call new series endpoint and should use match[] parameter', () => {
       const languageProvider = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         hasLabelsMatchAPISupport: () => true,
       } as PrometheusDatasource);
       const getSeriesValues = languageProvider.getSeriesValues;
@@ -130,17 +263,43 @@ describe('Language completion provider', () => {
       const labelValue = 'grafana';
       getSeriesValues(labelName, `{${labelName}="${labelValue}"}`);
       expect(requestSpy).toHaveBeenCalled();
-      expect(requestSpy).toHaveBeenCalledWith(`/api/v1/label/${labelName}/values`, [], {
-        end: '1',
-        'match[]': `{${labelName}="${labelValue}"}`,
-        start: '0',
-      });
+      expect(requestSpy).toHaveBeenCalledWith(
+        `/api/v1/label/${labelName}/values`,
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': `{${labelName}="${labelValue}"}`,
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
+    });
+
+    it('should call old series endpoint and should use match[] parameter and interpolate the template variables', () => {
+      const languageProvider = new LanguageProvider({
+        ...defaultDatasource,
+        interpolateString: (string: string) => string.replace(/\$/, 'interpolated-'),
+      } as PrometheusDatasource);
+      const getSeriesValues = languageProvider.getSeriesValues;
+      const requestSpy = jest.spyOn(languageProvider, 'request');
+      getSeriesValues('job', '{instance="$instance", job="grafana"}');
+      expect(requestSpy).toHaveBeenCalled();
+      expect(requestSpy).toHaveBeenCalledWith(
+        '/api/v1/series',
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': '{instance="interpolated-instance", job="grafana"}',
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
     });
   });
 
   describe('fetchSeries', () => {
     it('should use match[] parameter', () => {
-      const languageProvider = new LanguageProvider(datasource);
+      const languageProvider = new LanguageProvider(defaultDatasource);
       const fetchSeries = languageProvider.fetchSeries;
       const requestSpy = jest.spyOn(languageProvider, 'request');
       fetchSeries('{job="grafana"}');
@@ -148,7 +307,8 @@ describe('Language completion provider', () => {
       expect(requestSpy).toHaveBeenCalledWith(
         '/api/v1/series',
         {},
-        { end: '1', 'match[]': '{job="grafana"}', start: '0' }
+        { end: toPrometheusTimeString, 'match[]': '{job="grafana"}', start: fromPrometheusTimeString },
+        undefined
       );
     });
   });
@@ -156,41 +316,51 @@ describe('Language completion provider', () => {
   describe('fetchSeriesLabels', () => {
     it('should interpolate variable in series', () => {
       const languageProvider = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         interpolateString: (string: string) => string.replace(/\$/, 'interpolated-'),
       } as PrometheusDatasource);
       const fetchSeriesLabels = languageProvider.fetchSeriesLabels;
       const requestSpy = jest.spyOn(languageProvider, 'request');
       fetchSeriesLabels('$metric');
       expect(requestSpy).toHaveBeenCalled();
-      expect(requestSpy).toHaveBeenCalledWith('/api/v1/series', [], {
-        end: '1',
-        'match[]': 'interpolated-metric',
-        start: '0',
-      });
+      expect(requestSpy).toHaveBeenCalledWith(
+        '/api/v1/series',
+        [],
+        {
+          end: toPrometheusTimeString,
+          'match[]': 'interpolated-metric',
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
     });
   });
 
   describe('fetchLabelValues', () => {
     it('should interpolate variable in series', () => {
       const languageProvider = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         interpolateString: (string: string) => string.replace(/\$/, 'interpolated-'),
       } as PrometheusDatasource);
       const fetchLabelValues = languageProvider.fetchLabelValues;
       const requestSpy = jest.spyOn(languageProvider, 'request');
       fetchLabelValues('$job');
       expect(requestSpy).toHaveBeenCalled();
-      expect(requestSpy).toHaveBeenCalledWith('/api/v1/label/interpolated-job/values', [], {
-        end: '1',
-        start: '0',
-      });
+      expect(requestSpy).toHaveBeenCalledWith(
+        '/api/v1/label/interpolated-job/values',
+        [],
+        {
+          end: toPrometheusTimeString,
+          start: fromPrometheusTimeString,
+        },
+        undefined
+      );
     });
   });
 
   describe('empty query suggestions', () => {
     it('returns no suggestions on empty context', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('');
       const result = await instance.provideCompletionItems({ text: '', prefix: '', value, wrapperClasses: [] });
       expect(result.context).toBeUndefined();
@@ -198,7 +368,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns no suggestions with metrics on empty context even when metrics were provided', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       instance.metrics = ['foo', 'bar'];
       const value = Plain.deserialize('');
       const result = await instance.provideCompletionItems({ text: '', prefix: '', value, wrapperClasses: [] });
@@ -207,7 +377,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns history on empty context when history was provided', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('');
       const history: Array<HistoryItem<PromQuery>> = [
         {
@@ -236,7 +406,7 @@ describe('Language completion provider', () => {
 
   describe('range suggestions', () => {
     it('returns range suggestions in range context', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('1');
       const result = await instance.provideCompletionItems({
         text: '1',
@@ -266,7 +436,7 @@ describe('Language completion provider', () => {
 
   describe('metric suggestions', () => {
     it('returns history, metrics and function suggestions in an uknown context ', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       instance.metrics = ['foo', 'bar'];
       const history: Array<HistoryItem<PromQuery>> = [
         {
@@ -301,7 +471,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns no suggestions directly after a binary operator', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       instance.metrics = ['foo', 'bar'];
       const value = Plain.deserialize('*');
       const result = await instance.provideCompletionItems({ text: '*', prefix: '', value, wrapperClasses: [] });
@@ -310,7 +480,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns metric suggestions with prefix after a binary operator', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       instance.metrics = ['foo', 'bar'];
       const value = Plain.deserialize('foo + b');
       const ed = new SlateEditor({ value });
@@ -333,7 +503,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns no suggestions at the beginning of a non-empty function', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('sum(up)');
       const ed = new SlateEditor({ value });
 
@@ -351,7 +521,7 @@ describe('Language completion provider', () => {
 
   describe('label suggestions', () => {
     it('returns default label suggestions on label context and no metric', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('{}');
       const ed = new SlateEditor({ value });
       const valueWithSelection = ed.moveForward(1).value;
@@ -373,9 +543,8 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions on label context and metric', async () => {
       const datasources: PrometheusDatasource = {
-        metadataRequest: () => ({ data: { data: [{ __name__: 'metric', bar: 'bazinga' }] as any[] } }),
-        getTimeRangeParams: () => ({ start: '0', end: '1' }),
-        interpolateString: (string: string) => string,
+        ...defaultDatasource,
+        metadataRequest: () => ({ data: { data: [{ __name__: 'metric', bar: 'bazinga' }] } }),
       } as unknown as PrometheusDatasource;
       const instance = new LanguageProvider(datasources);
       const value = Plain.deserialize('metric{}');
@@ -394,7 +563,8 @@ describe('Language completion provider', () => {
     });
 
     it('returns label suggestions on label context but leaves out labels that already exist', async () => {
-      const datasource: PrometheusDatasource = {
+      const testDatasource: PrometheusDatasource = {
+        ...defaultDatasource,
         metadataRequest: () => ({
           data: {
             data: [
@@ -408,10 +578,8 @@ describe('Language completion provider', () => {
             ],
           },
         }),
-        getTimeRangeParams: () => ({ start: '0', end: '1' }),
-        interpolateString: (string: string) => string,
       } as unknown as PrometheusDatasource;
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(testDatasource);
       const value = Plain.deserialize('{job1="foo",job2!="foo",job3=~"foo",__name__="metric",}');
       const ed = new SlateEditor({ value });
       const valueWithSelection = ed.moveForward(54).value;
@@ -429,7 +597,7 @@ describe('Language completion provider', () => {
 
     it('returns label value suggestions inside a label value context after a negated matching operator', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => {
           return { data: { data: ['value1', 'value2'] } };
         },
@@ -456,7 +624,7 @@ describe('Language completion provider', () => {
 
     it('returns a refresher on label context and unavailable metric', async () => {
       jest.spyOn(console, 'warn').mockImplementation(() => {});
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('metric{}');
       const ed = new SlateEditor({ value });
       const valueWithSelection = ed.moveForward(7).value;
@@ -473,7 +641,7 @@ describe('Language completion provider', () => {
 
     it('returns label values on label context when given a metric and a label key', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('metric{bar=ba}');
@@ -494,7 +662,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions on aggregation context and metric w/ selector', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum(metric{foo="xx"}) by ()');
@@ -514,7 +682,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions on aggregation context and metric w/o selector', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum(metric) by ()');
@@ -534,7 +702,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions inside a multi-line aggregation context', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum(\nmetric\n)\nby ()');
@@ -560,7 +728,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions inside an aggregation context with a range vector', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum(rate(metric[1h])) by ()');
@@ -584,7 +752,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions inside an aggregation context with a range vector and label', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum(rate(metric{label1="value"}[1h])) by ()');
@@ -607,7 +775,7 @@ describe('Language completion provider', () => {
     });
 
     it('returns no suggestions inside an unclear aggregation context using alternate syntax', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const value = Plain.deserialize('sum by ()');
       const ed = new SlateEditor({ value });
       const valueWithSelection = ed.moveForward(8).value;
@@ -623,7 +791,7 @@ describe('Language completion provider', () => {
 
     it('returns label suggestions inside an aggregation context using alternate syntax', async () => {
       const instance = new LanguageProvider({
-        ...datasource,
+        ...defaultDatasource,
         metadataRequest: () => simpleMetricLabelsResponse,
       } as unknown as PrometheusDatasource);
       const value = Plain.deserialize('sum by () (metric)');
@@ -646,15 +814,16 @@ describe('Language completion provider', () => {
     });
 
     it('does not re-fetch default labels', async () => {
-      const datasource: PrometheusDatasource = {
-        metadataRequest: jest.fn(() => ({ data: { data: [] as any[] } })),
-        getTimeRangeParams: jest.fn(() => ({ start: '0', end: '1' })),
+      const testDatasource: PrometheusDatasource = {
+        ...defaultDatasource,
+        metadataRequest: jest.fn(() => ({ data: { data: [] } })),
         interpolateString: (string: string) => string,
+        getQuantizedTimeRangeParams: getMockQuantizedTimeRangeParams,
       } as unknown as PrometheusDatasource;
 
-      const mockedMetadataRequest = jest.mocked(datasource.metadataRequest);
+      const mockedMetadataRequest = jest.mocked(testDatasource.metadataRequest);
 
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(testDatasource);
       const value = Plain.deserialize('{}');
       const ed = new SlateEditor({ value });
       const valueWithSelection = ed.moveForward(1).value;
@@ -678,7 +847,6 @@ describe('Language completion provider', () => {
       jest.spyOn(console, 'warn').mockImplementation(() => {});
       const datasource: PrometheusDatasource = {
         metadataRequest: jest.fn(() => ({ data: { data: ['foo', 'bar'] as string[] } })),
-        getTimeRangeParams: jest.fn(() => ({ start: '0', end: '1' })),
         lookupsDisabled: true,
       } as unknown as PrometheusDatasource;
       const mockedMetadataRequest = jest.mocked(datasource.metadataRequest);
@@ -702,10 +870,9 @@ describe('Language completion provider', () => {
     });
     it('issues metadata requests when lookup is not disabled', async () => {
       const datasource: PrometheusDatasource = {
+        ...defaultDatasource,
         metadataRequest: jest.fn(() => ({ data: { data: ['foo', 'bar'] as string[] } })),
-        getTimeRangeParams: jest.fn(() => ({ start: '0', end: '1' })),
         lookupsDisabled: false,
-        interpolateString: (string: string) => string,
       } as unknown as PrometheusDatasource;
       const mockedMetadataRequest = jest.mocked(datasource.metadataRequest);
       const instance = new LanguageProvider(datasource);
@@ -714,18 +881,35 @@ describe('Language completion provider', () => {
       await instance.start();
       expect(mockedMetadataRequest.mock.calls.length).toBeGreaterThan(0);
     });
+
+    it('doesnt blow up if metadata or fetchLabels rejects', async () => {
+      jest.spyOn(console, 'error').mockImplementation();
+      const datasource: PrometheusDatasource = {
+        ...defaultDatasource,
+        metadataRequest: jest.fn(() => Promise.reject('rejected')),
+        lookupsDisabled: false,
+      } as unknown as PrometheusDatasource;
+      const mockedMetadataRequest = jest.mocked(datasource.metadataRequest);
+      const instance = new LanguageProvider(datasource);
+
+      expect(mockedMetadataRequest.mock.calls.length).toBe(0);
+      const result = await instance.start();
+      expect(result[0]).toBeUndefined();
+      expect(result[1]).toEqual([]);
+      expect(mockedMetadataRequest.mock.calls.length).toBe(3);
+    });
   });
 
   describe('Query imports', () => {
     it('returns empty queries', async () => {
-      const instance = new LanguageProvider(datasource);
+      const instance = new LanguageProvider(defaultDatasource);
       const result = await instance.importFromAbstractQuery({ refId: 'bar', labelMatchers: [] });
       expect(result).toEqual({ refId: 'bar', expr: '', range: true });
     });
 
     describe('exporting to abstract query', () => {
       it('exports labels with metric name', async () => {
-        const instance = new LanguageProvider(datasource);
+        const instance = new LanguageProvider(defaultDatasource);
         const abstractQuery = instance.exportToAbstractQuery({
           refId: 'bar',
           expr: 'metric_name{label1="value1", label2!="value2", label3=~"value3", label4!~"value4"}',
