@@ -2,6 +2,7 @@ import { createSlice, PayloadAction } from '@reduxjs/toolkit';
 import React, { useEffect, useReducer } from 'react';
 
 import { PanelData } from '@grafana/data';
+import { config } from '@grafana/runtime';
 
 import { PrometheusDatasource } from '../../datasource';
 import { PromQuery } from '../../types';
@@ -11,6 +12,7 @@ import { PromVisualQuery } from '../types';
 
 import { PromQueryBuilder } from './PromQueryBuilder';
 import { QueryPreview } from './QueryPreview';
+import { getSettings, MetricsModalSettings } from './metrics-modal/state/state';
 
 export interface Props {
   query: PromQuery;
@@ -18,7 +20,6 @@ export interface Props {
   onChange: (update: PromQuery) => void;
   onRunQuery: () => void;
   data?: PanelData;
-  showRawQuery?: boolean;
   showExplain: boolean;
 }
 
@@ -27,22 +28,39 @@ export interface State {
   expr: string;
 }
 
+const prometheusMetricEncyclopedia = config.featureToggles.prometheusMetricEncyclopedia;
 /**
  * This component is here just to contain the translation logic between string query and the visual query builder model.
  */
 export function PromQueryBuilderContainer(props: Props) {
-  const { query, onChange, onRunQuery, datasource, data, showRawQuery, showExplain } = props;
+  const { query, onChange, onRunQuery, datasource, data, showExplain } = props;
   const [state, dispatch] = useReducer(stateSlice.reducer, { expr: query.expr });
-
   // Only rebuild visual query if expr changes from outside
   useEffect(() => {
     dispatch(exprChanged(query.expr));
-  }, [query.expr]);
+
+    if (prometheusMetricEncyclopedia) {
+      dispatch(
+        setMetricsModalSettings({
+          useBackend: query.useBackend ?? false,
+          disableTextWrap: query.disableTextWrap ?? false,
+          fullMetaSearch: query.fullMetaSearch ?? false,
+          includeNullMetadata: query.includeNullMetadata ?? true,
+        })
+      );
+    }
+  }, [query]);
 
   const onVisQueryChange = (visQuery: PromVisualQuery) => {
     const expr = promQueryModeller.renderQuery(visQuery);
     dispatch(visualQueryChange({ visQuery, expr }));
-    onChange({ ...props.query, expr: expr });
+
+    if (prometheusMetricEncyclopedia) {
+      const metricsModalSettings = getSettings(visQuery);
+      onChange({ ...props.query, expr: expr, ...metricsModalSettings });
+    } else {
+      onChange({ ...props.query, expr: expr });
+    }
   };
 
   if (!state.visQuery) {
@@ -59,7 +77,7 @@ export function PromQueryBuilderContainer(props: Props) {
         data={data}
         showExplain={showExplain}
       />
-      {showRawQuery && <QueryPreview query={query.expr} />}
+      {<QueryPreview query={query.expr} />}
     </>
   );
 }
@@ -75,11 +93,20 @@ const stateSlice = createSlice({
     exprChanged: (state, action: PayloadAction<string>) => {
       if (!state.visQuery || state.expr !== action.payload) {
         state.expr = action.payload;
-        const parseResult = buildVisualQueryFromString(action.payload);
+        const parseResult = buildVisualQueryFromString(action.payload ?? '');
+
         state.visQuery = parseResult.query;
       }
     },
+    setMetricsModalSettings: (state, action: PayloadAction<MetricsModalSettings>) => {
+      if (state.visQuery && prometheusMetricEncyclopedia) {
+        state.visQuery.useBackend = action.payload.useBackend;
+        state.visQuery.disableTextWrap = action.payload.disableTextWrap;
+        state.visQuery.fullMetaSearch = action.payload.fullMetaSearch;
+        state.visQuery.includeNullMetadata = action.payload.includeNullMetadata;
+      }
+    },
   },
 });
 
-const { visualQueryChange, exprChanged } = stateSlice.actions;
+const { visualQueryChange, exprChanged, setMetricsModalSettings } = stateSlice.actions;
