@@ -3,6 +3,9 @@ import userEvent from '@testing-library/user-event';
 import { cloneDeep, defaultsDeep } from 'lodash';
 import React from 'react';
 
+import { CoreApp, PluginMeta, PluginType } from '@grafana/data';
+
+import { PromQueryEditorProps } from '../../components/types';
 import { PrometheusDatasource } from '../../datasource';
 import PromQlLanguageProvider from '../../language_provider';
 import { EmptyLanguageProviderMock } from '../../language_provider.mock';
@@ -27,7 +30,7 @@ jest.mock('app/core/store', () => {
       return undefined;
     },
     set() {},
-    getObject(key: string, defaultValue: any) {
+    getObject(key: string, defaultValue: unknown) {
       return defaultValue;
     },
   };
@@ -45,8 +48,30 @@ const defaultQuery = {
   expr: 'metric{label1="foo", label2="bar"}',
 };
 
-const defaultProps = {
-  datasource: new PrometheusDatasource(
+const defaultMeta: PluginMeta = {
+  id: '',
+  name: '',
+  type: PluginType.datasource,
+  info: {
+    author: {
+      name: 'tester',
+    },
+    description: 'testing',
+    links: [],
+    logos: {
+      large: '',
+      small: '',
+    },
+    screenshots: [],
+    updated: '',
+    version: '',
+  },
+  module: '',
+  baseUrl: '',
+};
+
+const getDefaultDatasource = (jsonDataOverrides = {}) =>
+  new PrometheusDatasource(
     {
       id: 1,
       uid: '',
@@ -54,14 +79,17 @@ const defaultProps = {
       name: 'prom-test',
       access: 'proxy',
       url: '',
-      jsonData: {},
-      meta: {} as any,
+      jsonData: jsonDataOverrides,
+      meta: defaultMeta,
       readOnly: false,
     },
     undefined,
     undefined,
     new EmptyLanguageProviderMock() as unknown as PromQlLanguageProvider
-  ),
+  );
+
+const defaultProps = {
+  datasource: getDefaultDatasource(),
   query: defaultQuery,
   onRunQuery: () => {},
   onChange: () => {},
@@ -71,17 +99,44 @@ describe('PromQueryEditorSelector', () => {
   it('shows code editor if expr and nothing else', async () => {
     // We opt for showing code editor for queries created before this feature was added
     render(<PromQueryEditorSelector {...defaultProps} />);
-    expectCodeEditor();
+    await expectCodeEditor();
+  });
+
+  it('shows code editor if no expr and nothing else since defaultEditor is code', async () => {
+    renderWithDatasourceDefaultEditorMode(QueryEditorMode.Code);
+    await expectCodeEditor();
+  });
+
+  it('shows builder if no expr and nothing else since defaultEditor is builder', async () => {
+    renderWithDatasourceDefaultEditorMode(QueryEditorMode.Builder);
+    await expectBuilder();
   });
 
   it('shows code editor when code mode is set', async () => {
     renderWithMode(QueryEditorMode.Code);
-    expectCodeEditor();
+    await expectCodeEditor();
   });
 
   it('shows builder when builder mode is set', async () => {
     renderWithMode(QueryEditorMode.Builder);
-    expectBuilder();
+    await expectBuilder();
+  });
+
+  it('shows Run Queries button in Dashboards', async () => {
+    renderWithProps({}, { app: CoreApp.Dashboard });
+    await expectRunQueriesButton();
+  });
+
+  it('hides Run Queries button in Explore', async () => {
+    renderWithProps({}, { app: CoreApp.Explore });
+    await expectCodeEditor();
+    expectNoRunQueriesButton();
+  });
+
+  it('hides Run Queries button in Correlations Page', async () => {
+    renderWithProps({}, { app: CoreApp.Correlations });
+    await expectCodeEditor();
+    expectNoRunQueriesButton();
   });
 
   it('changes to builder mode', async () => {
@@ -95,14 +150,7 @@ describe('PromQueryEditorSelector', () => {
     });
   });
 
-  it('Can enable raw query', async () => {
-    renderWithMode(QueryEditorMode.Builder);
-    expect(screen.queryByLabelText('selector')).toBeInTheDocument();
-    screen.getByLabelText('Raw query').click();
-    expect(screen.queryByLabelText('selector')).not.toBeInTheDocument();
-  });
-
-  it('Should show raw query by default', async () => {
+  it('Should show raw query', async () => {
     renderWithProps({
       editorMode: QueryEditorMode.Builder,
       expr: 'my_metric',
@@ -113,7 +161,7 @@ describe('PromQueryEditorSelector', () => {
   it('Can enable explain', async () => {
     renderWithMode(QueryEditorMode.Builder);
     expect(screen.queryByText(EXPLAIN_LABEL_FILTER_CONTENT)).not.toBeInTheDocument();
-    screen.getByLabelText('Explain').click();
+    await userEvent.click(screen.getByLabelText('Explain'));
     expect(await screen.findByText(EXPLAIN_LABEL_FILTER_CONTENT)).toBeInTheDocument();
   });
 
@@ -154,26 +202,49 @@ describe('PromQueryEditorSelector', () => {
 });
 
 function renderWithMode(mode: QueryEditorMode) {
-  return renderWithProps({ editorMode: mode } as any);
+  return renderWithProps({ editorMode: mode });
 }
 
-function renderWithProps(overrides?: Partial<PromQuery>) {
+function renderWithDatasourceDefaultEditorMode(mode: QueryEditorMode) {
+  const props = {
+    ...defaultProps,
+    datasource: getDefaultDatasource({
+      defaultEditor: mode,
+    }),
+    query: {
+      refId: 'B',
+      expr: '',
+    },
+    onRunQuery: () => {},
+    onChange: () => {},
+  };
+  render(<PromQueryEditorSelector {...props} />);
+}
+
+function renderWithProps(overrides?: Partial<PromQuery>, componentProps: Partial<PromQueryEditorProps> = {}) {
   const query = defaultsDeep(overrides ?? {}, cloneDeep(defaultQuery));
   const onChange = jest.fn();
 
-  const stuff = render(<PromQueryEditorSelector {...defaultProps} query={query} onChange={onChange} />);
+  const allProps = { ...defaultProps, ...componentProps };
+  const stuff = render(<PromQueryEditorSelector {...allProps} query={query} onChange={onChange} />);
   return { onChange, ...stuff };
 }
 
-function expectCodeEditor() {
-  // Metric browser shows this until metrics are loaded.
-  expect(screen.getByText('Loading metrics...')).toBeInTheDocument();
+async function expectCodeEditor() {
+  expect(await screen.findByText('MonacoQueryFieldWrapper')).toBeInTheDocument();
 }
 
-function expectBuilder() {
-  expect(screen.getByText('Metric')).toBeInTheDocument();
+async function expectBuilder() {
+  expect(await screen.findByText('Metric')).toBeInTheDocument();
 }
 
+async function expectRunQueriesButton() {
+  expect(await screen.findByRole('button', { name: /run queries/i })).toBeInTheDocument();
+}
+
+function expectNoRunQueriesButton() {
+  expect(screen.queryByRole('button', { name: /run queries/i })).not.toBeInTheDocument();
+}
 async function switchToMode(mode: QueryEditorMode) {
   const label = {
     [QueryEditorMode.Code]: /Code/,
