@@ -1,8 +1,8 @@
 import { lastValueFrom, Observable, of } from 'rxjs';
 import { createFetchResponse } from 'test/helpers/createFetchResponse';
+import { initTemplateSrv } from 'test/helpers/initTemplateSrv';
 
 import {
-  ArrayVector,
   DataFrame,
   dataFrameToJSON,
   DataSourceInstanceSettings,
@@ -10,11 +10,18 @@ import {
   FieldType,
   getDefaultTimeRange,
   LoadingState,
-  MutableDataFrame,
+  createDataFrame,
   PluginType,
+  CoreApp,
 } from '@grafana/data';
-import { BackendDataSourceResponse, FetchResponse, setBackendSrv, setDataSourceSrv } from '@grafana/runtime';
-import config from 'app/core/config';
+import {
+  BackendDataSourceResponse,
+  FetchResponse,
+  setBackendSrv,
+  setDataSourceSrv,
+  TemplateSrv,
+} from '@grafana/runtime';
+import { BarGaugeDisplayMode, TableCellDisplayMode } from '@grafana/schema';
 
 import {
   DEFAULT_LIMIT,
@@ -22,9 +29,10 @@ import {
   buildExpr,
   buildLinkExpr,
   getRateAlignedValues,
-  makeApmRequest,
+  makeServiceGraphViewRequest,
   makeTempoLink,
   getFieldConfig,
+  getEscapedSpanNames,
 } from './datasource';
 import mockJson from './mockJsonResponse.json';
 import mockServiceGraph from './mockServiceGraph.json';
@@ -49,9 +57,10 @@ describe('Tempo data source', () => {
   beforeEach(() => (console.error = consoleErrorMock));
 
   it('returns empty response when traceId is empty', async () => {
-    const ds = new TempoDatasource(defaultSettings);
+    const templateSrv: TemplateSrv = { replace: jest.fn() } as unknown as TemplateSrv;
+    const ds = new TempoDatasource(defaultSettings, templateSrv);
     const response = await lastValueFrom(
-      ds.query({ targets: [{ refId: 'refid1', queryType: 'traceId', query: '' } as Partial<TempoQuery>] } as any),
+      ds.query({ targets: [{ refId: 'refid1', queryType: 'traceql', query: '' } as Partial<TempoQuery>] } as any),
       { defaultValue: 'empty' }
     );
     expect(response).toBe('empty');
@@ -61,30 +70,44 @@ describe('Tempo data source', () => {
     function getQuery(): TempoQuery {
       return {
         refId: 'x',
-        queryType: 'traceId',
+        queryType: 'traceql',
         linkedQuery: {
           refId: 'linked',
           expr: '{instance="$interpolationVar"}',
         },
-        query: '$interpolationVar',
+        query: '$interpolationVarWithPipe',
+        spanName: '$interpolationVar',
+        serviceName: '$interpolationVar',
         search: '$interpolationVar',
         minDuration: '$interpolationVar',
         maxDuration: '$interpolationVar',
+        filters: [],
       };
     }
+    let templateSrv: TemplateSrv;
+    const text = 'interpolationText';
+    const textWithPipe = 'interpolationTextOne|interpolationTextTwo';
+
+    beforeEach(() => {
+      templateSrv = initTemplateSrv('key', [
+        {
+          type: 'custom',
+          name: 'interpolationVar',
+          current: { value: [text] },
+        },
+        {
+          type: 'custom',
+          name: 'interpolationVarWithPipe',
+          current: { value: [textWithPipe] },
+        },
+      ]);
+    });
 
     it('when traceId query for dashboard->explore', async () => {
-      const templateSrv: any = { replace: jest.fn() };
       const ds = new TempoDatasource(defaultSettings, templateSrv);
-      const text = 'interpolationText';
-      templateSrv.replace.mockReturnValue(text);
-
-      const queries = ds.interpolateVariablesInQueries([getQuery()], {
-        interpolationVar: { text: text, value: text },
-      });
-      expect(templateSrv.replace).toBeCalledTimes(7);
-      expect(queries[0].linkedQuery?.expr).toBe(text);
-      expect(queries[0].query).toBe(text);
+      const queries = ds.interpolateVariablesInQueries([getQuery()], {});
+      expect(queries[0].linkedQuery?.expr).toBe(`{instance=\"${text}\"}`);
+      expect(queries[0].query).toBe(textWithPipe);
       expect(queries[0].serviceName).toBe(text);
       expect(queries[0].spanName).toBe(text);
       expect(queries[0].search).toBe(text);
@@ -93,28 +116,24 @@ describe('Tempo data source', () => {
     });
 
     it('when traceId query for template variable', async () => {
-      const templateSrv: any = { replace: jest.fn() };
+      const scopedText = 'scopedInterpolationText';
       const ds = new TempoDatasource(defaultSettings, templateSrv);
-      const text = 'interpolationText';
-      templateSrv.replace.mockReturnValue(text);
-
       const resp = ds.applyTemplateVariables(getQuery(), {
-        interpolationVar: { text: text, value: text },
+        interpolationVar: { text: scopedText, value: scopedText },
       });
-      expect(templateSrv.replace).toBeCalledTimes(7);
-      expect(resp.linkedQuery?.expr).toBe(text);
-      expect(resp.query).toBe(text);
-      expect(resp.serviceName).toBe(text);
-      expect(resp.spanName).toBe(text);
-      expect(resp.search).toBe(text);
-      expect(resp.minDuration).toBe(text);
-      expect(resp.maxDuration).toBe(text);
+      expect(resp.linkedQuery?.expr).toBe(`{instance=\"${scopedText}\"}`);
+      expect(resp.query).toBe(textWithPipe);
+      expect(resp.serviceName).toBe(scopedText);
+      expect(resp.spanName).toBe(scopedText);
+      expect(resp.search).toBe(scopedText);
+      expect(resp.minDuration).toBe(scopedText);
+      expect(resp.maxDuration).toBe(scopedText);
     });
   });
 
   it('parses json fields from backend', async () => {
     setupBackendSrv(
-      new MutableDataFrame({
+      createDataFrame({
         fields: [
           { name: 'traceID', values: ['04450900759028499335'] },
           { name: 'spanID', values: ['4322526419282105830'] },
@@ -136,7 +155,7 @@ describe('Tempo data source', () => {
     expect(
       (response.data[0] as DataFrame).fields.map((f) => ({
         name: f.name,
-        values: f.values.toArray(),
+        values: f.values,
       }))
     ).toMatchObject([
       { name: 'traceID', values: ['04450900759028499335'] },
@@ -154,7 +173,7 @@ describe('Tempo data source', () => {
     expect(
       (response.data[1] as DataFrame).fields.map((f) => ({
         name: f.name,
-        values: f.values.toArray(),
+        values: f.values,
       }))
     ).toMatchObject([
       { name: 'id', values: ['4322526419282105830'] },
@@ -168,7 +187,7 @@ describe('Tempo data source', () => {
     expect(
       (response.data[2] as DataFrame).fields.map((f) => ({
         name: f.name,
-        values: f.values.toArray(),
+        values: f.values,
       }))
     ).toMatchObject([
       { name: 'id', values: [] },
@@ -188,7 +207,7 @@ describe('Tempo data source', () => {
     const field = response.data[0].fields[0];
     expect(field.name).toBe('traceID');
     expect(field.type).toBe(FieldType.string);
-    expect(field.values.get(0)).toBe('60ba2abb44f13eae');
+    expect(field.values[0]).toBe('60ba2abb44f13eae');
     expect(field.values.length).toBe(6);
   });
 
@@ -237,6 +256,7 @@ describe('Tempo data source', () => {
       minDuration: '$interpolationVar',
       maxDuration: '$interpolationVar',
       limit: 10,
+      filters: [],
     };
     const builtQuery = ds.buildSearchQuery(tempoQuery);
     expect(builtQuery).toStrictEqual({
@@ -254,6 +274,7 @@ describe('Tempo data source', () => {
       refId: 'A',
       query: '',
       search: '',
+      filters: [],
     };
     const builtQuery = ds.buildSearchQuery(tempoQuery);
     expect(builtQuery).toStrictEqual({
@@ -269,6 +290,7 @@ describe('Tempo data source', () => {
       refId: 'A',
       query: '',
       search: '',
+      filters: [],
     };
     const timeRange = { startTime: 0, endTime: 1000 };
     const builtQuery = ds.buildSearchQuery(tempoQuery, timeRange);
@@ -283,6 +305,7 @@ describe('Tempo data source', () => {
   it('formats native search query history correctly', () => {
     const ds = new TempoDatasource(defaultSettings);
     const tempoQuery: TempoQuery = {
+      filters: [],
       queryType: 'nativeSearch',
       refId: 'A',
       query: '',
@@ -388,7 +411,7 @@ describe('Tempo data source', () => {
           raw: { from: '15m', to: 'now' },
         },
       },
-      [{ refId: 'refid1', queryType: 'traceId', query: '' } as TempoQuery]
+      [{ refId: 'refid1', queryType: 'traceql', query: '' } as TempoQuery]
     );
 
     expect(request.range.from.unix()).toBe(dateTime(new Date(2022, 8, 13, 15, 58, 0, 0)).unix());
@@ -417,7 +440,7 @@ describe('Tempo data source', () => {
           raw: { from: '15m', to: 'now' },
         },
       },
-      [{ refId: 'refid1', queryType: 'traceId', query: '' } as TempoQuery]
+      [{ refId: 'refid1', queryType: 'traceql', query: '' } as TempoQuery]
     );
 
     expect(request.range.from.unix()).toBe(dateTime(0).unix());
@@ -425,7 +448,7 @@ describe('Tempo data source', () => {
   });
 });
 
-describe('Tempo apm table', () => {
+describe('Tempo service graph view', () => {
   it('runs service graph queries', async () => {
     const ds = new TempoDatasource({
       ...defaultSettings,
@@ -435,25 +458,24 @@ describe('Tempo apm table', () => {
         },
       },
     });
-    config.featureToggles.tempoApmTable = true;
     setDataSourceSrv(backendSrvWithPrometheus as any);
     const response = await lastValueFrom(
-      ds.query({ targets: [{ queryType: 'serviceMap' }], range: getDefaultTimeRange() } as any)
+      ds.query({ targets: [{ queryType: 'serviceMap' }], range: getDefaultTimeRange(), app: CoreApp.Explore } as any)
     );
 
     expect(response.data).toHaveLength(3);
     expect(response.state).toBe(LoadingState.Done);
 
-    // APM table
+    // Service Graph view
     expect(response.data[0].fields[0].name).toBe('Name');
-    expect(response.data[0].fields[0].values.toArray().length).toBe(2);
-    expect(response.data[0].fields[0].values.toArray()[0]).toBe('HTTP Client');
-    expect(response.data[0].fields[0].values.toArray()[1]).toBe('HTTP GET - root');
+    expect(response.data[0].fields[0].values.length).toBe(2);
+    expect(response.data[0].fields[0].values[0]).toBe('HTTP Client');
+    expect(response.data[0].fields[0].values[1]).toBe('HTTP GET - root');
 
     expect(response.data[0].fields[1].name).toBe('Rate');
-    expect(response.data[0].fields[1].values.toArray().length).toBe(2);
-    expect(response.data[0].fields[1].values.toArray()[0]).toBe(12.75164671814457);
-    expect(response.data[0].fields[1].values.toArray()[1]).toBe(12.121331111401608);
+    expect(response.data[0].fields[1].values.length).toBe(2);
+    expect(response.data[0].fields[1].values[0]).toBe(12.75164671814457);
+    expect(response.data[0].fields[1].values[1]).toBe(12.121331111401608);
     expect(response.data[0].fields[1].config.decimals).toBe(2);
     expect(response.data[0].fields[1].config.links[0].title).toBe('Rate');
     expect(response.data[0].fields[1].config.links[0].internal.query.expr).toBe(
@@ -463,11 +485,12 @@ describe('Tempo apm table', () => {
     expect(response.data[0].fields[1].config.links[0].internal.query.exemplar).toBe(true);
     expect(response.data[0].fields[1].config.links[0].internal.query.instant).toBe(false);
 
-    expect(response.data[0].fields[2].values.toArray().length).toBe(2);
-    expect(response.data[0].fields[2].values.toArray()[0]).toBe(12.75164671814457);
-    expect(response.data[0].fields[2].values.toArray()[1]).toBe(12.121331111401608);
+    expect(response.data[0].fields[2].values.length).toBe(2);
+    expect(response.data[0].fields[2].values[0]).toBe(12.75164671814457);
+    expect(response.data[0].fields[2].values[1]).toBe(12.121331111401608);
     expect(response.data[0].fields[2].config.color.mode).toBe('continuous-BlPu');
-    expect(response.data[0].fields[2].config.custom.displayMode).toBe('lcd-gauge');
+    expect(response.data[0].fields[2].config.custom.cellOptions.mode).toBe(BarGaugeDisplayMode.Lcd);
+    expect(response.data[0].fields[2].config.custom.cellOptions.type).toBe(TableCellDisplayMode.Gauge);
     expect(response.data[0].fields[2].config.decimals).toBe(3);
 
     expect(response.data[0].fields[3].name).toBe('Error Rate');
@@ -487,7 +510,8 @@ describe('Tempo apm table', () => {
     expect(response.data[0].fields[4].values[0]).toBe(3.75164671814457);
     expect(response.data[0].fields[4].values[1]).toBe(3.121331111401608);
     expect(response.data[0].fields[4].config.color.mode).toBe('continuous-RdYlGr');
-    expect(response.data[0].fields[4].config.custom.displayMode).toBe('lcd-gauge');
+    expect(response.data[0].fields[4].config.custom.cellOptions.mode).toBe(BarGaugeDisplayMode.Lcd);
+    expect(response.data[0].fields[4].config.custom.cellOptions.type).toBe(TableCellDisplayMode.Gauge);
     expect(response.data[0].fields[4].config.decimals).toBe(3);
 
     expect(response.data[0].fields[5].name).toBe('Duration (p90)');
@@ -560,6 +584,16 @@ describe('Tempo apm table', () => {
     expect(builtQuery).toBe(
       'topk(5, sum(rate(traces_spanmetrics_calls_total{service="app",service="app"}[$__range])) by (span_name))'
     );
+
+    targets = { targets: [{ queryType: 'serviceMap', serviceMapQuery: '{client="${app}",service="$app"}' }] } as any;
+    builtQuery = buildExpr(
+      { expr: 'topk(5, sum(rate(traces_spanmetrics_calls_total{}[$__range])) by (span_name))', params: [] },
+      '',
+      targets
+    );
+    expect(builtQuery).toBe(
+      'topk(5, sum(rate(traces_spanmetrics_calls_total{service="${app}",service="$app"}[$__range])) by (span_name))'
+    );
   });
 
   it('should build link expr correctly', () => {
@@ -567,6 +601,20 @@ describe('Tempo apm table', () => {
     expect(builtQuery).toBe('sum(rate(traces_spanmetrics_calls_total{}[$__rate_interval]))');
   });
 
+  it('should escape span names correctly', () => {
+    const spanNames = [
+      '/actuator/health/**',
+      '$type + [test]|HTTP POST - post',
+      'server.cluster.local:9090^/sample.test(.*)?',
+    ];
+    let escaped = getEscapedSpanNames(spanNames);
+    expect(escaped).toEqual([
+      '/actuator/health/\\\\*\\\\*',
+      '\\\\$type \\\\+ \\\\[test\\\\]\\\\|HTTP POST - post',
+      'server\\\\.cluster\\\\.local:9090\\\\^/sample\\\\.test\\\\(\\\\.\\\\*\\\\)\\\\?',
+    ]);
+  });
+
   it('should get field config correctly', () => {
     let datasourceUid = 's4Jvz8Qnk';
     let tempoDatasourceUid = 'EbPO1fYnz';
@@ -655,33 +703,33 @@ describe('Tempo apm table', () => {
               filterable: true,
             },
             type: 'string',
-            values: new ArrayVector(['HTTP Client', 'HTTP GET', 'HTTP GET - root', 'HTTP POST', 'HTTP POST - post']),
+            values: ['HTTP Client', 'HTTP GET', 'HTTP GET - root', 'HTTP POST', 'HTTP POST - post'],
           },
         ],
       },
     ];
     const objToAlign = {
       'HTTP GET - root': {
-        value: 0.1234,
+        value: '0.1234',
       },
       'HTTP GET': {
-        value: 0.6789,
+        value: '0.6789',
       },
       'HTTP POST - post': {
-        value: 0.4321,
+        value: '0.4321',
       },
     };
 
-    let value = getRateAlignedValues(resp, objToAlign as any);
+    let value = getRateAlignedValues(resp, objToAlign);
     expect(value.toString()).toBe('0,0.6789,0.1234,0,0.4321');
   });
 
-  it('should make apm request correctly', () => {
-    const apmRequest = makeApmRequest([
+  it('should make service graph view request correctly', () => {
+    const request = makeServiceGraphViewRequest([
       'topk(5, sum(rate(traces_spanmetrics_calls_total{service="app"}[$__range])) by (span_name))"',
       'histogram_quantile(.9, sum(rate(traces_spanmetrics_latency_bucket{status_code="STATUS_CODE_ERROR",service="app",service="app",span_name=~"HTTP Client"}[$__range])) by (le))',
     ]);
-    expect(apmRequest).toEqual([
+    expect(request).toEqual([
       {
         refId: 'topk(5, sum(rate(traces_spanmetrics_calls_total{service="app"}[$__range])) by (span_name))"',
         expr: 'topk(5, sum(rate(traces_spanmetrics_calls_total{service="app"}[$__range])) by (span_name))"',
@@ -774,7 +822,7 @@ const defaultSettings: DataSourceInstanceSettings<TempoJsonData> = {
   readOnly: false,
 };
 
-const rateMetric = new MutableDataFrame({
+const rateMetric = createDataFrame({
   refId: 'topk(5, sum(rate(traces_spanmetrics_calls_total{span_kind="SPAN_KIND_SERVER"}[$__range])) by (span_name))',
   fields: [
     { name: 'Time', values: [1653725618609, 1653725618609] },
@@ -786,7 +834,7 @@ const rateMetric = new MutableDataFrame({
   ],
 });
 
-const errorRateMetric = new MutableDataFrame({
+const errorRateMetric = createDataFrame({
   refId:
     'topk(5, sum(rate(traces_spanmetrics_calls_total{status_code="STATUS_CODE_ERROR",span_name=~"HTTP Client|HTTP GET - root"}[$__range])) by (span_name))',
   fields: [
@@ -799,7 +847,7 @@ const errorRateMetric = new MutableDataFrame({
   ],
 });
 
-const durationMetric = new MutableDataFrame({
+const durationMetric = createDataFrame({
   refId:
     'histogram_quantile(.9, sum(rate(traces_spanmetrics_latency_bucket{span_name=~"HTTP GET - root"}[$__range])) by (le))',
   fields: [
@@ -811,7 +859,7 @@ const durationMetric = new MutableDataFrame({
   ],
 });
 
-const totalsPromMetric = new MutableDataFrame({
+const totalsPromMetric = createDataFrame({
   refId: 'traces_service_graph_request_total',
   fields: [
     { name: 'Time', values: [1628169788000, 1628169788000] },
@@ -824,7 +872,7 @@ const totalsPromMetric = new MutableDataFrame({
   ],
 });
 
-const secondsPromMetric = new MutableDataFrame({
+const secondsPromMetric = createDataFrame({
   refId: 'traces_service_graph_request_server_seconds_sum',
   fields: [
     { name: 'Time', values: [1628169788000, 1628169788000] },
@@ -837,7 +885,7 @@ const secondsPromMetric = new MutableDataFrame({
   ],
 });
 
-const failedPromMetric = new MutableDataFrame({
+const failedPromMetric = createDataFrame({
   refId: 'traces_service_graph_request_failed_total',
   fields: [
     { name: 'Time', values: [1628169788000, 1628169788000] },
