@@ -1835,6 +1835,42 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
       config: {},
       values: ['db'],
     },
+    {
+      name: 'kind',
+      type: 'string',
+      config: {},
+      values: ['client'],
+    },
+    {
+      name: 'statusCode',
+      type: 'number',
+      config: {},
+      values: [2],
+    },
+    {
+      name: 'statusMessage',
+      type: 'string',
+      config: {},
+      values: ['message'],
+    },
+    {
+      name: 'instrumentationLibraryName',
+      type: 'string',
+      config: {},
+      values: ['libraryName'],
+    },
+    {
+      name: 'instrumentationLibraryVersion',
+      type: 'string',
+      config: {},
+      values: ['libraryVersion'],
+    },
+    {
+      name: 'traceState',
+      type: 'string',
+      config: {},
+      values: ['traceState'],
+    },
     {
       name: 'serviceTags',
       type: 'other',
@@ -1930,10 +1966,6 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
             key: 'component',
             value: 'net/http',
           },
-          {
-            key: 'span.kind',
-            value: 'client',
-          },
         ],
       ],
     },
@@ -1994,6 +2026,60 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
         displayName: 'serviceName',
       },
     },
+    {
+      name: 'kind',
+      type: 'string',
+      config: {},
+      values: ['client'],
+      state: {
+        displayName: 'kind',
+      },
+    },
+    {
+      name: 'statusCode',
+      type: 'number',
+      config: {},
+      values: [2],
+      state: {
+        displayName: 'statusCode',
+      },
+    },
+    {
+      name: 'statusMessage',
+      type: 'string',
+      config: {},
+      values: ['message'],
+      state: {
+        displayName: 'statusMessage',
+      },
+    },
+    {
+      name: 'instrumentationLibraryName',
+      type: 'string',
+      config: {},
+      values: ['libraryName'],
+      state: {
+        displayName: 'instrumentationLibraryName',
+      },
+    },
+    {
+      name: 'instrumentationLibraryVersion',
+      type: 'string',
+      config: {},
+      values: ['libraryVersion'],
+      state: {
+        displayName: 'instrumentationLibraryVersion',
+      },
+    },
+    {
+      name: 'traceState',
+      type: 'string',
+      config: {},
+      values: ['traceState'],
+      state: {
+        displayName: 'traceState',
+      },
+    },
     {
       name: 'serviceTags',
       type: 'other',
@@ -2079,10 +2165,6 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
             key: 'component',
             value: 'net/http',
           },
-          {
-            key: 'span.kind',
-            value: 'client',
-          },
         ],
       ],
       state: {
@@ -2135,13 +2217,22 @@ export const otlpResponse = {
       },
       instrumentationLibrarySpans: [
         {
+          instrumentationLibrary: {
+            name: 'libraryName',
+            version: 'libraryVersion',
+          },
           spans: [
             {
-              traceId: 'AAAAAAAAAABguiq7RPE+rg==',
-              spanId: 'cmteMBAvwNA=',
-              parentSpanId: 'OY8PIaPbma4=',
+              traceId: '000000000000000060ba2abb44f13eae',
+              spanId: '726b5e30102fc0d0',
+              parentSpanId: '398f0f21a3db99ae',
               name: 'HTTP GET - root',
               kind: 'SPAN_KIND_CLIENT',
+              status: {
+                code: 2,
+                message: 'message',
+              },
+              traceState: 'traceState',
               startTimeUnixNano: 1627471657255809000,
               endTimeUnixNano: 1627471657256268000,
               attributes: [
