@@ -2,11 +2,11 @@ import React from 'react';
 
 import { Input, InlineFieldRow, InlineField, Select } from '@grafana/ui';
 
-import { NodesQuery, TestDataQuery } from '../types';
+import { NodesQuery, TestData } from '../dataquery.gen';
 
 export interface Props {
   onChange: (value: NodesQuery) => void;
-  query: TestDataQuery;
+  query: TestData;
 }
 export function NodeGraphEditor({ query, onChange }: Props) {
   const type = query.nodes?.type || 'random';
@@ -23,7 +23,7 @@ export function NodeGraphEditor({ query, onChange }: Props) {
           width={32}
         />
       </InlineField>
-      {type === 'random' && (
+      {(type === 'random' || type === 'random edges') && (
         <InlineField label="Count" labelWidth={14}>
           <Input
             type="number"
@@ -41,4 +41,4 @@ export function NodeGraphEditor({ query, onChange }: Props) {
   );
 }
 
-const options: Array<NodesQuery['type']> = ['random', 'response'];
+const options: Array<NodesQuery['type']> = ['random', 'response', 'random edges'];
