@@ -9,12 +9,15 @@ import {
   CSVReader,
   Field,
   LoadingState,
+  DataFrameSchema,
+  DataFrameData,
+  StreamingDataFrame,
 } from '@grafana/data';
 
-import { TestDataQuery, StreamingQuery } from './types';
 import { getRandomLine } from './LogIpsum';
+import { TestData, StreamingQuery } from './dataquery.gen';
 
-export const defaultQuery: StreamingQuery = {
+export const defaultStreamQuery: StreamingQuery = {
   type: 'signal',
   speed: 250, // ms
   spread: 3.5,
@@ -22,8 +25,8 @@ export const defaultQuery: StreamingQuery = {
   bands: 1,
 };
 
-export function runStream(target: TestDataQuery, req: DataQueryRequest<TestDataQuery>): Observable<DataQueryResponse> {
-  const query = defaults(target.stream, defaultQuery);
+export function runStream(target: TestData, req: DataQueryRequest<TestData>): Observable<DataQueryResponse> {
+  const query = defaults(target.stream, defaultStreamQuery);
   if ('signal' === query.type) {
     return runSignalStream(target, query, req);
   }
@@ -37,40 +40,41 @@ export function runStream(target: TestDataQuery, req: DataQueryRequest<TestDataQ
 }
 
 export function runSignalStream(
-  target: TestDataQuery,
+  target: TestData,
   query: StreamingQuery,
-  req: DataQueryRequest<TestDataQuery>
+  req: DataQueryRequest<TestData>
 ): Observable<DataQueryResponse> {
   return new Observable<DataQueryResponse>((subscriber) => {
     const streamId = `signal-${req.panelId}-${target.refId}`;
     const maxDataPoints = req.maxDataPoints || 1000;
 
-    const data = new CircularDataFrame({
-      append: 'tail',
-      capacity: maxDataPoints,
-    });
-    data.refId = target.refId;
-    data.name = target.alias || 'Signal ' + target.refId;
-    data.addField({ name: 'time', type: FieldType.time });
-    data.addField({ name: 'value', type: FieldType.number });
+    const schema: DataFrameSchema = {
+      refId: target.refId,
+      fields: [
+        { name: 'time', type: FieldType.time },
+        { name: target.alias ?? 'value', type: FieldType.number },
+      ],
+    };
 
     const { spread, speed, bands = 0, noise } = query;
-
     for (let i = 0; i < bands; i++) {
       const suffix = bands > 1 ? ` ${i + 1}` : '';
-      data.addField({ name: 'Min' + suffix, type: FieldType.number });
-      data.addField({ name: 'Max' + suffix, type: FieldType.number });
+      schema.fields.push({ name: 'Min' + suffix, type: FieldType.number });
+      schema.fields.push({ name: 'Max' + suffix, type: FieldType.number });
     }
 
+    const frame = StreamingDataFrame.fromDataFrameJSON({ schema }, { maxLength: maxDataPoints });
+
     let value = Math.random() * 100;
-    let timeoutId: any = null;
+    let timeoutId: ReturnType<typeof setTimeout>;
+    let lastSent = -1;
 
     const addNextRow = (time: number) => {
       value += (Math.random() - 0.5) * spread;
 
-      let idx = 0;
-      data.fields[idx++].values.add(time);
-      data.fields[idx++].values.add(value);
+      const data: DataFrameData = {
+        values: [[time], [value]],
+      };
 
       let min = value;
       let max = value;
@@ -79,9 +83,12 @@ export function runSignalStream(
         min = min - Math.random() * noise;
         max = max + Math.random() * noise;
 
-        data.fields[idx++].values.add(min);
-        data.fields[idx++].values.add(max);
+        data.values.push([min]);
+        data.values.push([max]);
       }
+
+      const event = { data };
+      return frame.push(event);
     };
 
     // Fill the buffer on init
@@ -94,13 +101,13 @@ export function runSignalStream(
     }
 
     const pushNextEvent = () => {
-      addNextRow(Date.now());
+      lastSent = Date.now();
+      addNextRow(lastSent);
       subscriber.next({
-        data: [data],
+        data: [frame],
         key: streamId,
         state: LoadingState.Streaming,
       });
-
       timeoutId = setTimeout(pushNextEvent, speed);
     };
 
@@ -115,9 +122,9 @@ export function runSignalStream(
 }
 
 export function runLogsStream(
-  target: TestDataQuery,
+  target: TestData,
   query: StreamingQuery,
-  req: DataQueryRequest<TestDataQuery>
+  req: DataQueryRequest<TestData>
 ): Observable<DataQueryResponse> {
   return new Observable<DataQueryResponse>((subscriber) => {
     const streamId = `logs-${req.panelId}-${target.refId}`;
@@ -135,11 +142,11 @@ export function runLogsStream(
 
     const { speed } = query;
 
-    let timeoutId: any = null;
+    let timeoutId: ReturnType<typeof setTimeout>;
 
     const pushNextEvent = () => {
-      data.fields[0].values.add(Date.now());
-      data.fields[1].values.add(getRandomLine());
+      data.fields[0].values.push(getRandomLine());
+      data.fields[1].values.push(Date.now());
 
       subscriber.next({
         data: [data],
@@ -160,9 +167,9 @@ export function runLogsStream(
 }
 
 export function runFetchStream(
-  target: TestDataQuery,
+  target: TestData,
   query: StreamingQuery,
-  req: DataQueryRequest<TestDataQuery>
+  req: DataQueryRequest<TestData>
 ): Observable<DataQueryResponse> {
   return new Observable<DataQueryResponse>((subscriber) => {
     const streamId = `fetch-${req.panelId}-${target.refId}`;
@@ -192,7 +199,7 @@ export function runFetchStream(
             data.addField(field);
           }
         },
-        onRow: (row: any[]) => {
+        onRow: (row) => {
           data.add(row);
         },
       },
