@@ -16,7 +16,7 @@ import { BarGauge, DataLinksContextMenu, VizRepeater, VizRepeaterRenderValueProp
 import { DataLinksContextMenuApi } from '@grafana/ui/src/components/DataLinks/DataLinksContextMenu';
 import { config } from 'app/core/config';
 
-import { PanelOptions } from './models.gen';
+import { Options } from './panelcfg.gen';
 
 export class BarGaugePanel extends PureComponent<BarGaugePanelProps> {
   renderComponent = (
@@ -49,6 +49,7 @@ export class BarGaugePanel extends PureComponent<BarGaugePanelProps> {
         className={targetClassName}
         alignmentFactors={count > 1 ? alignmentFactors : undefined}
         showUnfilled={options.showUnfilled}
+        valueDisplayMode={options.valueMode}
       />
     );
   };
@@ -60,7 +61,9 @@ export class BarGaugePanel extends PureComponent<BarGaugePanelProps> {
     if (hasLinks && getLinks) {
       return (
         <div style={{ width: '100%', display: orientation === VizOrientation.Vertical ? 'flex' : 'initial' }}>
-          <DataLinksContextMenu links={getLinks}>{(api) => this.renderComponent(valueProps, api)}</DataLinksContextMenu>
+          <DataLinksContextMenu style={{ height: '100%' }} links={getLinks}>
+            {(api) => this.renderComponent(valueProps, api)}
+          </DataLinksContextMenu>
         </div>
       );
     }
@@ -109,9 +112,9 @@ export class BarGaugePanel extends PureComponent<BarGaugePanelProps> {
     );
   }
 }
-export type BarGaugePanelProps = PanelProps<PanelOptions>;
+export type BarGaugePanelProps = PanelProps<Options>;
 
-export function clearNameForSingleSeries(count: number, field: FieldConfig<any>, display: DisplayValue): DisplayValue {
+export function clearNameForSingleSeries(count: number, field: FieldConfig, display: DisplayValue): DisplayValue {
   if (count === 1 && !field.displayName) {
     return {
       ...display,
