@@ -1,56 +1,71 @@
-import _ from 'lodash';
-import { PanelModel, PanelPlugin } from '@grafana/data';
-import { DashList } from './DashList';
-import { DashListOptions } from './types';
-import { FolderPicker } from 'app/core/components/Select/FolderPicker';
 import React from 'react';
+
+import { PanelModel, PanelPlugin } from '@grafana/data';
 import { TagsInput } from '@grafana/ui';
 
-export const plugin = new PanelPlugin<DashListOptions>(DashList)
+import {
+  ALL_FOLDER,
+  GENERAL_FOLDER,
+  ReadonlyFolderPicker,
+} from '../../../core/components/Select/ReadonlyFolderPicker/ReadonlyFolderPicker';
+
+import { DashList } from './DashList';
+import { defaultOptions, Options } from './panelcfg.gen';
+
+export const plugin = new PanelPlugin<Options>(DashList)
   .setPanelOptions((builder) => {
     builder
+      .addBooleanSwitch({
+        path: 'keepTime',
+        name: 'Include current time range',
+        defaultValue: defaultOptions.keepTime,
+      })
+      .addBooleanSwitch({
+        path: 'includeVars',
+        name: 'Include current template variable values',
+        defaultValue: defaultOptions.includeVars,
+      })
       .addBooleanSwitch({
         path: 'showStarred',
         name: 'Starred',
-        defaultValue: true,
+        defaultValue: defaultOptions.showStarred,
       })
       .addBooleanSwitch({
         path: 'showRecentlyViewed',
         name: 'Recently viewed',
-        defaultValue: false,
+        defaultValue: defaultOptions.showRecentlyViewed,
       })
       .addBooleanSwitch({
         path: 'showSearch',
         name: 'Search',
-        defaultValue: false,
+        defaultValue: defaultOptions.showSearch,
       })
       .addBooleanSwitch({
         path: 'showHeadings',
         name: 'Show headings',
-        defaultValue: true,
+        defaultValue: defaultOptions.showHeadings,
       })
       .addNumberInput({
         path: 'maxItems',
         name: 'Max items',
-        defaultValue: 10,
+        defaultValue: defaultOptions.maxItems,
       })
       .addTextInput({
         path: 'query',
         name: 'Query',
-        defaultValue: '',
+        defaultValue: defaultOptions.query,
       })
       .addCustomEditor({
         path: 'folderId',
         name: 'Folder',
         id: 'folderId',
-        defaultValue: null,
-        editor: function RenderFolderPicker(props) {
+        defaultValue: undefined,
+        editor: function RenderFolderPicker({ value, onChange }) {
           return (
-            <FolderPicker
-              initialFolderId={props.value}
-              initialTitle="All"
-              enableReset={true}
-              onChange={({ id }) => props.onChange(id)}
+            <ReadonlyFolderPicker
+              initialFolderId={value}
+              onChange={(folder) => onChange(folder?.id)}
+              extraFolders={[ALL_FOLDER, GENERAL_FOLDER]}
             />
           );
         },
@@ -60,13 +75,13 @@ export const plugin = new PanelPlugin<DashListOptions>(DashList)
         path: 'tags',
         name: 'Tags',
         description: '',
-        defaultValue: [],
+        defaultValue: defaultOptions.tags,
         editor(props) {
           return <TagsInput tags={props.value} onChange={props.onChange} />;
         },
       });
   })
-  .setMigrationHandler((panel: PanelModel<DashListOptions> & Record<string, any>) => {
+  .setMigrationHandler((panel: PanelModel<Options> & Record<string, any>) => {
     const newOptions = {
       showStarred: panel.options.showStarred ?? panel.starred,
       showRecentlyViewed: panel.options.showRecentlyViewed ?? panel.recent,
