@@ -1,40 +1,41 @@
 import { css } from '@emotion/css';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { styleMixins } from '@grafana/ui';
 
 export const getStyles = (theme: GrafanaTheme2) => ({
   dashlistSectionHeader: css`
-    margin-bottom: ${theme.spacing(2)};
-    color: ${theme.colors.secondary.text};
+    padding: ${theme.spacing(0.25, 1)};
+    margin-right: ${theme.spacing(1)};
   `,
-
   dashlistSection: css`
     margin-bottom: ${theme.spacing(2)};
     padding-top: 3px;
   `,
-
   dashlistLink: css`
-    ${styleMixins.listItem(theme)}
     display: flex;
     cursor: pointer;
-    margin: 3px;
-    padding: 7px;
-  `,
+    border-bottom: 1px solid ${theme.colors.border.weak};
+    margin-right: ${theme.spacing(1)};
+    padding: ${theme.spacing(1)};
 
+    &:hover {
+      a {
+        color: ${theme.colors.text.link};
+        text-decoration: underline;
+      }
+    }
+  `,
   dashlistStar: css`
     align-self: center;
     margin-right: 0px;
     color: ${theme.colors.secondary.text};
     z-index: 1;
   `,
-
   dashlistFolder: css`
-    color: ${theme.colors.secondary.text};
+    color: ${theme.colors.text.secondary};
     font-size: ${theme.typography.bodySmall.fontSize};
     line-height: ${theme.typography.body.lineHeight};
   `,
-
   dashlistTitle: css`
     &::after {
       position: absolute;
@@ -45,18 +46,15 @@ export const getStyles = (theme: GrafanaTheme2) => ({
       right: 0;
     }
   `,
-
   dashlistLinkBody: css`
     flex-grow: 1;
     overflow: hidden;
     text-overflow: ellipsis;
   `,
-
   dashlistItem: css`
     position: relative;
     list-style: none;
   `,
-
   gridContainer: css`
     display: grid;
     gap: ${theme.spacing(1)};
