@@ -23,7 +23,7 @@ import {
   UPLOT_AXIS_FONT_SIZE,
 } from '@grafana/ui';
 
-import { defaultPanelFieldConfig, PanelFieldConfig, PanelOptions } from './models.gen';
+import { defaultFieldConfig, FieldConfig, Options } from './panelcfg.gen';
 
 function incrRoundDn(num: number, incr: number) {
   return Math.floor(num / incr) * incr;
@@ -34,7 +34,7 @@ function incrRoundUp(num: number, incr: number) {
 }
 
 export interface HistogramProps extends Themeable2 {
-  options: PanelOptions; // used for diff
+  options: Options; // used for diff
   alignedFrame: DataFrame; // This could take HistogramFields
   bucketSize: number;
   width: number;
@@ -47,12 +47,16 @@ export interface HistogramProps extends Themeable2 {
 
 export function getBucketSize(frame: DataFrame) {
   // assumes BucketMin is fields[0] and BucktMax is fields[1]
-  return frame.fields[1].values.get(0) - frame.fields[0].values.get(0);
+  return frame.fields[1].values[0] - frame.fields[0].values[0];
 }
 
 const prepConfig = (frame: DataFrame, theme: GrafanaTheme2) => {
   // todo: scan all values in BucketMin and BucketMax fields to assert if uniform bucketSize
 
+  // since this is x axis range, this should ideally come from xMin or xMax fields, not a count field
+  // though both methods are probably hacks, and we should just accept explicit opts into this prepConfig
+  let { min: xScaleMin, max: xScaleMax } = frame.fields[2].config;
+
   let builder = new UPlotConfigBuilder();
 
   // assumes BucketMin is fields[0] and BucktMax is fields[1]
@@ -64,8 +68,8 @@ const prepConfig = (frame: DataFrame, theme: GrafanaTheme2) => {
     let minSpace = u.axes[axisIdx]._space;
     let bucketWidth = u.valToPos(u.data[0][0] + bucketSize, 'x') - u.valToPos(u.data[0][0], 'x');
 
-    let firstSplit = u.data[0][0];
-    let lastSplit = u.data[0][u.data[0].length - 1] + bucketSize;
+    let firstSplit = incrRoundDn(xScaleMin ?? u.data[0][0], bucketSize);
+    let lastSplit = incrRoundUp(xScaleMax ?? u.data[0][u.data[0].length - 1] + bucketSize, bucketSize);
 
     let splits = [];
     let skip = Math.ceil(minSpace / bucketWidth);
@@ -84,6 +88,14 @@ const prepConfig = (frame: DataFrame, theme: GrafanaTheme2) => {
     orientation: ScaleOrientation.Horizontal,
     direction: ScaleDirection.Right,
     range: (u, wantedMin, wantedMax) => {
+      // these settings will prevent zooming, probably okay?
+      if (xScaleMin != null) {
+        wantedMin = xScaleMin;
+      }
+      if (xScaleMax != null) {
+        wantedMax = xScaleMax;
+      }
+
       let fullRangeMin = u.data[0][0];
       let fullRangeMax = u.data[0][u.data[0].length - 1];
 
@@ -182,7 +194,7 @@ const prepConfig = (frame: DataFrame, theme: GrafanaTheme2) => {
     field.state = field.state ?? {};
     field.state.seriesIndex = seriesIndex++;
 
-    const customConfig: PanelFieldConfig = { ...defaultPanelFieldConfig, ...field.config.custom };
+    const customConfig: FieldConfig = { ...defaultFieldConfig, ...field.config.custom };
 
     const scaleKey = 'y';
     const colorMode = getFieldColorModeForField(field);
@@ -221,7 +233,7 @@ const preparePlotData = (frame: DataFrame) => {
 
   for (const field of frame.fields) {
     if (field.name !== histogramFrameBucketMaxFieldName) {
-      data.push(field.values.toArray());
+      data.push(field.values);
     }
   }
 
@@ -311,13 +323,7 @@ export class Histogram extends React.Component<HistogramProps, State> {
     return (
       <VizLayout width={width} height={height} legend={this.renderLegend(config)}>
         {(vizWidth: number, vizHeight: number) => (
-          <UPlotChart
-            config={this.state.config!}
-            data={this.state.alignedData}
-            width={vizWidth}
-            height={vizHeight}
-            timeRange={null as any}
-          >
+          <UPlotChart config={this.state.config!} data={this.state.alignedData} width={vizWidth} height={vizHeight}>
             {children ? children(config, alignedFrame) : null}
           </UPlotChart>
         )}
