@@ -16,10 +16,10 @@ import {
   LoadingState,
   applyFieldOverrides,
   LiveChannelAddress,
+  StreamingDataFrame,
 } from '@grafana/data';
 import { config, getGrafanaLiveSrv } from '@grafana/runtime';
 import { Alert, stylesFactory, Button, JSONFormatter, CustomScrollbar, CodeEditor } from '@grafana/ui';
-import { StreamingDataFrame } from 'app/features/live/data/StreamingDataFrame';
 
 import { TablePanel } from '../table/TablePanel';
 
@@ -192,10 +192,10 @@ export class LivePanel extends PureComponent<Props, State> {
           }),
           state: LoadingState.Streaming,
         } as PanelData;
-        const props = {
+        const props: PanelProps = {
           ...this.props,
           options: { frameIndex: 0, showHeader: true },
-        } as PanelProps<any>;
+        };
         return <TablePanel {...props} data={data} height={height} />;
       }
     }
