@@ -4,7 +4,7 @@ import React, { MouseEvent, memo } from 'react';
 import tinycolor from 'tinycolor2';
 
 import { Field, getFieldColorModeForField, GrafanaTheme2 } from '@grafana/data';
-import { useTheme2 } from '@grafana/ui';
+import { Icon, useTheme2 } from '@grafana/ui';
 
 import { HoverState } from './NodeGraph';
 import { NodeDatum } from './types';
@@ -32,6 +32,7 @@ const getStyles = (theme: GrafanaTheme2, hovering: HoverState) => ({
 
   text: css`
     fill: ${theme.colors.text.primary};
+    pointer-events: none;
   `,
 
   titleText: css`
@@ -40,7 +41,7 @@ const getStyles = (theme: GrafanaTheme2, hovering: HoverState) => ({
     overflow: hidden;
     white-space: nowrap;
     background-color: ${tinycolor(theme.colors.background.primary).setAlpha(0.6).toHex8String()};
-    width: 100px;
+    width: 140px;
   `,
 
   statsText: css`
@@ -57,14 +58,20 @@ const getStyles = (theme: GrafanaTheme2, hovering: HoverState) => ({
       background-color: ${tinycolor(theme.colors.background.primary).setAlpha(0.8).toHex8String()};
     }
   `,
+
+  clickTarget: css`
+    fill: none;
+    stroke: none;
+    pointer-events: fill;
+  `,
 });
 
 export const Node = memo(function Node(props: {
   node: NodeDatum;
+  hovering: HoverState;
   onMouseEnter: (id: string) => void;
   onMouseLeave: (id: string) => void;
   onClick: (event: MouseEvent<SVGElement>, node: NodeDatum) => void;
-  hovering: HoverState;
 }) {
   const { node, onMouseEnter, onMouseLeave, onClick, hovering } = props;
   const theme = useTheme2();
@@ -76,35 +83,16 @@ export const Node = memo(function Node(props: {
   }
 
   return (
-    <g
-      data-node-id={node.id}
-      className={styles.mainGroup}
-      onMouseEnter={() => {
-        onMouseEnter(node.id);
-      }}
-      onMouseLeave={() => {
-        onMouseLeave(node.id);
-      }}
-      onClick={(event) => {
-        onClick(event, node);
-      }}
-      aria-label={`Node: ${node.title}`}
-    >
+    <g data-node-id={node.id} className={styles.mainGroup} aria-label={`Node: ${node.title}`}>
       <circle className={styles.mainCircle} r={nodeR} cx={node.x} cy={node.y} />
       {isHovered && <circle className={styles.hoverCircle} r={nodeR - 3} cx={node.x} cy={node.y} strokeWidth={2} />}
       <ColorCircle node={node} />
-      <g className={styles.text}>
-        <foreignObject x={node.x - (isHovered ? 100 : 35)} y={node.y - 15} width={isHovered ? '200' : '70'} height="40">
-          <div className={cx(styles.statsText, isHovered && styles.textHovering)}>
-            <span>{node.mainStat && statToString(node.mainStat, node.dataFrameRowIndex)}</span>
-            <br />
-            <span>{node.secondaryStat && statToString(node.secondaryStat, node.dataFrameRowIndex)}</span>
-          </div>
-        </foreignObject>
+      <g className={styles.text} style={{ pointerEvents: 'none' }}>
+        <NodeContents node={node} hovering={hovering} />
         <foreignObject
-          x={node.x - (isHovered ? 100 : 50)}
+          x={node.x - (isHovered ? 100 : 70)}
           y={node.y + nodeR + 5}
-          width={isHovered ? '200' : '100'}
+          width={isHovered ? '200' : '140'}
           height="40"
         >
           <div className={cx(styles.titleText, isHovered && styles.textHovering)}>
@@ -114,16 +102,65 @@ export const Node = memo(function Node(props: {
           </div>
         </foreignObject>
       </g>
+      <rect
+        data-testid={`node-click-rect-${node.id}`}
+        onMouseEnter={() => {
+          onMouseEnter(node.id);
+        }}
+        onMouseLeave={() => {
+          onMouseLeave(node.id);
+        }}
+        onClick={(event) => {
+          onClick(event, node);
+        }}
+        className={styles.clickTarget}
+        x={node.x - nodeR - 5}
+        y={node.y - nodeR - 5}
+        width={nodeR * 2 + 10}
+        height={nodeR * 2 + 50}
+      />
     </g>
   );
 });
 
+/**
+ * Shows contents of the node which can be either an Icon or a main and secondary stat values.
+ */
+function NodeContents({ node, hovering }: { node: NodeDatum; hovering: HoverState }) {
+  const theme = useTheme2();
+  const styles = getStyles(theme, hovering);
+  const isHovered = hovering === 'active';
+
+  if (!(node.x !== undefined && node.y !== undefined)) {
+    return null;
+  }
+
+  return node.icon ? (
+    <foreignObject x={node.x - 35} y={node.y - 20} width="70" height="40">
+      <div style={{ width: 70, overflow: 'hidden', display: 'flex', justifyContent: 'center', marginTop: -4 }}>
+        <Icon data-testid={`node-icon-${node.icon}`} name={node.icon} size={'xxxl'} />
+      </div>
+    </foreignObject>
+  ) : (
+    <foreignObject x={node.x - (isHovered ? 100 : 35)} y={node.y - 15} width={isHovered ? '200' : '70'} height="40">
+      <div className={cx(styles.statsText, isHovered && styles.textHovering)}>
+        <span>{node.mainStat && statToString(node.mainStat.config, node.mainStat.values[node.dataFrameRowIndex])}</span>
+        <br />
+        <span>
+          {node.secondaryStat &&
+            statToString(node.secondaryStat.config, node.secondaryStat.values[node.dataFrameRowIndex])}
+        </span>
+      </div>
+    </foreignObject>
+  );
+}
+
 /**
  * Shows the outer segmented circle with different colors based on the supplied data.
  */
 function ColorCircle(props: { node: NodeDatum }) {
   const { node } = props;
-  const fullStat = node.arcSections.find((s) => s.values.get(node.dataFrameRowIndex) >= 1);
+  const fullStat = node.arcSections.find((s) => s.values[node.dataFrameRowIndex] >= 1);
   const theme = useTheme2();
 
   if (fullStat) {
@@ -140,7 +177,7 @@ function ColorCircle(props: { node: NodeDatum }) {
     );
   }
 
-  const nonZero = node.arcSections.filter((s) => s.values.get(node.dataFrameRowIndex) !== 0);
+  const nonZero = node.arcSections.filter((s) => s.values[node.dataFrameRowIndex] !== 0);
   if (nonZero.length === 0) {
     // Fallback if no arc is defined
     return (
@@ -155,14 +192,17 @@ function ColorCircle(props: { node: NodeDatum }) {
     );
   }
 
-  const { elements } = nonZero.reduce(
-    (acc, section) => {
+  const { elements } = nonZero.reduce<{
+    elements: React.ReactNode[];
+    percent: number;
+  }>(
+    (acc, section, index) => {
       const color = section.config.color?.fixedColor || '';
-      const value = section.values.get(node.dataFrameRowIndex);
+      const value = section.values[node.dataFrameRowIndex];
 
       const el = (
         <ArcSection
-          key={color}
+          key={index}
           r={nodeR}
           x={node.x!}
           y={node.y!}
@@ -182,7 +222,7 @@ function ColorCircle(props: { node: NodeDatum }) {
       acc.percent = acc.percent + value;
       return acc;
     },
-    { elements: [] as React.ReactNode[], percent: 0 }
+    { elements: [], percent: 0 }
   );
 
   return <>{elements}</>;
@@ -223,8 +263,8 @@ function ArcSection({
 
 function getColor(field: Field, index: number, theme: GrafanaTheme2): string {
   if (!field.config.color) {
-    return field.values.get(index);
+    return field.values[index];
   }
 
-  return getFieldColorModeForField(field).getCalculator(field, theme)(0, field.values.get(index));
+  return getFieldColorModeForField(field).getCalculator(field, theme)(0, field.values[index]);
 }
