@@ -1,4 +1,4 @@
-import React, { useCallback, useLayoutEffect, useRef } from 'react';
+import React, { useCallback, useLayoutEffect, useRef, useState } from 'react';
 import uPlot from 'uplot';
 
 import {
@@ -23,15 +23,17 @@ interface ExemplarsPluginProps {
   visibleSeries?: VisibleExemplarLabels;
 }
 
-export const ExemplarsPlugin: React.FC<ExemplarsPluginProps> = ({
+export const ExemplarsPlugin = ({
   exemplars,
   timeZone,
   getFieldLinks,
   config,
   visibleSeries,
-}) => {
+}: ExemplarsPluginProps) => {
   const plotInstance = useRef<uPlot>();
 
+  const [lockedExemplarFieldIndex, setLockedExemplarFieldIndex] = useState<DataFrameFieldIndex | undefined>();
+
   useLayoutEffect(() => {
     config.addHook('init', (u) => {
       plotInstance.current = u;
@@ -53,7 +55,7 @@ export const ExemplarsPlugin: React.FC<ExemplarsPluginProps> = ({
     const yMin = plotInstance.current.scales[yScale].min;
     const yMax = plotInstance.current.scales[yScale].max;
 
-    let y = value.values.get(dataFrameFieldIndex.fieldIndex);
+    let y = value.values[dataFrameFieldIndex.fieldIndex];
     // To not to show exemplars outside of the graph we set the y value to min if it is smaller and max if it is bigger than the size of the graph
     if (yMin != null && y < yMin) {
       y = yMin;
@@ -64,7 +66,7 @@ export const ExemplarsPlugin: React.FC<ExemplarsPluginProps> = ({
     }
 
     return {
-      x: plotInstance.current.valToPos(time.values.get(dataFrameFieldIndex.fieldIndex), 'x'),
+      x: plotInstance.current.valToPos(time.values[dataFrameFieldIndex.fieldIndex], 'x'),
       y: plotInstance.current.valToPos(y, yScale),
     };
   }, []);
@@ -83,6 +85,8 @@ export const ExemplarsPlugin: React.FC<ExemplarsPluginProps> = ({
 
       return (
         <ExemplarMarker
+          setClickedExemplarFieldIndex={setLockedExemplarFieldIndex}
+          clickedExemplarFieldIndex={lockedExemplarFieldIndex}
           timeZone={timeZone}
           getFieldLinks={getFieldLinks}
           dataFrame={dataFrame}
@@ -92,7 +96,7 @@ export const ExemplarsPlugin: React.FC<ExemplarsPluginProps> = ({
         />
       );
     },
-    [config, timeZone, getFieldLinks, visibleSeries]
+    [config, timeZone, getFieldLinks, visibleSeries, setLockedExemplarFieldIndex, lockedExemplarFieldIndex]
   );
 
   return (
@@ -138,6 +142,7 @@ interface LabelWithExemplarUIData {
   labels: Labels;
   color?: string;
 }
+
 /**
  * Get color of active series in legend
  */
@@ -154,7 +159,7 @@ const getExemplarColor = (
     });
     if (fields.length) {
       const hasMatch = fields.every((field, index, fields) => {
-        const value = field.values.get(dataFrameFieldIndex.fieldIndex);
+        const value = field.values[dataFrameFieldIndex.fieldIndex];
         return visibleLabel.labels[field.name] === value;
       });
 
@@ -199,7 +204,7 @@ const showExemplarMarker = (
           showMarker = visibleSeries.labels.some((series) => {
             return Object.keys(series.labels).every((label) => {
               const value = series.labels[label];
-              return fields.find((field) => field.values.get(dataFrameFieldIndex.fieldIndex) === value);
+              return fields.find((field) => field.values[dataFrameFieldIndex.fieldIndex] === value);
             });
           });
         }
