@@ -1,6 +1,6 @@
 import { DataQuery } from '@grafana/data';
+import { Dashboard, DataSourceRef } from '@grafana/schema';
 import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
-import { VariableModel } from 'app/features/variables/types';
 
 import { DashboardAcl } from './acl';
 
@@ -10,6 +10,15 @@ export interface DashboardDTO {
   meta: DashboardMeta;
 }
 
+export interface SaveDashboardResponseDTO {
+  id: number;
+  slug: string;
+  status: string;
+  uid: string;
+  url: string;
+  version: number;
+}
+
 export interface DashboardMeta {
   slug?: string;
   uid?: string;
@@ -23,7 +32,6 @@ export interface DashboardMeta {
   folderId?: number;
   folderUid?: string;
   canMakeEditable?: boolean;
-  submenuEnabled?: boolean;
   provisioned?: boolean;
   provisionedExternalId?: string;
   isStarred?: boolean;
@@ -44,7 +52,6 @@ export interface DashboardMeta {
   publicDashboardAccessToken?: string;
   publicDashboardUid?: string;
   publicDashboardEnabled?: boolean;
-  hasPublicDashboard?: boolean;
   dashboardNotFound?: boolean;
 }
 
@@ -59,12 +66,10 @@ export interface AnnotationsPermissions {
   organization: AnnotationActions;
 }
 
-export interface DashboardDataDTO {
+// FIXME: This should not override Dashboard types
+export interface DashboardDataDTO extends Dashboard {
   title: string;
   uid: string;
-  templating: {
-    list: VariableModel[];
-  };
   panels?: any[];
 }
 
@@ -75,6 +80,7 @@ export enum DashboardRoutes {
   Path = 'path-dashboard',
   Scripted = 'scripted-dashboard',
   Public = 'public-dashboard',
+  Embedded = 'embedded-dashboard',
 }
 
 export enum DashboardInitPhase {
@@ -87,7 +93,7 @@ export enum DashboardInitPhase {
 
 export interface DashboardInitError {
   message: string;
-  error: any;
+  error: unknown;
 }
 
 export enum KioskMode {
@@ -105,6 +111,7 @@ export interface QueriesToUpdateOnDashboardLoad {
 export interface DashboardState {
   getModel: GetMutableDashboardModelFn;
   initPhase: DashboardInitPhase;
+  initialDatasource?: DataSourceRef['uid'];
   initError: DashboardInitError | null;
   permissions: DashboardAcl[];
 }
