@@ -3,27 +3,27 @@
 import { AlertState, DataSourceInstanceSettings } from '@grafana/data';
 
 import {
+  Annotations,
+  GrafanaAlertState,
+  GrafanaAlertStateWithReason,
+  Labels,
+  mapStateWithReasonToBaseState,
   PromAlertingRuleState,
   PromRuleType,
   RulerRuleDTO,
-  Labels,
-  Annotations,
   RulerRuleGroupDTO,
-  GrafanaAlertState,
-  GrafanaAlertStateWithReason,
-  mapStateWithReasonToBaseState,
 } from './unified-alerting-dto';
 
 export type Alert = {
   activeAt: string;
   annotations: { [key: string]: string };
   labels: { [key: string]: string };
-  state: PromAlertingRuleState | GrafanaAlertStateWithReason;
+  state: Exclude<PromAlertingRuleState | GrafanaAlertStateWithReason, PromAlertingRuleState.Inactive>;
   value: string;
 };
 
 export function hasAlertState(alert: Alert, state: PromAlertingRuleState | GrafanaAlertState): boolean {
-  return mapStateWithReasonToBaseState(alert.state as GrafanaAlertStateWithReason) === state;
+  return mapStateWithReasonToBaseState(alert.state) === state;
 }
 
 interface RuleBase {
@@ -45,6 +45,9 @@ export interface AlertingRule extends RuleBase {
   };
   state: PromAlertingRuleState;
   type: PromRuleType.Alerting;
+  totals?: Partial<Record<Lowercase<GrafanaAlertState>, number>>;
+  totalsFiltered?: Partial<Record<Lowercase<GrafanaAlertState>, number>>;
+  activeAt?: string; // ISO timestamp
 }
 
 export interface RecordingRule extends RuleBase {
@@ -59,10 +62,16 @@ export type Rule = AlertingRule | RecordingRule;
 
 export type BaseRuleGroup = { name: string };
 
+type TotalsWithoutAlerting = Exclude<AlertInstanceTotalState, AlertInstanceTotalState.Alerting>;
+enum FiringTotal {
+  Firing = 'firing',
+}
 export interface RuleGroup {
   name: string;
   interval: number;
   rules: Rule[];
+  // totals only exist for Grafana Managed rules
+  totals?: Partial<Record<TotalsWithoutAlerting | FiringTotal, number>>;
 }
 
 export interface RuleNamespace {
@@ -89,13 +98,30 @@ export interface CombinedRule {
   rulerRule?: RulerRuleDTO;
   group: CombinedRuleGroup;
   namespace: CombinedRuleNamespace;
+  instanceTotals: AlertInstanceTotals;
+  filteredInstanceTotals: AlertInstanceTotals;
 }
 
+// export type AlertInstanceState = PromAlertingRuleState | 'nodata' | 'error';
+export enum AlertInstanceTotalState {
+  Alerting = 'alerting',
+  Pending = 'pending',
+  Normal = 'inactive',
+  NoData = 'nodata',
+  Error = 'error',
+}
+
+export type AlertInstanceTotals = Partial<Record<AlertInstanceTotalState, number>>;
+
+// AlertGroupTotals also contain the amount of recording and paused rules
+export type AlertGroupTotals = Partial<Record<AlertInstanceTotalState | 'paused' | 'recording', number>>;
+
 export interface CombinedRuleGroup {
   name: string;
   interval?: string;
   source_tenants?: string[];
   rules: CombinedRule[];
+  totals: AlertGroupTotals;
 }
 
 export interface CombinedRuleNamespace {
@@ -111,6 +137,12 @@ export interface RuleWithLocation<T = RulerRuleDTO> {
   rule: T;
 }
 
+export interface CombinedRuleWithLocation extends CombinedRule {
+  dataSourceName: string;
+  namespaceName: string;
+  groupName: string;
+}
+
 export interface PromRuleWithLocation {
   rule: AlertingRule;
   dataSourceName: string;
@@ -122,6 +154,7 @@ export interface CloudRuleIdentifier {
   ruleSourceName: string;
   namespace: string;
   groupName: string;
+  ruleName: string;
   rulerRuleHash: string;
 }
 export interface GrafanaRuleIdentifier {
@@ -134,6 +167,7 @@ export interface PrometheusRuleIdentifier {
   ruleSourceName: string;
   namespace: string;
   groupName: string;
+  ruleName: string;
   ruleHash: string;
 }
 
@@ -153,7 +187,7 @@ export interface SilenceFilterState {
 
 interface EvalMatch {
   metric: string;
-  tags?: any;
+  tags?: Record<string, string>;
   value: number;
 }
 
@@ -176,7 +210,7 @@ export interface StateHistoryItem {
   time: number;
   timeEnd: number;
   text: string;
-  tags: any[];
+  tags: string[];
   login: string;
   email: string;
   avatarUrl: string;
