@@ -1,12 +1,12 @@
 import { ActionCreatorWithoutPayload, PayloadActionCreator } from '@reduxjs/toolkit';
 
-export const mockToolkitActionCreator = (creator: PayloadActionCreator<any>) => {
+export const mockToolkitActionCreator = <T extends string>(creator: PayloadActionCreator<any, T>) => {
   return Object.assign(jest.fn(), creator);
 };
 
 export type ToolkitActionCreatorWithoutPayloadMockType = typeof mockToolkitActionCreatorWithoutPayload &
-  ActionCreatorWithoutPayload<any>;
+  ActionCreatorWithoutPayload;
 
-export const mockToolkitActionCreatorWithoutPayload = (creator: ActionCreatorWithoutPayload<any>) => {
+export const mockToolkitActionCreatorWithoutPayload = (creator: ActionCreatorWithoutPayload) => {
   return Object.assign(jest.fn(), creator);
 };
