@@ -2,11 +2,10 @@
 // angular is imported.
 import './global-jquery-shim';
 
-import Adapter from '@wojtekmaj/enzyme-adapter-react-17';
 import angular from 'angular';
-import { configure } from 'enzyme';
 
 import { EventBusSrv } from '@grafana/data';
+import { GrafanaBootConfig } from '@grafana/runtime';
 import 'blob-polyfill';
 import 'mutationobserver-shim';
 import './mocks/workers';
@@ -18,6 +17,16 @@ const testAppEvents = new EventBusSrv();
 const global = window as any;
 global.$ = global.jQuery = $;
 
+// mock the default window.grafanaBootData settings
+const settings: Partial<GrafanaBootConfig> = {
+  angularSupportEnabled: true,
+};
+global.grafanaBootData = {
+  settings,
+  user: {},
+  navTree: [],
+};
+
 // https://jestjs.io/docs/manual-mocks#mocking-methods-which-are-not-implemented-in-jsdom
 Object.defineProperty(global, 'matchMedia', {
   writable: true,
@@ -41,12 +50,16 @@ angular.module('grafana.directives', []);
 angular.module('grafana.filters', []);
 angular.module('grafana.routes', ['ngRoute']);
 
-// Mock IntersectionObserver
-const mockIntersectionObserver = jest.fn().mockReturnValue({
-  observe: jest.fn(),
-  unobserve: jest.fn(),
-  disconnect: jest.fn(),
-});
+// mock the intersection observer and just say everything is in view
+const mockIntersectionObserver = jest
+  .fn()
+  .mockImplementation((callback: (arg: IntersectionObserverEntry[]) => void) => ({
+    observe: jest.fn().mockImplementation((elem: HTMLElement) => {
+      callback([{ target: elem, isIntersecting: true }] as unknown as IntersectionObserverEntry[]);
+    }),
+    unobserve: jest.fn(),
+    disconnect: jest.fn(),
+  }));
 global.IntersectionObserver = mockIntersectionObserver;
 
 jest.mock('../app/core/core', () => ({
@@ -56,28 +69,6 @@ jest.mock('../app/core/core', () => ({
 jest.mock('../app/angular/partials', () => ({}));
 jest.mock('../app/features/plugins/plugin_loader', () => ({}));
 
-configure({ adapter: new Adapter() });
-
-const localStorageMock = (() => {
-  let store: any = {};
-  return {
-    getItem: (key: string) => {
-      return store[key];
-    },
-    setItem: (key: string, value: any) => {
-      store[key] = value.toString();
-    },
-    clear: () => {
-      store = {};
-    },
-    removeItem: (key: string) => {
-      delete store[key];
-    },
-  };
-})();
-
-global.localStorage = localStorageMock;
-
 const throwUnhandledRejections = () => {
   process.on('unhandledRejection', (err) => {
     throw err;
@@ -85,3 +76,33 @@ const throwUnhandledRejections = () => {
 };
 
 throwUnhandledRejections();
+
+// Used by useMeasure
+global.ResizeObserver = class ResizeObserver {
+  //callback: ResizeObserverCallback;
+
+  constructor(callback: ResizeObserverCallback) {
+    setTimeout(() => {
+      callback(
+        [
+          {
+            contentRect: {
+              x: 1,
+              y: 2,
+              width: 500,
+              height: 500,
+              top: 100,
+              bottom: 0,
+              left: 100,
+              right: 0,
+            },
+          } as ResizeObserverEntry,
+        ],
+        this
+      );
+    });
+  }
+  observe() {}
+  disconnect() {}
+  unobserve() {}
+};
