@@ -3,6 +3,7 @@ import { each, template } from 'lodash';
 import { RawTimeRange, PanelPluginMeta, dateMath } from '@grafana/data';
 import { GrafanaRootScope } from 'app/angular/GrafanaCtrl';
 import config from 'app/core/config';
+import { ContextSrv } from 'app/core/services/context_srv';
 import { PanelModel } from 'app/features/dashboard/state/PanelModel';
 
 import { angularMocks, sinon } from '../lib/common';
@@ -133,7 +134,7 @@ export class TimeSrvStub {
   }
 }
 
-export class ContextSrvStub {
+export class ContextSrvStub extends ContextSrv {
   isGrafanaVisible = jest.fn();
 
   getValidInterval() {
